#define	AT2SO	1
/*
 * what: rx2at - RC receiver servo signal to ASCII conversion
 * who:	 miru
 * when: April 2011...
 */
#include <avr/interrupt.h>
#include <avr/pgmspace.h>
#include <avr/boot.h>
const char version[] PROGMEM = "0.23 20161207";

/* Receiver type: PARALLEL 0-std, 1-rev, 2-cust mount  SERIAL 3-AETR56 */
#define	RX_CON	0

/* switch setup, S_GEAR-(2 pos), S_AUX1-(2 or 3 pos) *
 * S_LAND S_FMOD
 * S_AUX1 S_AUX1 one 3 position switch (e.g. DX7)
 * S_GEAR S_GEAR one 2 position switch
 * S_GEAR S_AUX1 two switches (e.g. DX6)
 * S_AUX1 S_GEAR two switches */
#define	S_LAND	S_AUX1
#define	S_FMOD	S_AUX1

/* transmitter mode, function assignment of sticks
 * T_MODE 1 -> left: V-ELEV H-RUDD right: V-THRO H-AILE
 * T_MODE 4 -> left: V-THRO H-AILE right: V-ELEV H-RUDD
 * T_MODE 2 -> left: V-THRO H-RUDD right: V-ELEV H-AILE, US common mode
 * T_MODE 3 -> left: V-ELEV H-AILE right: V-THRO H-RUDD, US reversed */
#define	T_MODE	2

/* drone configuration choices
 * outdoor:     FALSE or TRUE, use (0 or 1)
 * no_shell:    FALSE or TRUE, use (0 or 1)
 * max_euler:   0.0 ... 0.52 max pitch/roll angle [rad]
 * max_vz:      200 ... 2000 max climb speed [mm/s]
 * max_yaw      0.7 ... 6.11 max yaw speed [rad/s]
 * max_alt:     altitude limit [m] (0 is off)
 * animation:   0 - disable, enabled otherwise
 * videorecord: 0 - disable, 1 - enable (NOOP on Drone 1 or Drone 2 without USB stick)
 * dcat:        TX/RX disconnect action deferral [sec]
 *            outdoor,no_shell,max_euler,max_vz,max_yaw,max_alt,anim,rvid,dcat */
const char cfg1[] PROGMEM = "1,1,0.35,2000,3.5,0,1,1,30";	/* S standard */
const char cfg2[] PROGMEM = "1,1,0.52,2000,6.1,0,1,1,30";	/* W wild (max) */
const char cfg3[] PROGMEM = "0,0,0.21,700,1.75,2,0,0,5";	/* N normal */
const char cfg4[] PROGMEM = "0,0,0.10,700,1.50,2,0,0,5";	/* E easy */

/* VLBA output, Visible Low Battery Alert
 * the program can watch the battery capacity (percentage) on the drone, if it
 * goes below VLBA_THR the VLBA mechanism triggers. The drone's LEDs flash in RED
 * and VLBA output gets activated (blinking or steady), set to 0 to turn VLBA off */
#define	VLBA_THR	15	/* 0 or > 60 turns it off */
#define	VLBA_POL	1	/* 1-active high, 0-active low */
#define	VLBA_BLINK	1	/* 1-blink, 0-no blink */

/* GSWO output, you can route the GEAR channel status to this output to switch
 * something ON/OFF or use it as the output of the BEEP sequencer */
#define	GSWO_ENA	-1	/* -1 disable, 0 active low, 1 active high */
#define	GSWO_SRC	0	/* 0 - GEAR channel, 1 - BEEP output */

/* Arduino LED: 1 to turn off when airborne */
#define	NL_AIR	0

#define	LOOPHZ	30	/* loop frequency */
#define	S2LTIC(s)	(u08_t)((double)LOOPHZ*(double)(s)+0.5)


#if defined(__AVR_ATmega328P__)
#define	U4	0
/* Arduino Nano and ProMini */
/* LABEL PORT  DIR description
 *   RX0 PD.0  IN  UART receive
 *   TX1 PD.1  OUT UART transmit
 *   D2  PD.2  IN  RX parallel AUX1 channel
 *   D3  PD.3  IN  RX parallel GEAR channel, RX serial PPM signal
 *   D4  PD.4  IN  RX parallel RUDD channel
 *   D5  PD.5  IN  RX parallel ELEV channel
 *   D6  PD.6  IN  RX parallel AILE channel
 *   D7  PD.7  IN  RX parallel THRO channel
 * LABEL PORT  DIR description
 *   D8  PB.0
 *   D9  PB.1  OUT VLBA
 *   D10 PB.2  OUT GSWO (if GSWO_ENA >= 0)
 *   D11 PB.3  IN  SETUP input
 *   D12 PB.4
 *   D13 PB.5  OUT (LED,   Arduino comes this way)
 *   -   PB.6  -   (quarz, Arduino comes this way)
 *   -   PB.7  -   (quarz, Arduino comes this way)
 * LABEL PORT  DIR description
 *   A0  PC.0  IN  GPS RX
 *   A1  PC.1  OUT GPS TX
 *   A2  PC.2
 *   A3  PC.3  
 *   A4  PC.4  I/O (SDA two wire interface)
 *   A5  PC.5  I/O (SCL two wire interface)
 *   A6  -         (analog input 6, Nano and newer ProMini)
 *   A7  -         (analog input 7, Nano and newer ProMini)
 *
 * TIMER0: 'soft' serial port for GPS
 * TIMER1: system clock
 * TIMER2: not used
 */
#define	SIO_UDR		UDR0
#define	SIO_RX_VECT	USART_RX_vect
#define	SIO_TX_VECT	USART_UDRE_vect
#define	SIO_UCSRA	UCSR0A
#define	SIO_UCSRB	UCSR0B
#define	SIO_UCSRC	UCSR0C
#define	SIO_UBRR	UBRR0
#define	SIO_U2X		U2X0
#define	SIO_UDRIE	UDRIE0
#define	SIO_RXCIE	RXCIE0
#define	SIO_RXEN	RXEN0
#define	SIO_TXEN	TXEN0
#define	PIN_CHG_IRQEN()	PCICR |= _BV(PCIE2)|_BV(PCIE1)

#elif defined(__AVR_ATmega32U4__)
#define	U4	1
/* MiruPCB board layout
 * LABEL PORT  notes         DIR description
 *       PB.0
 * B1    PB.1  (SCK)         IN  RX parallel THRO
 * B2    PB.2  (MOSI)        IN  RX parallel AILE
 * B3    PB.3  (MISO)        IN  RX parallel ELEV
 * B4    PB.4                IN  RX parallel RUDD
 * B5    PB.5                IN  RX parallel GEAR
 * B6    PB.6                IN  RX parallel AUX1, RX serial PPM signal
 * RST   PB.7                (O) RESET*
 * LABEL PORT  notes         DIR description
 *       PC.6
 * LED   PC.7  LED green     OUT activity LED
 * LABEL PORT  notes         DIR description
 * SCL   PD.0  (SCL)         I/O (two wire interface)
 * SDA   PD.1  (SDA)         I/O (two wire interface)
 *       PD.2  (UART RX)     IN  UART receive
 *       PD.3  (UART TX)     OUT UART transmit
 * GTX   PD.4                OUT GPS  transmit
 *       PD.5
 * VLBA  PD.6                OUT VLBA
 * GSWO  PD.7                OUT GSWO
 * LABEL PORT  notes         DIR description
 *       PE.2  (HWB)
 * GRX   PE.6  (INT6)        IN  GPS receive
 * LABEL PORT  notes         DIR description
 *       PF.0
 *       PF.1
 *       PF.4
 *       PF.5
 *       PF.6               (OUT debug signal 1)
 *       PF.7               (OUT debug signal 0)
 *
 * TIMER0: 'soft' serial port for GPS
 * TIMER1: system clock
 * TIMER2: not used
 */
#define	SIO_UDR		UDR1
#define	SIO_RX_VECT	USART1_RX_vect
#define	SIO_TX_VECT	USART1_UDRE_vect
#define	SIO_UCSRA	UCSR1A
#define	SIO_UCSRB	UCSR1B
#define	SIO_UCSRC	UCSR1C
#define	SIO_UBRR	UBRR1
#define	SIO_U2X		U2X1
#define	SIO_UDRIE	UDRIE1
#define	SIO_RXCIE	RXCIE1
#define	SIO_RXEN	RXEN1
#define	SIO_TXEN	TXEN1
#define	PIN_CHG_IRQEN()	PCICR |= _BV(PCIE0), EIFR |= _BV(6)

#else
#error "sorry, processor not supported"
#endif

/* NOOPs, get redefined if needed */
#define	usb_sq()

void port_setup(void)
{
#if	U4 == 0		/* is Arduino Nano or ProMini */
	PORTB = 0b00000000;
	DDRB  = 0b00000000;

/* (label 13 on Arduino) HW comes with a LED on this pin */
#define	LED	_BV(5)
#define	LEDON()	PORTB |=  LED
#define	LEDOF()	PORTB &= ~LED
#define	LEDTG()	PORTB ^=  LED
	DDRB |= LED;	/* output */

/* (label 11 on Arduino) ground for SETUP */
	PORTB |= _BV(3);	/* enable pull-up */
#define	SETUP() ((PINB & _BV(3)) == 0)

/* (label 10 on Arduino) reflects GSWO_SRC if enabled */
#define	GSWO	_BV(2)
#if	GSWO_ENA >= 0
	#if	GSWO_ENA > 0
	#define	GSWON()	PORTB |=  GSWO
	#define	GSWOF()	PORTB &= ~GSWO
	#else
	#define	GSWON()	PORTB &= ~GSWO
	#define	GSWOF()	PORTB |=  GSWO
	#endif
	DDRB |= GSWO;	/* output */
	GSWOF();
#else
	#define	GSWON()
	#define	GSWOF()
#endif

/* (label  9 on Arduino) VLBA output pin */
#define	VLBA	_BV(1)
#if	VLBA_POL == 1
#define	VLBON()	PORTB |=  VLBA
#define	VLBOF()	PORTB &= ~VLBA
#else
#define	VLBOF()	PORTB |=  VLBA
#define	VLBON()	PORTB &= ~VLBA
#endif
#define	VLBTG()	PORTB ^=  VLBA
	VLBOF();
	DDRB |= VLBA;	/* output */

/* I2C interface */
	PORTC = 0b00000000;
	PORTC |= _BV(5)|_BV(4);	/* enable pullups for SDA/SCL */
	DDRC  = 0b00000000;

/* (label A0 on Arduino) GPS serial port in */
#define	GPS_RXI_VECT	PCINT1_vect
#define	GPS_RXI	_BV(0)
#define	GPS_RXI_INPUT()	(PINC & GPS_RXI)
#define	GPS_RXI_IRQON()	PCMSK1 |=  GPS_RXI
#define	GPS_RXI_IRQOF()	PCMSK1 &= ~GPS_RXI
	PORTC |=  GPS_RXI;	/* enable pullup on RXI */

/* (label A1 on Arduino) GPS serial port out */
#define	GPS_TXO	_BV(1)
#define	GPS_TXO_SET()	PORTC |=  GPS_TXO
#define	GPS_TXO_CLR()	PORTC &= ~GPS_TXO
#define	GPS_TXO_VAL()	(PORTC & GPS_TXO)
	DDRC  |=  GPS_TXO;	/* TXO is output */
	PORTC |=  GPS_TXO;	/* set TXO idle */

#define	RXSIG_VECT	PCINT2_vect
#define	RXSIG		PIND
#if	RX_CON == 3
#define	RXMSK		(_BV(3))
#else
#define	RXMSK		(_BV(7)|_BV(6)|_BV(5)|_BV(4)|_BV(3)|_BV(2))
#endif
	PCMSK2 = RXMSK;
	PORTD =  RXMSK|03;   	/* enable pull-ups for receiver inputs, and UART signals */
	DDRD  = 0b00000000;


#else	/* is MiruPCB */
#define	RXSIG_VECT	PCINT0_vect
#define	RXSIG		PINB
#if	RX_CON == 3
#define	RXMSK		(_BV(6))
#else
#define	RXMSK		(_BV(6)|_BV(5)|_BV(4)|_BV(3)|_BV(2)|_BV(1))
#endif
	PCMSK0 = RXMSK;
	PORTB  = RXMSK;	/* enable pull-ups for receiver */
	DDRB   = 0b00000000;

	PORTC = 0b00000000;
	DDRC  = 0b00000000;
/* HW comes with a LED on this pin */
#define LED	_BV(7)
#define	LEDON()	PORTC |=  LED
#define	LEDOF()	PORTC &= ~LED
#define	LEDTG()	PORTC ^=  LED
	DDRC  |= LED;	/* output */

/* I2C interface */
	PORTD = 0b00001111;   	/* enable pull-ups for UART and I2C signals */
	DDRD  = 0b00000000;
/* GSWO output pin */
#define	GSWO	_BV(7)
#if	GSWO_ENA >= 0
	#if	GSWO_ENA > 0
	#define	GSWON()	PORTD |=  GSWO
	#define	GSWOF()	PORTD &= ~GSWO
	#else
	#define	GSWON()	PORTD &= ~GSWO
	#define	GSWOF()	PORTD |=  GSWO
	#endif
	DDRD  |= GSWO;	/* output */
#else
	#define	GSWON()
	#define	GSWOF()
#endif
	GSWOF();
/* VLBA output pin */
#define	VLBA	_BV(6)
#if	VLBA_POL == 1
#define	VLBON()	PORTD |=  VLBA
#define	VLBOF()	PORTD &= ~VLBA
#else
#define	VLBOF()	PORTD |=  VLBA
#define	VLBON()	PORTD &= ~VLBA
#endif
#define	VLBTG()	PORTD ^=  VLBA
	VLBOF();
	DDRD  |= VLBA;		/* output */
/* GPS serial port out */
#define	GPS_TXO	_BV(4)
#define	GPS_TXO_SET()	PORTD |=  GPS_TXO
#define	GPS_TXO_CLR()	PORTD &= ~GPS_TXO
#define	GPS_TXO_VAL()	(PORTD & GPS_TXO)
	PORTD |= GPS_TXO;	/* set TXO idle */
	DDRD  |= GPS_TXO;	/* output */

	PORTE = 0b00000000;
/* GPS serial port in */
#define	GPS_RXI_VECT	INT6_vect
#define	GPS_RXI	_BV(6)
#define	GPS_RXI_INPUT()	(PINE & GPS_RXI)
#define	GPS_RXI_IRQON()	EIMSK |=  GPS_RXI
#define	GPS_RXI_IRQOF()	EIMSK &= ~GPS_RXI
	PORTE |= GPS_RXI;	/* enable pullup on RXI */
	DDRE  = 0b00000000;
	EICRB = 0b00010000;	/* -,-,isc61,ISC60,-,-,-,- */

	PORTF = 0b00000000;
	DDRF  = 0b00000000;
#endif

	MCUCR = 0b00000000;	/* PUD=0 clear global pull-up disable */
}

void sio_setup(void)
{
	SIO_UCSRB = 0b00000000;	/* rxcie0,txcie0,udrie0,rxen0,txen0,ucsz02,rxb80,txb80 */
	SIO_UCSRC = 0b00000110;	/* umsel01,umsel00,upm01,upm00,usbs0,UCSZ01,UCSZ00,ucpol0 */
	SIO_UCSRA = 0b00000000;	/* rxc0,txc0,udre0,fe0,dor0,upe0,u2x0,mpcm0 */
#if	F_CPU == 16000000UL	/* (see NOTES USART) */
	SIO_UBRR  = 16;
	SIO_UCSRA |= _BV(SIO_U2X);
#else
	SIO_UBRR  = (F_CPU/(16UL*115200UL)-1);
#endif
}

void tmr1_setup(void)
{
#define	F_TM1		(F_CPU/8UL)	/* (see NOTES TIMER1) */
#define	MS2TIC(ms)	(u32_t)((double)F_TM1*(double)(ms)*1e-3)
#define	TIC2MS(tic)	(u32_t)((tic)/(F_TM1/1000L))
#define	TIC2MS10(tic)	(u32_t)((tic)/(F_TM1/10000L))
#define	TIC2US(tic)	(u32_t)((tic)/(F_TM1/1000000L))

	TCCR1A = 0b00000000;	/* com1a1,com1a0,com1b1,com1b0,-,-,wgm11,wgm10 */
	TCCR1B = 0b00000010;	/* icnc1,ices1,-,wgm13,wgm12,cs12,CS11,cs10 F_CPU/8 */
	TCCR1C = 0b00000000;	/* foc1a,foc1b,-,-,-,-,-,- */
	TIMSK1 = 0b00000001;	/* -,-,icie1,-,-,ocie1b,ocie1a,TOIE1 */
}

#define	NEL(x)		(sizeof(x)/sizeof(x[0]))
#define	ABS(x)		((x)>=0?(x):-(x))
#define	MIN(a,b)	((a)<=(b)?(a):(b))
#define	LIMIT(mn,mx,v)	((v)<(mn)?(mn):(v)>(mx)?(mx):(v))
/* circular buffers */
#define	CB_FILL(r,w,s)	(((w)-(r)+(s))%(s))	/* available elements for get */
#define	CB_FREE(r,w,s)	(((r)-(w)+(s)-1)%(s))	/* available elements for put */
#define	CB_HASD(r,w)	((r)!=(w))		/* has data */
#define	CB_NO_D(r,w)	((r)==(w))		/* has no data */

typedef char		s08_t;
typedef volatile s08_t	vs08_t;
typedef unsigned char	u08_t;
typedef volatile u08_t	v08_t;
typedef unsigned short	u16_t;
typedef volatile u16_t	v16_t;
typedef unsigned long	u32_t;

typedef struct {
	u32_t	dcst;	/* drone status */
	char	cbat;	/* battery percentage left */
	char	beep;
	char	sgps;	/* GPS status */
}	__attribute__ ((packed)) m2a_t;

typedef struct {	/* radio signal sample */
	u08_t	smp;
	u32_t	tmr;	/* time stamp */
}	__attribute__ ((packed)) rsm_t;

struct {
	v16_t	t1ov;	/* timer 1 overflow count */
	v16_t	dcnt;	/* delay count for ms_dly() */
	u08_t	exit;
	u08_t	alin;

	struct { /* UART is connected to drone */
		/* circular receive buffer (r == w -> empty) */
		v08_t	rxw;
		v08_t	rxr;
		u08_t	rxb[32];
		/* circular transmit buffer (r == w -> empty) */
		v08_t	txw;
		v08_t	txr;
		u08_t	txb[200];
	}	sio;

#if	U4
	struct { /* FTDI simulation */
		u08_t	ep0a;	/* interface active */
		u08_t	ep0r;	/* EP0 received */
		union {	/* setup request packet */
			u08_t	b[8];
			struct {
				u08_t	bmRequestType;
				#define REQ_DIR	0x80
				#define  REQ_H2D	0x00
				#define  REQ_D2H	0x80
				#define REQ_TYP	0x60
				#define  REQ_STD	0x00
				#define  REQ_CLS	0x20
				#define  REQ_VEN	0x40
				#define REQ_DST	0x03
				#define  REQ_DEV	0x00
				#define  REQ_IFC	0x01
				#define  REQ_EPT	0x02
				#define  REQ_OTH	0x03
				u08_t	bRequest;
				#define GET_STATUS	0
				#define CLR_FEA		1
				#define SET_FEA		3
				#define SET_ADR		5
				#define GET_DSC		6
				#define SET_DSC		7
				#define GET_CFG		8
				#define SET_CFG		9
				#define GET_IFC		10
				#define SET_IFC		11
				u16_t	wValue;
				u16_t	wIndex;
				u16_t	wLength;
			};
		}	ep0b;
		/* EP1 management dev->host */
		u08_t	sofi;
		v08_t	ep1h;
		v08_t	ep1r;
		v08_t	ep1w;
		u08_t	ep1b[200];
		/* EP2 management host->dev */
		v08_t	ep2r;

		/* FTDI simulator */
		u08_t	mdst;	/* modem status */
		#define	MDST_RLSD	_BV(7)	/* receive line signal */
		#define	MDST_RI		_BV(6)	/* ring indicator */
		#define	MDST_DSR	_BV(5)	/* data set ready */
		#define	MDST_CTS	_BV(4)	/* clear to send */
		#define	MDST_RTS	_BV(3)	/* INTERNAL request to send */
		#define	MDST_DTR	_BV(2)	/* INTERNAL data terminal ready */
		#define	MDST(s)		((s)&~(MDST_RTS|MDST_DTR))
		#define	RST_MDST	(MDST_DSR|MDST_CTS|_BV(0))
		u08_t	lnst;	/* line status */
		#define	LNST_FIFO	_BV(7)	/* fifo error */
		#define	LNST_TEMT	_BV(6)	/* transmitter empty */
		#define	LNST_THRE	_BV(5)	/* transmit holding register enpty */
		#define	LNST_BI		_BV(4)	/* break interrupt */
		#define	LNST_FE		_BV(3)	/* framing error */
		#define	LNST_PE		_BV(2)	/* parity error */
		#define	LNST_OE		_BV(1)	/* overrun */
		#define	LNST_DR		_BV(0)	/* data ready */
		#define	RST_LNST	(LNST_TEMT|LNST_THRE|LNST_DR)
		#define	RUN_LNST	(LNST_TEMT|LNST_THRE|LNST_DR)
		u16_t	sfmt;	/* parity, number of bits */
		u16_t	baud;	/* speed */
		u16_t	tlat;	/* latency timer */
	}	usb;
#endif

	struct { /* messages from drone companion program */
		v08_t	ack;
		v08_t	cst;
		v08_t	nda;
		union {
			u08_t	b[0];
			m2a_t	m2a;
		}	dat;
		m2a_t	m2a;
	}	drm;

	struct { /* 'soft' serial port for GPS */
		int	b100;
		u08_t	tcnt;
		u08_t	thbt;
		u16_t	lstp;	/* sample of timer 1 at last stop bit */
		/* receiver */
		v08_t	rxi;	/* last value of input GPS_RXI */
		u08_t	rxm;	/* data bit mask register */
		u08_t	rxd;	/* data shift register */
		v08_t	rxw;
		v08_t	rxr;
		/* transmitter */
		u08_t	txm;
		u08_t	txd;
		v08_t	txe;
		v08_t	txw;
		v08_t	txr;
		/* GPS data assembly */
		u08_t	est;
		u08_t	ech;
		u08_t	cst;
		u08_t	cks;
		u08_t	seq;
		u08_t	b_r;
		u08_t	b_w;
		u08_t	b_s;
		u08_t	b_n;
		/* buffers */
		union {
			u32_t	rxt[95];	/* for baudrate detection */
			struct {
			u08_t	rxb[96];	/* buffers 24.7 ms on 38400 baud stream */
			u08_t	txb[32];
			char	buf[252];
			};
		};
	}	gps;

	struct {
		u08_t	stat;
		u08_t	tick;
	}	vlba;
#if	GSWO_ENA >= 0 && GSWO_SRC == 1
	struct {
		u08_t	nbp;
		u08_t	tmr;
		u08_t	seq;
	}	beep;
#endif

	struct { /* RC receiver signals */
		u08_t	err;	/* signals with errors */
		u08_t	erx;	/* consecutive error count rx_read() */

		u08_t	fms;	/* flight mode (rx_read()) */
#define	FMS_LAND	0
#define	FMS_FM_1	1	/* use camera for stabilization on ROL/PTC sticks centered */
#define	FMS_FM_2	2	/* idle up, don't use camera on ROL/PTC stick centered */
#define	FMS_FM_3	3	/* auto pilot mode */
		u08_t	fsq;	/* flight mode sequencer */
		u08_t	fst;	/* flight mode sequencer tic */
		u08_t	fsa;	/* flight mode sequencer animation trigger */

		u08_t	stk;	/* stick status (rx_read()) */
		u08_t	chg;	/* stick status change (dr_loop() private) */
#define	TS_RT	0x01
#define	TS_LF	0x02
#define	TS_UP	0x04
#define	TS_DN	0x08
#define	TS_MSK	0x0f
#define	ES_RT	0x10
#define	ES_LF	0x20
#define	ES_UP	0x40
#define	ES_DN	0x80
#define	ES_MSK	0xf0

		u08_t	smp;	/* last signal sample */
		u08_t	rsr;	/* read  index radio sampling buffer */
		u08_t	rsw;	/* write index radio sampling buffer */
		rsm_t	rsb[32];

/* AETR ordering for serial RX */
#define	S_AILE	0
#define	S_ELEV	1
#define	S_THRO	2
#define	S_RUDD	3
#define	S_GEAR	4
#define	S_AUX1	5
#define	S_NCHN	6
/* Note: independent of TX mode 1-4, throttle and elevator channels are never on the
 * same physical stick and are always controlled by vertical movement of the stick */
#if   T_MODE == 1 || T_MODE == 4
	#define	SH_THRO	S_AILE
	#define	SH_ELEV	S_RUDD
#else
	#define	SH_THRO	S_RUDD
	#define	SH_ELEV	S_AILE
#endif
#define	STKTHR	500	/* throttle/elevator stick threshold for switching */

		u32_t	lfs; /* [tic] last frame start */
		u32_t	ftm; /* [tic] frame time */
#if	RX_CON == 3
		struct {	/* serial RC receiver */
			v08_t	idx; /* serial RX pulse index */
			u32_t	ptd; /* [tic] last down transition processed */
		}	srx;
		struct chn {
			u32_t	tac; /* [tic] timer1 when signal activated */
			int	dur; /* [tic] measured pulse length */
			int	dbn; /* [tic] signal dead band */
			int	val; /* interpreted value (rx_read()) */
		}	chn[S_NCHN];
#else
		struct chn {
			u08_t	msk; /* port mask for signal */
			u32_t	tac; /* [tic] timer1 when signal activated */
			int	dur; /* [tic] measured pulse length */
			int	dbn; /* [tic] signal dead band */
			int	val; /* interpreted value (rx_read()) */
		}	chn[S_NCHN];
#endif
/* RX channel mapping to drone */
#define S_ROL	S_AILE
#define S_PTC	S_ELEV
#define S_GAZ	S_THRO
#define S_YAW	S_RUDD
/* RX channels used */
#if	GSWO_ENA >= 0
#define	S_SIG	(_BV(S_ROL)|_BV(S_PTC)|_BV(S_GAZ)|_BV(S_YAW)|_BV(S_AUX1)|_BV(S_GEAR))
#else
#define	S_SIG	(_BV(S_ROL)|_BV(S_PTC)|_BV(S_GAZ)|_BV(S_YAW)|_BV(S_LAND)|_BV(S_FMOD))
#endif
	}	rxs;

	/* drone companion program in flash */
	struct {
		u16_t	adr;
		u16_t	siz;
		u16_t	cks;
	}	arm;

	u08_t	dsnd;	/* snd_sc() destination, 0 sio, 1 usb */
	char	pad;	/* drone control <0 emergency, >0 fly, else land */
	char	cfw;	/* configuration wanted by telling from the sticks */
	u08_t	eewen;	/* EEROM */
	union {
		u08_t	eedat[6];
		struct {
			u16_t	eemag;
			u16_t	bid;	/* boot id */
			u08_t	cfg;
			u08_t	eecks;
		};
	};
#define	EE_MAG	0x2701
}	gl;

#if	GSWO_ENA >= 0 && GSWO_SRC == 1
void beep_sq(void)
{
	if (gl.beep.tmr && (gl.beep.tmr -= 1)) return;
	switch (gl.beep.seq) {
	case 0: if (gl.beep.nbp == 0) break;
		gl.beep.nbp -= 1;
		gl.beep.tmr = S2LTIC(0.25);
		gl.beep.seq = 1;
		GSWON();
		break;
	case 1: gl.beep.tmr = S2LTIC(0.25);
		gl.beep.seq = 0;
		GSWOF();
		break;
	}
}
#else
#define	beep_sq()
#endif

/*
 * How the 'soft' serial port for GPS works:
 * TIMER0 (8bit) is setup so it rolls on RS232 bit boundaries, this provides all that's
 * needed to do a transmitter with the timer rollover interrupt. The interrupt is turned
 * off when there is nothing to transmit.
 * To build a receiver at the same baudrate, the 1->0 transition of the RX input is used
 * to set the second compare register of the timer with the current timer value+some,
 * after that the compare interrupt becomes the sampling point for the RX input. Once a
 * byte is received, the RX transition interrupt is reenabled to wait for the next byte.
 */
void tmr0_setup(int b100)	/* argument is baudrate/100 */
{
	u16_t	cnt;
	u08_t	ccr;

	ccr = SREG; cli();
	TIMSK0 = 0b00000000;	/* -,-,-,-,-,ocie0b,ocie0a,toie0 */
	TCCR0A = 0b00000000;	/* com0a1,com0a0,com0b1,com0b0,-,-,wgm01,wgm00  */
	TCCR0B = 0b00000000;	/* foc0a,foc0b,-,-,wgm02,cs02,cs01,cs00  OFF */
	SREG = ccr;
	gl.gps.rxw = gl.gps.rxr = 0;
	gl.gps.txw = gl.gps.txr = 0;
	gl.gps.txe = 0;
	gl.gps.b100 = 0;
	gl.gps.tcnt = 0;
	gl.gps.thbt = 0;
	if (b100 <= 0) return;
	/* turn it on for baudrate b100 * 100 */
	gl.gps.txe = 1;
	cnt = (F_CPU/100UL)/(long)b100;
	for (ccr = 1; cnt >= 210L; cnt >>= 3) ccr++;
	if (ccr >= 5) return;
	gl.gps.b100 = b100;
	gl.gps.tcnt = cnt - 1;
	/* sampling offset relative to 1->0 transition of start bit */
	if (gl.gps.tcnt > 80)
		gl.gps.thbt = (cnt*50)/100;
	else	gl.gps.thbt = (cnt*15)/100;
	OCR0A  = gl.gps.tcnt;
	TCCR0B = ccr;
	TCCR0A = 0b00000010;	/* com0a1,com0a0,com0b1,com0b0,-,-,WGM01,wgm00  CTC mode */
}

ISR(TIMER1_OVF_vect)
{
	gl.t1ov++;
}

inline void itic(u16_t *t)	/* called with interrupts disabled */
{
	t[1] = gl.t1ov;
	t[0] = TCNT1;
	if ((TIFR1 & _BV(TOV1)) && t[0] < 0xffff) t[1]++;
}

u32_t tic(void)
{
	union { u16_t uw[2]; u32_t ul; } t;
	u08_t	srg;

	srg = SREG; cli();
	itic(t.uw);
	SREG = srg;
	return t.ul;
}

void ms_dly(int ndcnt)
{
	int	i;

	for (; ndcnt; ndcnt--)
		for (i = gl.dcnt; --i >= 0; )
			__asm__ __volatile__ ("nop");
}

void msdly_cali(void)
{
	u32_t	tmr;

	gl.dcnt = 2000;
	tmr = tic();
	ms_dly(100);
	tmr = tic() - tmr;
	gl.dcnt = (int)((200UL*F_TM1)/tmr);
}

void blip(unsigned char nb)
{
	while (nb--) {
		LEDON(); ms_dly( 20);
		LEDOF(); ms_dly(180);
	}
}

/*
 * EEPROM
 */
void eepr_save(void)
{
	u08_t	i;

	gl.eemag = EE_MAG;
	gl.eecks = 0;
	for (i = 0; i < (NEL(gl.eedat)-1); i++) gl.eecks += gl.eedat[i];
	gl.eewen = 0;
}

void eepr_updt(void)
{
	u08_t	t;

	if ((EECR & _BV(EEPE)) == 0) {
		EEAR = (int)gl.eewen;
		EEDR = gl.eedat[gl.eewen];
		t = SREG; cli();
		EECR = _BV(EEMPE);
		EECR |= _BV(EEPE);
		SREG = t;
		gl.eewen++;
	}
}

/*
 * uart receiver
 */
ISR(SIO_RX_VECT) /* receiver interrupt */
{
	u08_t	i;

	gl.sio.rxb[i = gl.sio.rxw] = SIO_UDR;
	if (++i >= NEL(gl.sio.rxb)) i = 0;
	if (i != gl.sio.rxr) gl.sio.rxw = i;
}

int sio_rc(void) /* read next character received */
{
	u08_t	i;
	int	b;

	if (CB_NO_D(gl.sio.rxr,gl.sio.rxw)) return -1;
	b = (int)gl.sio.rxb[i = gl.sio.rxr];
	gl.sio.rxr = ++i >= NEL(gl.sio.rxb) ? 0 : i;
	return b;
}

char sio_rf(void) /* flush sio receive buffer */
{
	if (gl.sio.rxr == gl.sio.rxw) return 0;
	gl.sio.rxr = gl.sio.rxw;
	return 1;
}

/*
 * uart transmitter
 */
ISR(SIO_TX_VECT) /* tx empty interrupt */
{
	u08_t	i;

	if (CB_HASD(gl.sio.txr,gl.sio.txw)) {
		SIO_UDR = gl.sio.txb[i = gl.sio.txr];
		gl.sio.txr = ++i >= NEL(gl.sio.txb) ? 0 : i;
	}
	if (CB_NO_D(gl.sio.txr,gl.sio.txw))
		SIO_UCSRB &= ~_BV(SIO_UDRIE); /* no more, disable TX IRQ */
}

void sio_sc(char c) /* send character */
{
	u08_t	i;

	gl.sio.txb[i = gl.sio.txw] = c;
	if (++i >= NEL(gl.sio.txb)) i = 0;
	if (i != gl.sio.txr) {
		gl.sio.txw = i;
		SIO_UCSRB |= _BV(SIO_UDRIE); /* enable TX IRQ */
	}
}

u08_t sio_tf(void) /* txb free space */
{
	return CB_FREE(gl.sio.txr,gl.sio.txw,NEL(gl.sio.txb));
}

void gps_rcv(void);

void sio_tw(void) /* wait for tx empty */
{
	do gps_rcv();
	while (CB_HASD(gl.sio.txr,gl.sio.txw));
}

void sio_ss(char *s) /* send string from ram */
{
	char	c;

	while ((c = *s++)) sio_sc(c);
}

void sio_sp(const char *p) /* send string from flash */
{
	char	c;

	while ((c = pgm_read_byte(p++))) sio_sc(c);
}

#define	SIO_SP(str)	sio_sp(PSTR(str))

void sio_rev(void)
{
	u08_t	n, k;

	for (n = 0; n < 5; n++) {
		k = pgm_read_byte(&version[n]);
		if (k == '.') continue;
		if (k == ' ') break;
		sio_sc(k);
	}
}

void snd_sc(char c)
{
#if	U4
	void usb_sc(char c);
	if (gl.dsnd) usb_sc(c); else
#endif
	sio_sc(c);
}

/*
 * convert to ASCII and transmit
 */
/* send hex */
void snd_snx(u08_t n) { n &= 0x0f; if (n <= 9) snd_sc('0'+n); else snd_sc('A'-10+n); }
void snd_sbx(u08_t b) { snd_snx(b>>4); snd_snx(b>>0); }
void snd_swx(u16_t w) { snd_sbx(w>>8); snd_sbx(w>>0); }

void snd_sid(char lc, int i) /* integer decimal */
{
	u08_t	fw, nd, sn, b[16];

	fw = sn = nd = 0;
	if (lc > 0) snd_sc(lc);		/* 'lc' is leading character */
	else if (lc < 0) fw = -lc;	/* 'lc' is field width */
	if (i < 0) i = -i, sn = '-';	/* sign */
	do b[nd++] = (i%10) + '0'; while ((i /= 10));
	if (sn) b[nd++] = sn;
	for (sn = nd; sn < fw; sn++) snd_sc(' ');
	do snd_sc(b[--nd]); while (nd);
}

void snd_spd(u08_t fw, u08_t pr, long i) /* pseudo decimal */
{
	u08_t	nd, sn, b[20];

	if (pr > 16) pr = 16;
	sn = nd = 0;
	if (i < 0) i = -i, sn = '-';
	do {
		b[nd++] = (i%10) + '0';
		if (nd == pr) b[nd++] = '.';
	}
	while ((i /= 10) || nd < pr);
	if (pr && (nd - pr) == 1) b[nd++] = '0';
	if (sn) b[nd++] = '-';
	while (nd < fw) fw--, snd_sc(' ');
	do snd_sc(b[--nd]); while (nd);
}

void snd_sp(const char *p) /* string from flash */
{
	char	c;

	while ((c = pgm_read_byte(p++))) snd_sc(c);
}

#define	SND_SP(str)	snd_sp(PSTR(str))

/*
 * 'soft' serial port for GPS
 */
ISR(TIMER0_COMPA_vect)
{
	u08_t	i;

	/* transmit bit interrupt */
	if (gl.gps.txm == 0) {
		if (GPS_TXO_VAL()) { /* was stop bit or pause */
			if (gl.gps.txr != gl.gps.txw) {
				gl.gps.txd = gl.gps.txb[i = gl.gps.txr];
				gl.gps.txr = ++i >= NEL(gl.gps.txb) ? 0 : i;
				GPS_TXO_CLR();	/* send start bit */
			}
			else {
				TIMSK0 &= ~_BV(OCIE0A);	/* compa interrupt OFF */
				gl.gps.txe = 1;
			}
		}
		else { /* was start bit */
			gl.gps.txm = 1;
			if (gl.gps.txd & 01) GPS_TXO_SET();
		}
	}
	else {
		gl.gps.txe = 0;
		gl.gps.txm <<= 1;
		if (gl.gps.txm == 0 || (gl.gps.txd & gl.gps.txm))
			GPS_TXO_SET();
		else	GPS_TXO_CLR();
	}
}

ISR(TIMER0_COMPB_vect)
{
	u08_t	i;

	/* receive bit interrupt */
	i = GPS_RXI_INPUT();
	if (gl.gps.rxm == 0xff) { /* start bit */
		if (i == 0) {
			gl.gps.rxd = 0;
			gl.gps.rxm = 1;
		}
	}
	else {
		if (i) gl.gps.rxd |= gl.gps.rxm;
		if (gl.gps.rxm) gl.gps.rxm <<= 1;	/* more bits to sample */
		else {					/* just sampled stop bit */
			TIMSK0 &= ~_BV(OCIE0B);		/* compb interrupt OFF */
			if (i) {			/* stop bit is valid */
				gl.gps.rxb[i = gl.gps.rxw] = gl.gps.rxd;
				if (++i >= NEL(gl.gps.rxb)) i = 0;
				if (i != gl.gps.rxr) gl.gps.rxw = i;
				gl.gps.rxi |= GPS_RXI;
			}
			GPS_RXI_IRQON();
			gl.gps.lstp = TCNT1;
		}
	}
}

ISR(GPS_RXI_VECT)
{
	u08_t	rxi, tmp;

	rxi = GPS_RXI_INPUT();		/* sample input */
	tmp = rxi ^ gl.gps.rxi;		/* compare to last sample */
	gl.gps.rxi = rxi;		/* save input */
	if (gl.gps.tcnt == 0) {		/* sample timer for figuring out baudrate */
		if (gl.gps.rxw < NEL(gl.gps.rxt)) {
			itic((u16_t *)&gl.gps.rxt[gl.gps.rxw]);
			gl.gps.rxw++;
		}
	}
	else if (tmp && rxi == 0) {	/* it changed and is 0 now -> received start bit */
		tmp = TCNT0;
		tmp += gl.gps.thbt;
		if (tmp == gl.gps.tcnt) tmp++;
		if (tmp > gl.gps.tcnt) tmp -= gl.gps.tcnt;
		if (tmp < 1) tmp++;
		OCR0B = tmp;		/* set sampling point */
		TIFR0  |= _BV(OCF0B);	/* clear in case it is set */
		TIMSK0 |= _BV(OCIE0B);	/* compB interrupt ON */
		GPS_RXI_IRQOF();
		gl.gps.rxm = 0xff;	/* tell timer irq COMPB, next sample is start bit */
	}
}

void gps_sc(char c) /* send character */
{
	u08_t	i;

	gl.gps.txb[i = gl.gps.txw] = c;
	if (++i >= NEL(gl.gps.txb)) i = 0;
	if (i == gl.gps.txr) return;
	gl.gps.txw = i;
	if (TIMSK0 & _BV(OCIE0A)) return;
	TIFR0  |= _BV(OCF0A);		/* clear compa flag */
	TIMSK0 |= _BV(OCIE0A);		/* compa interrupt ON */
}

void gps_snx(u08_t n) { if ((n &= 0x0f) <= 9) gps_sc('0'+n); else gps_sc('A'-10+n); }

void nmea_snd(const char *p)
{
	u08_t	b, cks;

	gps_sc('$');
	for (cks = 0; (b = pgm_read_byte(p)); p++) cks ^= b, gps_sc(b);
	gps_sc('*');
	gps_snx(cks>>4); gps_snx(cks>>0);
	gps_sc('\r'); gps_sc('\n');
}

#define	NMEA_SND(str)	nmea_snd(PSTR(str))

void gps_bdt(void)
{
	int	b;
	u08_t	i;

	/* figure out baudrate from single bit timing, 4800...57600 is MAX! */
	if (gl.gps.rxw == NEL(gl.gps.rxt)) {
		b = 1000;
		for (i = NEL(gl.gps.rxt); --i > 5; ) { /* ignore first couple of samples */
			gl.gps.rxt[i] -= gl.gps.rxt[i-1];
			if (gl.gps.rxt[i] < b) b = gl.gps.rxt[i];
		}
		     if (b >= (int)MS2TIC(0.016) && b <= (int)MS2TIC(0.018)) b = 576;
		else if (b >= (int)MS2TIC(0.025) && b <= (int)MS2TIC(0.027)) b = 384;
		else if (b >= (int)MS2TIC(0.051) && b <= (int)MS2TIC(0.053)) b = 192;
		else if (b >= (int)MS2TIC(0.103) && b <= (int)MS2TIC(0.106)) b =  96;
		else if (b >= (int)MS2TIC(0.205) && b <= (int)MS2TIC(0.210)) b =  48;
		else b = 0;
		tmr0_setup(b);
		gl.gps.cst = 0;
		gl.gps.b_r = gl.gps.b_w = 0;
	}
}

void gps_rcv(void)
{
	u08_t	c, i;

	if (gl.gps.tcnt == 0) {
		gps_bdt();
		return;
	}
	while (1) {
		if (CB_NO_D(gl.gps.rxr,gl.gps.rxw)) break;
		c = (int)gl.gps.rxb[i = gl.gps.rxr];
		gl.gps.rxr = ++i >= NEL(gl.gps.rxb) ? 0 : i;
		/* NMEA: $..........*hh\r\n */
		switch (gl.gps.cst) {
		default:
GPSDROP0:		gl.gps.ech = c;
			gl.gps.est = gl.gps.est ? 0x20 : 0x00;
			gl.gps.est |= gl.gps.cst;
			if (i == gl.gps.b_r) gl.gps.est |= 0x10; /* overflow */
GPSDROP1:		gl.gps.cst = 0;
			break;
		case 6: /* stays here until next '$' arrives */
		case 0: if (c != '$') break;
			gl.gps.cks = 0;
			i = gl.gps.b_s = gl.gps.b_w;
			gl.gps.buf[i] = c;
			if (++i >= NEL(gl.gps.buf)) i = 0;
			if (i == gl.gps.b_r) goto GPSDROP0;
			gl.gps.b_n = 1;
			gl.gps.b_s = i;
			gl.gps.cst = 1;
			break;
		case 1:
			gl.gps.buf[i = gl.gps.b_s] = c;
			if (++i >= NEL(gl.gps.buf)) i = 0;
			if (c < ' ' || c > '~' || i == gl.gps.b_r) goto GPSDROP0;
			if (gl.gps.b_n == 1 && c != 'G') goto GPSDROP1;
			if (gl.gps.b_n == 2 && c != 'P' && c != 'N') goto GPSDROP1;
			gl.gps.b_n++;
			gl.gps.b_s = i;
			if (c == '*') gl.gps.cst = 2;
			else gl.gps.cks ^= c;
			break;
		case 2: case 3:
			gl.gps.buf[i = gl.gps.b_s] = c;
			if (++i >= NEL(gl.gps.buf)) i = 0;
			     if (c >= '0' && c <= '9') c -= '0';
			else if (c >= 'A' && c <= 'F') c -= 'A'-10;
			if (c > 0x0f || i == gl.gps.b_r) goto GPSDROP0;
			gl.gps.b_n++;
			gl.gps.b_s = i;
			gl.gps.cst++;
			if (gl.gps.cst == 3) gl.gps.cks ^= c << 4;
			else if (gl.gps.cks != c) goto GPSDROP0;
			break;
		case 4:
			gl.gps.buf[i = gl.gps.b_s] = c;
			if (++i >= NEL(gl.gps.buf)) i = 0;
			if (c != '\r' || i == gl.gps.b_r) goto GPSDROP0;
			gl.gps.b_n++;
			gl.gps.b_s = i;
			gl.gps.cst = 5;
			break;
		case 5: if (c == '\n' && gl.gps.seq >= 10) gl.gps.b_w = gl.gps.b_s;
			gl.gps.cst = 6;
			break;
		}
	}
	if (gl.gps.cst !=  6) return;	/* message incomplete */
	if (gl.gps.seq >= 10) return;	/* setup done, good to go */
	gl.gps.b_r = gl.gps.b_w = 0;	/* kill received messages during setup */
	if (gl.gps.txr != gl.gps.txw || gl.gps.txe == 0) return; /* not done sending last cmd */
	if ((TCNT1 - gl.gps.lstp) < (u16_t)MS2TIC(10.0)) return; /* wait for gap in data stream */
	switch (gl.gps.seq) {
	case 0: /* check/set baudrate */
		if (gl.gps.b100 == 384)         gl.gps.seq = 2;
		else NMEA_SND("PMTK251,38400"), gl.gps.seq = 1;
		break;
	case 1: tmr0_setup(0);
		gl.gps.seq = 2;
		break;
	/* get RMC,GGA sentences only */
	case 2: NMEA_SND("PMTK314,0,5,0,1,0,0,0,0"); gl.gps.seq = 3; break;
	/* set rate to 200ms, 5Hz */
	case 3: NMEA_SND("PMTK220,200");             gl.gps.seq = 4; break;
	/* done */
	case 4: gl.gps.seq = 10; break;
	}
}

/*
 * RC receiver
 */
#define	PTMAX	MS2TIC(2.05)	/* pulse should be shorter than that */
#define	PTMIN	MS2TIC(0.95)	/* pulse should be longer than that */
#define	PTREF	MS2TIC(1.50)	/* nominal center position */
#define	PTRNG	MS2TIC(0.40)	/* +- nominal spread */

#define	FTMIN	MS2TIC( 8.0)	/* min frametime */
#define	FTMAX	MS2TIC(35.0)	/* max frametime */
#define	FTTOT	MS2TIC(250.0)	/* max frame time out */

ISR(RXSIG_VECT) /* RX signal change interrupt */
{
	union { rsm_t *r; u08_t *b; } p;
	u08_t	i;

	p.r = gl.rxs.rsb;
	i = gl.rxs.rsw;
	p.b += i * sizeof(*p.r);
	p.r->smp = RXSIG;
	itic((u16_t *)&p.r->tmr);
	if (++i >= NEL(gl.rxs.rsb)) i = 0;
	if (i != gl.rxs.rsr) gl.rxs.rsw = i;
#if	RX_CON == 3
#if	0
	static u08_t	fst;
	static u32_t	ltd;
	/* hardware DEBUG, serial RX, frame start is the first down transition after a pause */
	if ((i = (p.r->smp & RXMSK) ? 1 : 0) == 0 && fst) {
		if ((p.r->tmr - ltd) > MS2TIC(3.00)) VLBTG(); /* use VLBA output as scope trigger signal */
		ltd = p.r->tmr;
	}
	fst = i;
#endif
#endif
}

void rx_proc(void)
{
	u32_t	tmr, dtm;
	u08_t	k, i, smp, chg, lsm;

	smp = SREG; cli(); i = gl.rxs.rsw; SREG = smp;
	k = CB_FILL(gl.rxs.rsr,i,NEL(gl.rxs.rsb));
	lsm = gl.rxs.smp;
	while (k) {
		k--;
		i = gl.rxs.rsr;
		smp = gl.rxs.rsb[i].smp;
		tmr = gl.rxs.rsb[i].tmr;
		gl.rxs.rsr = ++i >= NEL(gl.rxs.rsb) ? 0 : i;
		chg = (smp ^ lsm);
		lsm = smp;
#if	RX_CON == 3
		if ((chg & RXMSK) && (smp & RXMSK) == 0) { /* down transition on PPM input */
			dtm = tmr - gl.rxs.srx.ptd;
			gl.rxs.srx.ptd = tmr;
			if (dtm > MS2TIC(3.00)) { /* frame start */
				gl.rxs.srx.idx = 0;
				gl.rxs.ftm = tmr - gl.rxs.lfs;
				gl.rxs.lfs = tmr;
			}
			else if ((i = gl.rxs.srx.idx) < NEL(gl.rxs.chn)) {
				gl.rxs.chn[i].tac = tmr;
				gl.rxs.chn[i].dur = dtm;
				gl.rxs.srx.idx++;
			}
		}
#else
		for (i = 0; (chg & RXMSK) && i < NEL(gl.rxs.chn); i++)
			if (chg & gl.rxs.chn[i].msk) {
				dtm = tmr - gl.rxs.chn[i].tac;
				if (smp & gl.rxs.chn[i].msk) {
					gl.rxs.chn[i].tac = tmr;
					if (i == S_AILE) { /* AILE is usually the first pulse */
						gl.rxs.ftm = tmr - gl.rxs.lfs;
						gl.rxs.lfs = tmr;
					}
				}
				else gl.rxs.chn[i].dur = dtm;
				chg &= ~gl.rxs.chn[i].msk;
			}
#endif
	}
	gl.rxs.smp = lsm;
}

int rx_tk2v(int dur, int dbn)
{
	int	val;

	dur -= PTREF;
	if (dur >= 0) { if ((dur -= dbn) <= 0) return 0; }
	else          { if ((dur += dbn) >= 0) return 0; }
	val = (int)((long)(dur * 1000L + PTRNG/2)/(long)(PTRNG - dbn));
	val = val < -1000 ? -1000 : val > 1000 ? 1000 : val;
	return val;
}

u08_t rx_esel(int thr)
{
	int	v, h;
	u08_t	isp;

	isp = 0;
	if ((v = gl.rxs.chn[ S_ELEV].val) < 0) v *= -1; else isp |= 01;
	if ((h = gl.rxs.chn[SH_ELEV].val) < 0) h *= -1; else isp |= 02;
	if (v < thr && h < thr) return 0;
	return v >= h ? (isp & 01) ? 1 : 3 : (isp & 02) ? 4 : 2;
}

u08_t rx_read(void)
{
	u08_t	err, mch;
	u32_t	tot;
	int	val;
	struct chn *c;

	if (CB_HASD(gl.rxs.rsr,gl.rxs.rsw)) rx_proc();
	err = 0;
	tot = tic();
	if (gl.rxs.ftm < FTMIN || gl.rxs.ftm > FTMAX) err = S_SIG;
	else {
		mch = _BV(NEL(gl.rxs.chn)-1);
		for (c = gl.rxs.chn + NEL(gl.rxs.chn); --c >= gl.rxs.chn; mch >>= 1)
			if (!(mch & S_SIG)) continue;	/* bit/channel is not used */
			else if ((tot - c->tac) > FTTOT) err |= mch;
			else if (c->dur < PTMIN || c->dur > PTMAX) err |= mch;
			else c->val = rx_tk2v(c->dur,c->dbn);
	}

	if ((gl.rxs.err = err)) { /* there is a problem with one or more RX signals */
		if (gl.rxs.erx < S2LTIC(0.5)) {
			/* delay error reporting */
			gl.rxs.erx++;
			return 0;
		}
		if (err == S_SIG) gl.rxs.ftm = 0;
		for (c = gl.rxs.chn + NEL(gl.rxs.chn); --c >= gl.rxs.chn; ) c->val = 0;
		return err;
	}
	/* all RX signals ok */
	gl.rxs.erx = 0;

	if (1) gl.rxs.chn[S_AUX1].val *= -1;	/* legacy, can be done in TX */

	val = gl.rxs.chn[S_LAND].val;
	switch (S_LAND) {
	case S_GEAR: gl.rxs.fms =       val < 0 ? FMS_LAND : FMS_FM_1; break;
	case S_AUX1: gl.rxs.fms = val ? val < 0 ? FMS_LAND : FMS_FM_2 : FMS_FM_1; break;
	}
	if (S_FMOD != S_LAND && gl.rxs.fms != FMS_LAND) /* 2 switches and in the air */
		gl.rxs.fms = gl.rxs.chn[S_FMOD].val < 0 ? FMS_FM_1 : FMS_FM_2;

	/* extended flightmode sequencer */
	switch (gl.rxs.fsq) {
	default: gl.rxs.fsq = 0; break;
	case 0: if (gl.rxs.fms == FMS_FM_2) gl.rxs.fsq = 1; break;
	case 1: if (gl.rxs.fms == FMS_LAND) gl.rxs.fsq = 0;
		else if (gl.rxs.fms == FMS_FM_1) {
			/* switch to FM_1, arms trigger mechanism */
			gl.rxs.fst = S2LTIC(0.5);
			gl.rxs.fsq = 2;
			gl.rxs.fms = FMS_FM_2;
		}
		break;
	case 2: gl.rxs.fsq = 0;
		if ((gl.rxs.fst -= 1) == 0) break; /* timeout */
		if (gl.rxs.fms == FMS_LAND) break; /* land */
		if (gl.rxs.fms == FMS_FM_1) {
			/* keep FM_2 during timeout period */
			gl.rxs.fsq = 2;
			gl.rxs.fms = FMS_FM_2;
			break;
		}
		if (gl.rxs.fms != FMS_FM_2) break;
		/* user switched back to FM_2 before timeout */
		gl.rxs.fst = S2LTIC(0.40);	/* animation trigger window */
		gl.rxs.fsq = 3;
		break;
	case 3: if (gl.rxs.fms != FMS_FM_2) { /* switch changed */
			gl.rxs.fsq = 0;
			break;
		}
		if ((gl.rxs.fst -= 1) == 0) { /* enter FM_3 */
			gl.rxs.fms = FMS_FM_3;
			gl.rxs.fsq = 5;
			break;
		}
		if ((mch = rx_esel(100)) == 0) break;
		/* trigger animation */
		gl.rxs.fst = S2LTIC(0.5);
		gl.rxs.fsa = mch;
		gl.rxs.fsq = 4;
		break;
	case 4: if ((gl.rxs.fst -= 1) == 0 || gl.rxs.fsa == 0)
			gl.rxs.fsq = gl.rxs.fsa = 0;
		break;
	case 5: gl.rxs.fsq = 0;
		if (gl.rxs.fms != FMS_FM_2) break;	/* switch changed */
		if (rx_esel(150)) break;		/* stick moved */
		gl.rxs.fsq = 5;
		gl.rxs.fms = FMS_FM_3;
		break;
	}

#if	GSWO_ENA >= 0 && GSWO_SRC == 0
	if (gl.rxs.chn[S_GEAR].val <= 0) GSWOF(); else GSWON();
#endif

	if (gl.rxs.fms == FMS_LAND) {
		mch = 0;
		val = gl.rxs.chn[ S_THRO].val; if (ABS(val) > STKTHR) mch |= val < 0 ? TS_DN : TS_UP;
		val = gl.rxs.chn[SH_THRO].val; if (ABS(val) > STKTHR) mch |= val < 0 ? TS_LF : TS_RT;
		val = gl.rxs.chn[ S_ELEV].val; if (ABS(val) > STKTHR) mch |= val < 0 ? ES_UP : ES_DN;
		val = gl.rxs.chn[SH_ELEV].val; if (ABS(val) > STKTHR) mch |= val < 0 ? ES_LF : ES_RT;
		gl.rxs.stk = mch;
		/* alternate configuration selection */
		if ((gl.rxs.stk & TS_MSK) == TS_UP)
			gl.cfw = (char)rx_esel(STKTHR) - 1;
		else {
			if (gl.cfw >= 0 && gl.cfg != gl.cfw && gl.eewen >= NEL(gl.eedat)) {
				gl.cfg = gl.cfw;
				eepr_save();
			}
			gl.cfw = -1;
		}
#if	GSWO_ENA >= 0 && GSWO_SRC == 1
		if ((gl.rxs.stk & TS_MSK) == (TS_UP|TS_LF) && gl.beep.nbp == 0) gl.beep.nbp = 5;
#endif
	}
	else {
		gl.rxs.stk = 0;
		gl.cfw = -1;
	}
	return 0;
}

/*
 * messages from drone
 */
#define	C_ACK	0x01
void sio_rcv(void)
{
	int	r;
	char	c;

	while ((r = sio_rc()) >= 0)
		if ((c = r) <= 0) gl.drm.cst = 0;
		else if (c == C_ACK) gl.drm.ack = 1, gl.drm.cst = 0;
		else switch (gl.drm.cst) {
		case 0: if (c == '$') gl.drm.cst = 1, gl.drm.nda = 0; break;
		case 1: if (c == '*') {
				if (gl.drm.nda == sizeof(gl.drm.dat.m2a)) {
#if GSWO_ENA >= 0 && GSWO_SRC == 1
					if (gl.drm.dat.m2a.beep > 0 && gl.beep.nbp == 0)
						gl.beep.nbp = gl.drm.dat.m2a.beep;
#endif
					gl.drm.m2a = gl.drm.dat.m2a;
				}
				gl.drm.cst = 0;
				break;
			}
			/* FALLTHROUGH */
		case 2: if (c >= '0' && c <= '9') c -= '0';
			else if (c >= 'A' && c <= 'F') c -= 'A'-10;
			else if (c >= 'a' && c <= 'f') c -= 'a'-10;
			else c = -1;
			if (c < 0 || gl.drm.nda >= sizeof(gl.drm.dat)) {
				gl.drm.cst = 0;
				break;
			}
			if (gl.drm.cst == 1)
				gl.drm.dat.b[gl.drm.nda] = (c<<4);
			else	gl.drm.dat.b[gl.drm.nda++] |= c;
			gl.drm.cst ^= 3;
			break;
		}
}

#if	U4
#undef	usb_sq
/*
 * MiruPCB USB interface
 */
typedef struct { /* Standard Device Descriptor */
	u08_t	bLength;
	u08_t	bDescriptorType;
	u16_t	bcdUSB;
	u08_t	bDeviceClass;
	u08_t	bDeviceSubClass;
	u08_t	bDeviceProtocol;
	u08_t	bMaxPacketSize0;
	u16_t	idVendor;
	u16_t	idProduct;
	u16_t	bcdDevice;
	u08_t	iManufacturer;
	u08_t	iProduct;
	u08_t	iSerialNumber;
	u08_t	bNumConfigurations;
}	usb_sdd_t; /* 18 bytes */

typedef struct { /* Standard Configuration Descriptor */
	u08_t	bLength;
	u08_t	bDescriptorType;
	u16_t	wTotalLength;
	u08_t	bNumInterfaces;
	u08_t	bConfigurationValue;
	u08_t	iConfiguration;
	u08_t	bmAttributes;
	u08_t	bMaxPower;	/* in 2mA units, 50 ^ 100mA */
}	usb_scd_t; /* 9 bytes */

typedef struct { /* Standard Interface Descriptor */
	u08_t	bLength;
	u08_t	bDescriptorType;
	u08_t	bInterfaceNumber;
	u08_t	bAlternateSetting;
	u08_t	bNumEndPoints;
	u08_t	bInterfaceClass;
	u08_t	bInterfaceSubClass;
	u08_t	bInterfaceProtocol;
	u08_t	iInterface;
}	usb_sid_t; /* 9 bytes */

typedef struct { /* Standard Endpoint Descriptor */
	u08_t	bLength;
	u08_t	bDescriptorType;
	u08_t	bEndPointAddress;
	u08_t	bmAttributes;
	u16_t	wMaxPacketSize;
	u08_t	bInterval;
}	usb_sep_t; /* 7 bytes */

#define DSC_DEV	1	// DEVICE
#define DSC_CFG	2	// CONFIGURATION
#define DSC_STR	3	// STRING
#define DSC_IFC	4	// INTERFACE
#define DSC_EPT	5	// ENDPOINT
#define DSC_DQU	6	// DEVICE_QUALIFIER
#define DSC_OSC	7	// OTHER_SPEED_CONFIGURATION
#define DSC_PWR	8	// INTERFACE_POWER

const usb_sdd_t usb_sdd PROGMEM = {
 .bLength = sizeof(usb_sdd_t), .bDescriptorType = DSC_DEV, .bcdUSB = 0x0200,
 .bDeviceClass       = 0,
 .bDeviceSubClass    = 0,
 .bDeviceProtocol    = 0,
 .bMaxPacketSize0    = 64,
 .idVendor           = 0x0403, /* FTDI */
 .idProduct          = 0x6001, /* FT232 USB-Serial (UART) IC */
 .bcdDevice          = 0x0600,
 .iManufacturer      = 0,
 .iProduct           = 0,
 .iSerialNumber      = 0,
 .bNumConfigurations = 1,
};

#define	EP1_LGS		3	/* endpoint size (0 == 8, 1 == 16, 2 == 32 ... 6 == 512) */
#define	EP2_LGS		3	/* endpoint size (0 == 8, 1 == 16, 2 == 32 ... 6 == 512) */
const struct {
	usb_scd_t	scd;	/* 9 bytes */
	usb_sid_t	sid;	/* 9 bytes */
	usb_sep_t	ept[2];	/* 7 bytes each */
}	usb_cfg PROGMEM = {
 .scd.bLength = sizeof(usb_scd_t), .scd.bDescriptorType = DSC_CFG,
 .scd.wTotalLength        = sizeof(usb_scd_t) + sizeof(usb_sid_t) + 2*sizeof(usb_sep_t),
 .scd.bNumInterfaces      = 1,
 .scd.bConfigurationValue = 1,
 .scd.iConfiguration      = 0,
 .scd.bmAttributes        = 0xa0,
 .scd.bMaxPower           = 100/2,

 .sid.bLength = sizeof(usb_sid_t), .sid.bDescriptorType = DSC_IFC,
 .sid.bInterfaceNumber    = 0,
 .sid.bAlternateSetting   = 0,
 .sid.bNumEndPoints       = 2,
 .sid.bInterfaceClass     = 0xff, /* vendor specific */
 .sid.bInterfaceSubClass  = 0xff,
 .sid.bInterfaceProtocol  = 0xff,
 .sid.iInterface          = 2,

 .ept[0].bLength = sizeof(usb_sep_t), .ept[0].bDescriptorType = DSC_EPT,
 .ept[0].bEndPointAddress = 0x81, /* EP 1 IN dev->host */
 .ept[0].bmAttributes     = 0x02, /* BULK */
 .ept[0].wMaxPacketSize   = (8<<EP1_LGS),
 .ept[0].bInterval        = 0,

 .ept[1].bLength = sizeof(usb_sep_t), .ept[1].bDescriptorType = DSC_EPT,
 .ept[1].bEndPointAddress = 0x02, /* EP 2 OUT dev<-host */
 .ept[1].bmAttributes     = 0x02, /* BULK */
 .ept[1].wMaxPacketSize   = (8<<EP2_LGS),
 .ept[1].bInterval        = 0,
};

u08_t usb_tf(void) /* txb free space */
{
	return CB_FREE(gl.usb.ep1r,gl.usb.ep1w,NEL(gl.usb.ep1b));
}

void usb_sc(char c)
{
	u08_t	i;

	gl.usb.ep1b[i = gl.usb.ep1w] = c;
	if (++i >= NEL(gl.usb.ep1b)) i = 0;
	if (i != gl.usb.ep1r) gl.usb.ep1w = i;
}

void usb_sp(const char *p) /* send string from flash */
{
	char	c;

	while ((c = pgm_read_byte(p++))) usb_sc(c);
}

#define	USB_SP(str)	usb_sp(PSTR(str))

int usb_rc(void) /* read next character received */
{
	int	b;

	if (gl.usb.ep2r == 0) return -1;
	UENUM = 2;
	if (!(UEINTX & _BV(FIFOCON))) return -1;
	b = UEDATX;
	if (--gl.usb.ep2r == 0) UEINTX &= ~_BV(FIFOCON);
	return b;
}

ISR(USB_GEN_vect)
{
	u08_t	irq, ept;

	irq = UDINT;
	ept = UENUM;
	UDINT = 0b00000000;	/* -,uprsmi,eorsmi,wakeup,eorsti,sofi,-,suspi */
	irq &= UDIEN;
	if (irq & _BV(EORSTI)) {
		gl.usb.ep0a = 0;
		gl.usb.ep0r = 0;
		gl.usb.ep1w = 0;
		gl.usb.ep1r = 0;
		gl.usb.sofi = 0;
		gl.usb.ep1h = 1;
		gl.usb.mdst = RST_MDST;
		gl.usb.lnst = RST_LNST;
		UENUM   = 0;
		UECONX  = 0b00000001;	/* -,-,stallrq,stallqc,rstdt,-,-,EPEN */
		UECFG0X = 0b00000000;	/* ept1,ept0,-,-,-,-,-,epdir */
		UECFG1X = 0b00110010;	/* -,eps2,EPS1,EPS0,epbk1,epbk0,ALLOC,- 64 bytes */
		if (UESTA0X & _BV(CFGOK)) {
			UEIENX = _BV(RXSTPE);	/* enable IRQs for EP 0 */
			gl.usb.ep0a = 1;	/* enable usb_sq */
		}
	}
	if (irq & _BV(SOFI)) gl.usb.sofi++;
	UENUM = ept;
}

ISR(USB_COM_vect)
{
	u08_t	ept = UENUM;

	/* UEINTX: fifocon,nakini,rwal,nakouti,rxstpi,rxouti,stalledi,txini */
	if (UEINT & 01) { /* control endpoint */
		UENUM = 0;
		if ((UEINTX & _BV(RXSTPI))) {
			if (gl.usb.ep0r == 0)
				while (gl.usb.ep0r < 8) gl.usb.ep0b.b[gl.usb.ep0r++] = UEDATX;
			UEINTX = 0;
		}
	}
	if (UEINT & 02) { /* IN endpoint dev->host, outgoing data */
		UENUM = 1;
		if ((UEINTX & _BV(TXINI))) {
			gl.usb.ep1h = 0;
			UEINTX &= ~_BV(TXINI);
		}
	}
	if (UEINT & 04) { /* OUT endpoint dev<-host, incoming data */
		UENUM = 2;
		if ((UEINTX & _BV(RXOUTI))) {
			gl.usb.ep2r += UEBCX;
			UEINTX &= ~_BV(RXOUTI);
		}
	}
	UENUM = ept;
}

void usbd_psnd(const void *buf, u08_t nbu)
{
	const u08_t	*d = buf;
	u08_t		n;

	for (n = 0; n < nbu; n++) {
		while (!(UEINTX & (_BV(TXINI)|_BV(RXOUTI))));
		if (UEINTX & _BV(RXOUTI)) break;
		UEDATX = pgm_read_byte(d++);
	}
}

void usb_sq(void)
{
	u08_t	i;

	if (gl.usb.ep0a == 0) return;
	/*
	 * EP1, IN endpoint dev->host
	 */
	if (gl.usb.ep1h == 0 && (CB_HASD(gl.usb.ep1r,gl.usb.ep1w) || gl.usb.sofi >= 40)) {
		UENUM = 1;
		UEDATX = MDST(gl.usb.mdst);
		UEDATX = RUN_LNST;
		while ((UEINTX & _BV(RWAL))) {
			if (CB_NO_D(gl.usb.ep1r,gl.usb.ep1w)) break;
			UEDATX = gl.usb.ep1b[i = gl.usb.ep1r];
			gl.usb.ep1r = ++i >= NEL(gl.usb.ep1b) ? 0 : i;
		}
		gl.usb.sofi = 0;
		gl.usb.ep1h = 1;
		UEINTX &= ~_BV(FIFOCON);
	}
	/*
	 * control endpoint
	 */
	if (gl.usb.ep0r == 0) return;
	i = SREG; cli();
	UENUM = 0;
	if (gl.usb.ep0b.bmRequestType & REQ_D2H)
		while (!(UEINTX & _BV(TXINI)));
	else	UEINTX = ~_BV(TXINI);
	switch ((gl.usb.ep0b.bmRequestType & REQ_TYP)) {
	case REQ_STD:
		switch (gl.usb.ep0b.bRequest) {
		case GET_STATUS:
			UEDATX = 0;
			UEDATX = 0;
			UEINTX &= ~_BV(TXINI);
			break;
		case SET_ADR:
			while (!(UEINTX & _BV(TXINI)));
			UDADDR = gl.usb.ep0b.wValue;
			UEINTX &= ~_BV(TXINI);
			UDADDR |= _BV(ADDEN);
			break;
		case GET_DSC:
			switch (gl.usb.ep0b.wValue>>8) {
			case DSC_DEV: /* 1 USB_DEVICE_DESCRIPTOR_TYPE */
				usbd_psnd(&usb_sdd,MIN(gl.usb.ep0b.wLength,sizeof(usb_sdd)));
				UEINTX &= ~_BV(TXINI);
				break;
			case DSC_CFG: /* 2 USB_CONFIGURATION_DESCRIPTOR_TYPE */
				usbd_psnd(&usb_cfg,MIN(gl.usb.ep0b.wLength,sizeof(usb_cfg)));
				UEINTX &= ~_BV(TXINI);
				break;
#if	0
			case DSC_STR: /* 3 USB_STRING_DESCRIPTOR_TYPE */
			case DSC_IFC: /* 4 USB_INTERFACE_DESCRIPTOR_TYPE */
			case DSC_EPT: /* 5 USB_ENDPOINT_DESCRIPTOR_TYPE */
			case DSC_DQU: /* 6 USB_DEVICE_QUALIFIER_TYPE */
			case DSC_OSC: /* 7 USB_OTHER_SPEED_CONFIGURATION_TYPE */
			case DSC_PWR: /* 8 USB_INTERFACE_POWER_TYPE */
#endif
			default: UECONX |= _BV(STALLRQ); break;
			}
			break;
		case GET_CFG:
			UEDATX = 1;
			UEINTX &= ~_BV(TXINI);
			break;
		case SET_CFG:
			switch ((gl.usb.ep0b.bmRequestType & REQ_DST)) {
			case REQ_DEV:
				UENUM   = 1;	/* IN DEV -> HOST */
				UECONX  = 1;
				UECFG0X = 0b10000001; /* ept[1:0],-,-,-,-,-,EPDIR  BULK IN */
				UECFG1X = (EP1_LGS<<4)|0b0110; /* -,epsize[2:0]=010,epbk[1:0]=01,ALLOC,- double */
				UEIENX  = 0b00000001; /* flerre,nakine,-,nakoute,rxstpe,rxoute,stallede,TXINE */
				UENUM   = 2;	/* OUT HOST -> DEV */
				UECONX  = 1;
				UECFG0X = 0b10000000; /* ept[1:0],-,-,-,-,-,epdir  BULK OUT */
				UECFG1X = (EP2_LGS<<4)|0b0110; /* -,epsize[2:0]=010,epbk[1:0]=01,ALLOC,- double */
				UEIENX  = 0b00000100; /* flerre,nakine,-,nakoute,rxstpe,RXOUTE,stallede,txine */
				break;
//			case REQ_IFC:
//			case REQ_EPT:
//			default:
//				break;
			}
			break;
		default: UECONX |= _BV(STALLRQ); break;
		}
		break;
	case REQ_VEN:
		switch (gl.usb.ep0b.bRequest) {
		case  0: /* FTDI_SIO_RESET		 0 reset port */
			gl.usb.mdst = RST_MDST;
			gl.usb.lnst = RST_LNST;
			gl.usb.tlat = 0;
			UEINTX &= ~_BV(TXINI);
			break;
		case  1: /* FTDI_SIO_MODEM_CTRL		 1 set modem control register */
#if	0
			if (gl.usb.ep0b.wValue & 0x0200) {
				if (gl.usb.ep0b.wValue & 0x02)
					gl.usb.mdst |=  MDST_RTS;
				else	gl.usb.mdst &= ~MDST_RTS;
			}
#endif
			if (gl.usb.ep0b.wValue & 0x0100) {
				while (1) {
					/* raising DTR at 1200 baud, 8 bits means RESET */
					if (!(gl.usb.mdst & MDST_DTR)) break;
					if (gl.usb.ep0b.wValue & 0x01) break;
					if (gl.usb.baud != 0x09c4) break; /* 0x09c4 is 1200 baud */
					if (gl.usb.sfmt != 0x0008) break; /* should be on 8 bits/char */
					gl.exit = 1;
					break;
				}
				if (gl.usb.ep0b.wValue & 0x01)
					gl.usb.mdst |=  MDST_DTR;
				else	gl.usb.mdst &= ~MDST_DTR;
			}
			UEINTX &= ~_BV(TXINI);
			break;
		case  3: /* FTDI_SIO_SET_BAUD_RATE	 3 set baud rate */
			gl.usb.baud = gl.usb.ep0b.wValue;
			UEINTX &= ~_BV(TXINI);
			break;
		case  4: /* FTDI_SIO_SET_DATA		 4 set data format */
			gl.usb.sfmt = gl.usb.ep0b.wValue;
			UEINTX &= ~_BV(TXINI);
			break;
		case  5: /* FTDI_SIO_GET_MODEM_STATUS	 5 get modem status register */
			if (gl.usb.ep0b.wLength > 0) UEDATX = MDST(gl.usb.mdst);
			if (gl.usb.ep0b.wLength > 1) UEDATX = RUN_LNST;
			/* FALLTHROUGH */
		case  2: /* FTDI_SIO_SET_FLOW_CTRL	 2 set flow control register */
		case  6: /* FTDI_SIO_SET_EVENT_CHAR	 6 set event character */
		case  7: /* FTDI_SIO_SET_ERROR_CHAR	 7 set error character */
			UEINTX &= ~_BV(TXINI);
			break;
		case  9: /* FTDI_SIO_SET_LATENCY_TIMER	 9 set latency timer */
			gl.usb.tlat = gl.usb.ep0b.wValue;
			UEINTX &= ~_BV(TXINI);
			break;
		case 10: /* FTDI_SIO_GET_LATENCY_TIMER	10 get latency timer */
			if (gl.usb.ep0b.wLength > 0) UEDATX = (gl.usb.tlat>>0);
			if (gl.usb.ep0b.wLength > 1) UEDATX = (gl.usb.tlat>>8);
			UEINTX &= ~_BV(TXINI);
			break;
		default: UECONX |= _BV(STALLRQ); break;
		}
		break;
	default:
		UECONX |= _BV(STALLRQ);
		break;
	}
	gl.usb.ep0r = 0;
	SREG = i;
}

void usb_tw(void) /* wait for tx empty */
{
	do usb_sq(); while (gl.usb.sofi < 100 && CB_HASD(gl.usb.ep1r,gl.usb.ep1w));
}

void usb_init(void)
{
	u08_t	sreg;

	sreg = SREG; cli();
	USBCON = 0b00000000;	/* usbe,-,frzclk,otgpade,-,-,-,vbuste */
	UHWCON = 0b00000001;	/* -,-,-,-,-,-,-,UVREGE */
	USBCON = 0b10100000;	/* USBE,-,FRZCLK,otgpade,-,-,-,vbuste */
	PLLCSR = 0b00010010;	/* -,-,-,PINDIV,-,-,PLLE,plock */
	while (!(PLLCSR & _BV(PLOCK)));
	UDINT  = 0b00000000;	/* -,uprsme,eorsme,wakeupe,eorste,sofe,-,suspe */
	USBCON = 0b10010000;	/* USBE,-,frzclk,OTGPADE,-,-,-,vbuste */
	UDIEN  = 0b00001100;	/* -,uprsme,eorsme,wakeupe,EORSTE,SOFE,-,suspe */
	UDCON  = 0b00000000;	/* -,-,-,-,rstcpu,lsm,rmwkup,detach */
	SREG = sreg;
}
#endif

#if	AT2SO == 1
/*
 * drone companion program piggy back in flash
 */
void at2so_chck(void)
{
	u16_t	adr, mag, siz, cks;
	extern const u08_t at2so_buf[];

	adr = (u16_t)at2so_buf;
	mag = pgm_read_word(adr); adr += 2;
	siz = pgm_read_word(adr); adr += 2;
	cks = pgm_read_word(adr); adr += 2;
	if (mag != 0x55aa) return;
	if (siz < ( 1*1024)) return;
	if (siz > (20*1024)) return;
	gl.arm.adr = adr;
	gl.arm.siz = siz;
	gl.arm.cks = cks;
}

int at2so_load(void)
{
	union { u16_t w; u08_t b[2]; } v;
	u16_t	cks, adr;
	int	n;

	/* put tty we are talking to into raw mode, will be
	 * sending binary data -> NO interpretation please! */
	SIO_SP("stty -echo -iexten pass8 raw\n");
	ms_dly(50); sio_rf();
	/* 'dd' is the program of choice to receive the data, need to
	 * tell it how much is coming, so it quits after the transfer.
	 * 'dd' on drone is the 'amputated' version without bells and
	 * whistles. */
	SIO_SP("dd of=/tmp/$F.gz bs=1 count=");
	snd_sid(0,gl.arm.siz);
	sio_sc('\n');
	ms_dly(100); sio_rf();
	for (adr = gl.arm.adr, n = cks = 0;;) {
		v.w = pgm_read_word(adr+n); /* reads 2 bytes from flash */
		sio_sc(v.b[0]); cks += v.b[0];
		if (++n >= gl.arm.siz) break;
		sio_sc(v.b[1]); cks += v.b[1];
		if (++n >= gl.arm.siz) break;
		if ((n & 0x1f) == 0) {
			LEDTG(); /* makes LED look like it is dimmed */
			while (CB_HASD(gl.sio.txr,gl.sio.txw));
			ms_dly(1);
		}
	}
	ms_dly(50); sio_rf();
	/* put tty back to 'normal' */
	SIO_SP("stty sane\n"); ms_dly(50); sio_rf();
	if (n != gl.arm.siz || cks != gl.arm.cks) return 0; /* upload bad */
	/* unzip it */
	SIO_SP("gunzip /tmp/$F.gz\n"); ms_dly(100); sio_rf();
	ms_dly(50); sio_rf();
	return 1;
}
#endif

#define	C_STRT	0x02
#define	C_STOP	0x04

void at2so_lstp(u08_t n)
{
	while (1) {
		blip(1); ms_dly(1000);
		blip(n); ms_dly(2000);
	}
}

char sio_w4lf(int nms)
{
	int	k;

	for ( ; nms; nms -= 1, ms_dly(1))
		while ((k = sio_rc()) >= 0) if (k == '\n') return 0;
	return -1;
}

char sio_w4ln(int nms, u08_t *lbu, u08_t nlb)
{
	int	k;
	u08_t	i;

	for (i = 0; nms; nms -= 1, ms_dly(1))
		while ((k = sio_rc()) >= 0) {
			if (k == '\n') return (char)i;
			if (i < nlb) lbu[i++] = k;
		}
	return -1;
}

int at2so_txfr(const char *pnm)
{
	u08_t	lbu[4];

	sio_rf(); SIO_SP("F="); sio_sp(pnm); sio_rev(); SIO_SP(".arm\n");
	if (sio_w4lf(99)) return -1; /* communication bad */
	sio_rf(); SIO_SP("if [ -f $D/$F ];then cp $D/$F /tmp;echo 1;else echo 0;fi\n");
	if (sio_w4lf(99)) return -1; /* communication bad */
	return sio_w4ln(99,lbu,NEL(lbu)) < 1 ? -1 : lbu[0] == '1' ? 1 : 0;
}

int ld_comprgr(void)
{
	int	n;

	if ((n = at2so_txfr(PSTR("pilot")))) return n;
	if ((n = at2so_txfr(PSTR("at2so")))) return n;
	return 0;
}

void at2so_exec(u08_t blkwifi)
{
	int	n;

	/* change baudrate since Arduino at 16 Mhz has problems receiving back to
	 * back characters at 115200 with half speed receiver
	 * 76800 would be nice because it can do it, but stty on drone is amputated... */
	if ((SIO_UCSRA & _BV(SIO_U2X))) {
		/* is using double speed on serial transmitter, which is not good for
		 * receiver (half sampling rate) -> change baudrate to 38400 to fix this */
		SIO_SP("stty 38400\n");
		ms_dly(10); sio_rf();
		SIO_UBRR  = (F_CPU/(16UL*38400UL)-1);
		SIO_UCSRA = 0b00000000;	/* rxc0,txc0,udre0,fe0,dor0,upe0,u2x0,mpcm0 */
		ms_dly(50); sio_rf();
		SIO_UCSRB |= _BV(SIO_RXCIE)|_BV(SIO_RXEN)|_BV(SIO_TXEN);
		sio_sc('\r');		/* send a character at new baudrate */
		ms_dly(20); sio_rf();	/* wait a while and clear residuals if any */
	}
	sio_rf(); sio_sc('\n');
	if (sio_w4lf(99)) at2so_lstp(1);	/* communication bad */
	sio_rf(); SIO_SP("D=/data/video/usb\n");
	if (sio_w4lf(99)) at2so_lstp(2);	/* communication bad */
	if ((n = ld_comprgr()) < 0) at2so_lstp(3);
	else if (n == 0) {
		sio_rf(); SIO_SP("D=/data/video\n");
		if (sio_w4lf(99)) at2so_lstp(5);/* communication bad */
		if ((n = ld_comprgr()) < 0) at2so_lstp(6);
	}
#if	AT2SO == 1
	if (n == 0 && gl.arm.adr != 0) n = at2so_load();
#endif
	if (n == 0) at2so_lstp(8);		/* no companion program */

	LEDON();
	/* make companion program executable */
	SIO_SP("chmod +x /tmp/$F\n"); ms_dly(50); sio_rf();
	/* launch compagnion program */
	SIO_SP("/tmp/$F");
	if (blkwifi) SIO_SP(" -w");
	SIO_SP(" -l ");	gl.bid++; snd_sid(0,gl.bid); /* boot id */
	ms_dly(25); sio_rf();	/* wait out echo */
	sio_sc('\n');		/* and launch */

	/* wait for companion program to send start character */
	while (1) {
		if ((n = sio_rc()) < 0) ms_dly(1);
		else if (n == C_STRT) break;
		while (n == C_STOP) at2so_lstp(9); /* there is another controller active */
	}
	eepr_save();	/* store new 'bid' in EEPROM */
}

/*
 * RC receiver interface debug/setup loop
 */
void csisclr(void)  { SND_SP("\033[H\033[0m\033[2J"); }	/* home, clear attributes, clear screen */
void csirclr(void)  { SND_SP("\033[0J"); }
void csilclr(void)  { SND_SP("\033[K"); }
void csirow(int  r) { SND_SP("\033["); snd_sid(0,r); SND_SP(";1H"); }
void csilco(char c) { SND_SP("\033[0;"); snd_sbx(0x30+c); snd_sc('m'); }
void csihco(char c) { SND_SP("\033[1;"); snd_sbx(0x30+c); snd_sc('m'); }

#define	DLN0	1
#define	DLN1	2
#define	DLN2	3
#define	DLN3	4
#define	DLNRXI	6
#define	DLNRXC	7
#define	DLNGGA	14
#define	DLNRMC	15
#define	DLNOTH	16
#define	DLNBMPD	18  /* BMP data */
#define	DLNBMPC	19  /* BMP calibration */
#define	DLNHMCD	20  /* HMC data */
#define	DLNHMCC	21  /* HMC calibration */

#define	BLACK	0
#define	RED	1
#define	GREEN	2
#define	YELLOW	3
#define	BLUE	4
#define	MAGENTA	5
#define	CYAN	6
#define	WHITE	7

void rdcfg(u08_t *buf)
{
	u08_t	srg;

	srg = SREG; cli();
	buf[0] = boot_lock_fuse_bits_get(GET_HIGH_FUSE_BITS);
	buf[1] = boot_lock_fuse_bits_get(GET_LOW_FUSE_BITS);
	buf[2] = boot_lock_fuse_bits_get(GET_EXTENDED_FUSE_BITS);
	buf[3] = boot_lock_fuse_bits_get(GET_LOCK_BITS);
	buf[4] = boot_signature_byte_get(0);
	buf[5] = boot_signature_byte_get(2);
	buf[6] = boot_signature_byte_get(4);
	SREG = srg;
}

void snd_est(void)
{
	SND_SP("$GPERR,");
	snd_sbx(gl.gps.est);
	snd_sc(',');
	snd_sbx(gl.gps.ech);
	gl.gps.est = 0;
}

void su_sgps(void)
{
	char	c;
	int	i;

	if (gl.gps.est) csirow(DLNOTH), csihco(RED), snd_est(), csilclr();
	while (CB_HASD(gl.gps.b_r,gl.gps.b_w) && sio_tf() >= 100) {
		if (++gl.gps.b_r >= NEL(gl.gps.buf)) gl.gps.b_r = 0;
		if ((i = gl.gps.b_r + 2) >= NEL(gl.gps.buf)) i -= NEL(gl.gps.buf);
		c = gl.gps.buf[i];
		if (c == 'G') csirow(DLNGGA), csihco(GREEN);
		else if (c == 'R') csirow(DLNRMC), csihco(GREEN);
		else csirow(DLNOTH), csihco(RED);
		while (1) {
			c = gl.gps.buf[gl.gps.b_r];
			if (++gl.gps.b_r >= NEL(gl.gps.buf)) gl.gps.b_r = 0;
			if (c == '\r') break;
			snd_sc(c);
		}
		csilclr();
	}
}

#define	HZ2TIC(hz)	((double)F_TM1/(double)(hz))
#define	DRUPD		(u32_t)HZ2TIC(LOOPHZ)	/* dr_loop() cycle time in timer 1 ticks */

void su_loop(void)
{
	u08_t	i = 0, k, n, msk;
	char	j;
	int	rxs;
	long	tmp;
	u32_t	nxt;
	u08_t	cfg[7];

#if	U4 == 0
#define	GUI_TW	sio_tw
#define	GUI_RC	sio_rc
#define	GUI_TF	sio_tf
#else
#define	GUI_TW	usb_tw
#define	GUI_RC	usb_rc
#define	GUI_TF	usb_tf
#endif
	sio_rf();
	while (1) {
		if (gl.exit) return;
		if (++i < 21 && (i & 02)) LEDTG();
		else if (i >= 40) i = 0;
		nxt = tic() + DRUPD;
		do GUI_TW(); while ((tmp = nxt - tic()) > 0);
		if (GUI_RC() == C_STRT) break;
#if	U4
		if (CB_NO_D(gl.sio.rxr,gl.sio.rxw)) continue;
		/* USB <-> RS232 serial bridge */
		csisclr();
		while (gl.usb.sofi < 100) {
			while ((rxs = sio_rc()) > 0) usb_sc(rxs);
			usb_tw();
			while ((rxs = usb_rc()) > 0) sio_sc(rxs);
			if ((tmp = nxt - tic()) <= 0)
				LEDTG(), nxt = tic() + MS2TIC(250);
		}
		return;
#endif
	}
	LEDOF();
	gl.dsnd = U4 ? 1 : 0;
AGAIN:
	GUI_TW();
	csisclr();
	csirow(DLN0); csihco(CYAN);
	SND_SP("rx2at ");
	snd_sp(version);
	SND_SP(", at2so ");
	if (gl.arm.adr == 0) SND_SP("not ");
	SND_SP("attached");

	rdcfg(cfg);
	csirow(DLN1);
	csilco(WHITE); SND_SP("cpusg ");
	k = 0x1e;		i = cfg[4]; csihco(i==k?GREEN:RED); snd_sbx(i);
	k = 0x95;		i = cfg[5]; csihco(i==k?GREEN:RED); snd_sbx(i);
	k = U4 ? 0x87:0x0f;	i = cfg[6]; csihco(i==k?GREEN:RED); snd_sbx(i);
	csilco(WHITE); SND_SP(" fuses ");
	snd_sbx(cfg[0]); snd_sc('-');	/* high */
	snd_sbx(cfg[1]); snd_sc('-');	/* low */
	snd_sbx(cfg[2]); snd_sc('-');	/* extended */
	snd_sbx(cfg[3]);		/* lockbits */
	csihco(YELLOW);
	if (S_LAND == S_FMOD) SND_SP(" 1sM"); else SND_SP(" 2sM");
	snd_snx(T_MODE);
	if (RX_CON == 3) snd_sc('S'); else snd_sc('P');

	GUI_TW();
	csirow(DLN2); csilco(WHITE);
	SND_SP(" loop ");
	snd_spd(0,1,TIC2MS10(DRUPD));
	SND_SP("ms, dcnt="); snd_sid(0,gl.dcnt);

	csirow(DLNRXI); csihco(CYAN);
	SND_SP("-RX-  f[ms]  p[ms] value");

	tmr0_setup(0);
GPSCHANGE:
	GUI_TW();
	csirow(DLN3); csilco(WHITE);
	SND_SP("  gps ");
	if (gl.gps.b100) {
		snd_sid(0,gl.gps.b100);
		SND_SP("00 bps");
	}
	csilclr();

	nxt = tic() + DRUPD;
	for (n = 0; !gl.exit; n ^= 01) {
		/* EEPROM update */
		if (gl.eewen < NEL(gl.eedat)) eepr_updt();
		i = gl.gps.tcnt;
		LEDOF();
		do {
			if (CB_HASD(gl.rxs.rsr,gl.rxs.rsw)) rx_proc();
			usb_sq();
			gps_rcv();
		}
		while ((tmp = nxt - tic()) > 0);
		LEDON();
		if (i != gl.gps.tcnt) goto GPSCHANGE;
		nxt = tic() + DRUPD;
		GUI_TW();

		rxs = rx_read();
		beep_sq();
		if (n & 01) {
			for (i = k = 0; i < NEL(gl.rxs.chn); i++) {
				if (!((msk = _BV(i)) & S_SIG)) continue;
				if (GUI_TF() < 48) GUI_TW();
				csirow(DLNRXC+k); k++;
				csihco(rxs&msk?RED:GREEN);
				switch (i) {
				case S_AILE: SND_SP("AILE"); break;
				case S_ELEV: SND_SP("ELEV"); break;
				case S_THRO: SND_SP("THRO"); break;
				case S_RUDD: SND_SP("RUDD"); break;
				case S_GEAR: SND_SP("GEAR"); break;
				case S_AUX1: SND_SP("AUX1"); break;
				}
				csihco(gl.rxs.err&msk?RED:GREEN);
				snd_spd(7,1,TIC2MS10(gl.rxs.ftm));
				snd_spd(7,3,TIC2US(gl.rxs.chn[i].dur));
				snd_sid(-6,gl.rxs.chn[i].val);
				if (rxs == 0) {
					if (i == S_LAND)
						switch (gl.rxs.fms) {
						case FMS_LAND: SND_SP(" LAND"); break;
						case FMS_FM_1: SND_SP(" FM_1"); break;
						case FMS_FM_2: SND_SP(" FM_2"); break;
						case FMS_FM_3: SND_SP(" FM_3"); break;
						default:       SND_SP(" ????"); break;
						}
					if (gl.rxs.fms == FMS_LAND) {
						if (i == SH_THRO) {
							if (gl.rxs.stk & TS_LF) {
								if (gl.rxs.stk & TS_DN)
									SND_SP(" HOME");
#if GSWO_ENA >= 0 && GSWO_SRC == 1
								else if (gl.rxs.stk & TS_UP)
									SND_SP(" ALRM");
#endif
								else	SND_SP(" TRIM");
							}
							else if (gl.rxs.stk & TS_RT) SND_SP(" ESTP");
						}
						if (i == S_THRO) {
							j = gl.cfg;
							if (gl.rxs.stk & TS_UP) {
								if ((j = gl.cfw) < 0) j = gl.cfg;
								if ((gl.rxs.stk & ES_MSK)) csihco(YELLOW);
							}
							SND_SP(" CFG"); snd_snx(j+1);
						}
						if (i == SH_ELEV && !(gl.rxs.stk & TS_UP)) {
							if (gl.rxs.stk & ES_RT) SND_SP(" VID+");
						}
					}
					else {
						if (i == S_LAND && gl.rxs.fsa) {
						     SND_SP(" ANI"); snd_snx(gl.rxs.fsa);
						}
					}
				}
				csilclr();
			}
			SND_SP("\r\n");
		}
		else {
			if (gl.gps.est || CB_HASD(gl.gps.b_r,gl.gps.b_w)) GUI_TW(), su_sgps();
			if (GUI_RC() == C_STRT) goto AGAIN;
		}
	}
#undef	GUI_TW
#undef	GUI_RC
#undef	GUI_TF
}

/*
 * DRONE control loop
 */
void dr_scfg(void)
{
	const char	*p;

	SIO_SP("RX=C,");
	switch (gl.cfg) {
	default:
	case 0: p = cfg1; break;
	case 1: p = cfg2; break;
	case 2: p = cfg3; break;
	case 3: p = cfg4; break;
	}
	sio_sp(p);
	sio_sc('\r');
}

void dr_vlba(void)
{
	if (++gl.vlba.tick < 6) {
		if (VLBA_BLINK && gl.vlba.stat && gl.vlba.tick == 2) VLBOF();
		return;
	}
	gl.vlba.tick = 0;
	switch (gl.vlba.stat) {
	case 0: if (VLBA_THR > 0 && VLBA_THR <= 60 && gl.drm.m2a.cbat <= VLBA_THR) {
			VLBON();
			SIO_SP("RX=B,1");
			gl.vlba.stat = 1;
			break;
		}
		break;
	case 1: if (gl.drm.m2a.cbat > VLBA_THR) {
			VLBOF();
			SIO_SP("RX=B,0");
			gl.vlba.stat = 0;
		}
		else VLBON();
		break;
	}
}

void dr_sgps(void) /* send GPS data to drone */
{
	u08_t	c, r, w;

	if (gl.gps.est) snd_est(), sio_sc('\r');
	r = gl.gps.b_r;
	w = gl.gps.b_w;
	while (CB_HASD(r,w) && sio_tf() >= 80)
		do {
			c = gl.gps.buf[r];
			if (++r >= NEL(gl.gps.buf)) r = 0;
			sio_sc(c);
			if (c == '\r') break;
		}
		while (CB_HASD(r,w));
	gl.gps.b_r = r;
}

void dr_send(u08_t s)
{
	SIO_SP("RX=");
	if (gl.pad < 0) sio_sc('E');
	else if (s == 9) sio_sc('D');
	else snd_sid(0,s==10?gl.rxs.fms:0);
	snd_sid(',',gl.rxs.chn[S_ROL].val);
	snd_sid(',',gl.rxs.chn[S_PTC].val);
	snd_sid(',',gl.rxs.chn[S_GAZ].val);
	snd_sid(',',gl.rxs.chn[S_YAW].val);
	if (gl.rxs.fsa) { /* animation trigger */
		SIO_SP("\rRX=A");
		snd_sid(',',gl.rxs.fsa);
		gl.rxs.fsa = 0;
	}
	sio_sc('\r');
	if (gl.gps.est || CB_HASD(gl.gps.b_r,gl.gps.b_w)) dr_sgps();
	sio_sc('\n');
}

void dr_loop(void)
{
	u08_t	s, i, k, led;
	long	tmp;
	u32_t	nxt;

	gl.rxs.stk = 0;
	led = 0;
	s = i = k = 0;
	/* This is it, this program is talking to the program on the drone now.
	 * s < 3 -> drone configuration, s >= 3 -> TX/RX in charge */
	sio_rf();
	nxt = tic() + DRUPD;
	tmr0_setup(0);	/* get GPS setup going */
	while (1) {
		/* packet to drone */
		dr_send(s);
		/* EEPROM update */
		if (gl.eewen < NEL(gl.eedat)) eepr_updt();

		/* keep loop on track, don't want to be too pushy or late */
		gl.drm.ack = 0;
		do {
			if (CB_HASD(gl.rxs.rsr,gl.rxs.rsw)) rx_proc();
			gps_rcv();
			sio_rcv();
		}
		while ((tmp = nxt - tic()) > 0);
		nxt = tic() + DRUPD;

		gl.rxs.chg = gl.rxs.stk;	/* remember previous */
		rx_read();

		if (s < 3) {	/* drone configuration */
			switch (s) {
			case 0: dr_scfg();
				k = S2LTIC(3.0);
				LEDOF();
				s = 1;
				break;
			case 1: if (gl.drm.ack) s = 2;	/* received C_ACK from drone */
				else if (--k == 0) s = 0, LEDON();
				break;
			case 2: i = 0;
				s = 3;
				break;
			}
			continue;
		}
		/* Arduino LED blink */
#if	NL_AIR
		if (s == 10) LEDOF(); else
#endif
		if (led == 0) LEDTG();
		else if ((led >>= 1) == 0) {
			led = 1<<(5-1);
			if (i < k) LEDON();
			if (++i >= 6) i = 0;
		}
		else LEDOF();

		/* chores */
		dr_vlba();
		beep_sq();

		/* check radio link */
		if (gl.rxs.err) {	/* radio quit or got disconnected from TX */
			led = 0;
			s = 9;
			continue;
		}

		switch (s) {
		/*
		 * drone on ground, or getting there
		 */
		case 3:
			gl.rxs.chg ^= gl.rxs.stk;
			if (gl.rxs.fms == FMS_LAND) {
				if (gl.rxs.chg & TS_RT) {
					if (gl.rxs.stk & TS_RT) /* EMERGENCY */
						gl.pad = -1;
					else	gl.pad =  0;
				}
				else if (gl.rxs.stk & gl.rxs.chg & TS_LF) {
					if (gl.rxs.stk & TS_DN)
						SIO_SP("RX=H\r"); /* HOME */
					else	SIO_SP("RX=T\r"); /* FTRIM */
				}
				if (gl.rxs.stk & TS_UP) { /* show/change config */
					led = 1;
					k = gl.cfg + 1;
					i = 0;
					s = 5;
				}
				else if (gl.rxs.stk & TS_DN) { /* show GPS status */
					if (gl.drm.m2a.sgps >= 0) {
						if (gl.rxs.chg & TS_DN) led = 1;
						k = gl.drm.m2a.sgps;
					}
				}
				else if (gl.rxs.chg & TS_DN) led = 0;
				if (gl.rxs.stk & gl.rxs.chg & ES_RT) /* VZAP */
					SIO_SP("RX=V,Z\r");
				break;
			}
			if (gl.eewen < NEL(gl.eedat)) break;	/* wait for EEPROM write to complete */
			if (gl.rxs.stk != 0) break;		/* all sticks centered for launch */
			if (gl.rxs.chn[S_THRO].val) break;	/* throttle should be dead 0 */
			gl.pad = 1, s = 10;			/* launch */
			SIO_SP("RX=V,1\r");			/* video record on */
			break;
		case 5: /* display/set configuration */
			k = (gl.cfw < 0 ? gl.cfg : gl.cfw) + 1;
			if (gl.rxs.stk & TS_UP) break;
			if (gl.eewen < NEL(gl.eedat))	/* did get changed */
				s = i = 0;		/* send new configuration to drone */
			else	s = 3;
			led = 0;
			break;
		case 9: /* radio loss recovery */
			if (gl.rxs.fms == FMS_LAND) gl.pad = 0;
			s = gl.pad > 0 ? 10 : 3;
			break;
		/*
		 * drone airborne
		 */
		case 10:
			if (gl.rxs.fms != FMS_LAND) break;
			gl.pad = 0;
			SIO_SP("RX=V,0\r"); /* video record off */
			s = 3;
			break;
		}
	}
}

void init(void)
{
extern	u08_t	__bss_start;
extern	u08_t	__bss_end;
	u08_t	i, k, *b = &__bss_start;
	int	n = &__bss_end - &__bss_start;

	cli();
#if	U4
	UDIEN  = 0;
	USBCON = 0;
	UHWCON = 0;
#endif
	while (--n >= 0) *b++ = 0;	/* clear BSS segment */

	for (EECR = 0; gl.eewen < NEL(gl.eedat); gl.eewen++) {
		EEAR = (int)gl.eewen;
		EECR |= _BV(EERE);
		gl.eedat[gl.eewen] = EEDR;
	}
	for (i = k = 0; i < (NEL(gl.eedat)-1); i++) k += gl.eedat[i];
	if (gl.eemag != EE_MAG || gl.eecks != k) gl.cfg = gl.bid = 0;
	gl.cfw = -1;
#if	AT2SO == 1
	at2so_chck();
#endif

}

int main(void)
{
	u08_t	i, j, k;

AGAIN:
	init();

#if	U4 == 0
	/* Nano, ProMini - RC receiver hardware bits on port D[7:2] */
#if	RX_CON == 0
	gl.rxs.chn[S_THRO].msk = _BV(7);
	gl.rxs.chn[S_AILE].msk = _BV(6);
	gl.rxs.chn[S_ELEV].msk = _BV(5);
	gl.rxs.chn[S_RUDD].msk = _BV(4);
	gl.rxs.chn[S_GEAR].msk = _BV(3);
	gl.rxs.chn[S_AUX1].msk = _BV(2);
#elif	RX_CON == 1
	gl.rxs.chn[S_THRO].msk = _BV(2);
	gl.rxs.chn[S_AILE].msk = _BV(3);
	gl.rxs.chn[S_ELEV].msk = _BV(4);
	gl.rxs.chn[S_RUDD].msk = _BV(5);
	gl.rxs.chn[S_GEAR].msk = _BV(6);
	gl.rxs.chn[S_AUX1].msk = _BV(7);
#elif	RX_CON == 2
	/* put your own bit numbers here */
	gl.rxs.chn[S_THRO].msk = _BV(7);
	gl.rxs.chn[S_AILE].msk = _BV(6);
	gl.rxs.chn[S_ELEV].msk = _BV(5);
	gl.rxs.chn[S_RUDD].msk = _BV(4);
	gl.rxs.chn[S_GEAR].msk = _BV(3);
	gl.rxs.chn[S_AUX1].msk = _BV(2);
#elif	RX_CON == 3
#else
#error	"RX_CON bad value"
#endif
#else
	/* MiruPCB - RC receiver hardware bits on port B[6:1] */
#if	RX_CON == 0
	gl.rxs.chn[S_THRO].msk = _BV(1);
	gl.rxs.chn[S_AILE].msk = _BV(2);
	gl.rxs.chn[S_ELEV].msk = _BV(3);
	gl.rxs.chn[S_RUDD].msk = _BV(4);
	gl.rxs.chn[S_GEAR].msk = _BV(5);
	gl.rxs.chn[S_AUX1].msk = _BV(6);
#elif	RX_CON == 1
	gl.rxs.chn[S_THRO].msk = _BV(6);
	gl.rxs.chn[S_AILE].msk = _BV(5);
	gl.rxs.chn[S_ELEV].msk = _BV(4);
	gl.rxs.chn[S_RUDD].msk = _BV(3);
	gl.rxs.chn[S_GEAR].msk = _BV(2);
	gl.rxs.chn[S_AUX1].msk = _BV(1);
#elif	RX_CON == 2
	/* put your own bit numbers here */
	gl.rxs.chn[S_THRO].msk = _BV(1);
	gl.rxs.chn[S_AILE].msk = _BV(2);
	gl.rxs.chn[S_ELEV].msk = _BV(3);
	gl.rxs.chn[S_RUDD].msk = _BV(4);
	gl.rxs.chn[S_GEAR].msk = _BV(5);
	gl.rxs.chn[S_AUX1].msk = _BV(6);
#elif	RX_CON == 3
#else
#error	"RX_CON bad value"
#endif
#endif

	/* dead bands */
	gl.rxs.chn[S_AILE].dbn = MS2TIC(0.04);
	gl.rxs.chn[S_ELEV].dbn = MS2TIC(0.04);
	gl.rxs.chn[S_THRO].dbn = MS2TIC(0.06);
	gl.rxs.chn[S_RUDD].dbn = MS2TIC(0.04);
	gl.rxs.chn[S_GEAR].dbn = MS2TIC(0.20);
	gl.rxs.chn[S_AUX1].dbn = MS2TIC(0.20);

	port_setup();
	LEDON();
	tmr0_setup(0);
	tmr1_setup();
	sio_setup();
	gl.rxs.smp = RXSIG;
	gl.gps.rxi = GPS_RXI_INPUT();
	sei();		/* turn interrupts on */
	msdly_cali();	/* calculates propper gl.dcnt */
	SIO_UCSRB |= _BV(SIO_RXCIE)|_BV(SIO_RXEN)|_BV(SIO_TXEN);	/* turn USART on */
	GPS_RXI_IRQON();	/* enable GPS softserial port */
	PIN_CHG_IRQEN();	/* turn pin change interrupts on */
	LEDOF();

#if	U4
	usb_init();
	ms_dly(500);
	if (gl.usb.ep0a) {
		su_loop();
		while (1) PORTB = 0, DDRB = 0x80; /* hardware reset (RST connected to this pin) */
		goto AGAIN;
	}
	UDIEN  = 0;
	USBCON = 0;
	UHWCON = 0;
#else
	if (SETUP()) {
		sio_rf();
		ms_dly(500);
		su_loop();
		goto AGAIN;
	}
#endif

	/* wait for drone to boot
	 * make sure radio works and has 'sane' state, aka is in LAND */
#define	NS_BOOT	18
#define	NSQUIET	5
	gl.rxs.erx = 255;	/* mark radio down */
	for (i = j = k = 0; 1; ) {
		if (sio_rf() || j < NS_BOOT) i = 0;
		else if (i < NSQUIET) i++;
		if (rx_read()) k = 0;
		else if (gl.rxs.fms != FMS_LAND) k = 1;
		else if (j < NS_BOOT) k = 2;
		else if (i < NSQUIET) k = 3;
		else break; /* all conditions met, go on */
		switch (k) {
		case 0: blip(1); ms_dly(800-50); break; /* radio not ready */
		case 1: blip(2); ms_dly(600-50); break; /* flight mode not LAND */
		case 2: blip(3); ms_dly(400-50); break; /* drone still booting */
		case 3: blip(4); ms_dly(200-50); break; /* drone still talking */
		}
		/* Note: this loop runs on a 1 second pace, need to refresh RX,
		 *       otherwise 'dead signal' detector triggers on rx_read() */
		rx_read(); ms_dly(50);
		if (j < NS_BOOT) j++;
	}

	/* start shell on drone */
	sio_sc('\r'); ms_dly(100); sio_rf();
	sio_sc('\r'); ms_dly( 50); sio_rf(); /* do it twice... */

	LEDON();
	/* look at throttlestick, if it is not centered, user wants to lock out WiFi... */
	k = (gl.rxs.stk & (TS_UP|TS_DN)) ? 1 : 0;
	at2so_exec(k);	/* load/launch companion program on drone */
	LEDOF();

	dr_loop();
	/* NOTREACHED */
	return 0;
}

#if	AT2SO == 1

const u08_t at2so_buf[] PROGMEM = {
0xaa,0x55,0x6c,0x31,0xc4,0xbb,
0x1f,0x8b,0x08,0x00,0x2b,0x59,0x48,0x58,0x02,0x03,0xcd,0x7c,0x7b,0x7c,0x54,0xd5,
0xbd,0xef,0xda,0x7b,0x66,0x92,0x10,0x02,0x4c,0x1e,0x68,0x8c,0x48,0x76,0x62,0x50,
0xaa,0x49,0xd8,0x13,0x02,0xc6,0x48,0x74,0x42,0xc2,0x4b,0x03,0xe4,0x05,0xd2,0x8a,
0x26,0x43,0x32,0x40,0xda,0x90,0x4c,0x33,0x83,0x62,0x0f,0x5e,0x26,0x99,0xe1,0xa1,
0x25,0x8a,0x04,0x2b,0x97,0x0b,0xcd,0x58,0xe9,0x95,0x8f,0x87,0x63,0xe3,0xe3,0x58,
0x8e,0x07,0xdb,0x00,0x51,0xa9,0xd2,0x16,0x34,0xb6,0x1c,0x8a,0x76,0x66,0x4f,0xf6,
0x4d,0x1a,0xec,0x2d,0x3d,0xa2,0xa2,0x52,0xe7,0x7e,0x7f,0x6b,0xaf,0x21,0x1b,0xb4,
0xe7,0x9e,0x73,0xff,0xba,0xd1,0xc5,0xfa,0xad,0xb5,0x7e,0x6b,0xad,0xdf,0xfa,0xad,
0xdf,0x6b,0xad,0xbd,0x67,0x6f,0x9a,0x57,0x35,0x5f,0x92,0x24,0x16,0xff,0x93,0xd9,
0x74,0x46,0xa5,0x8d,0x8f,0x31,0x56,0x8c,0xfc,0x40,0x35,0xd5,0x31,0x5b,0x31,0x53,
0x58,0x12,0xda,0xae,0x67,0x59,0xd4,0xee,0x79,0xa5,0x8a,0xb1,0x57,0x4e,0x18,0x69,
0x84,0x19,0xc9,0x2a,0x52,0x02,0x33,0xfa,0x16,0xfb,0x8d,0xc4,0x07,0x44,0xb2,0x89,
0x76,0x0b,0xb5,0xa1,0x5c,0xdc,0x69,0xa4,0x74,0x66,0x24,0xeb,0x18,0xaa,0xf1,0xe7,
0x37,0xd2,0xde,0xc5,0x46,0xb2,0x89,0x3a,0x6a,0x37,0xea,0x24,0x9e,0x4e,0xa1,0x62,
0xb7,0xc3,0x98,0x97,0xda,0x65,0xa2,0x7b,0x31,0x25,0x89,0xa7,0xf8,0xa0,0x09,0x26,
0x1a,0x17,0xa2,0xbc,0xb0,0xd3,0x48,0x0a,0x33,0x52,0xbc,0xad,0x46,0xf7,0x35,0xb3,
0x6f,0xf8,0x8b,0xf7,0x9f,0xd1,0xda,0xb2,0x6a,0x46,0x6b,0x73,0x41,0x6b,0x4b,0xdb,
0xfa,0x0d,0x85,0xde,0xf6,0xc2,0x99,0x46,0xbd,0x5d,0xd0,0xbe,0x60,0xc9,0x32,0xc1,
0x4b,0xa3,0x0f,0xd5,0x4f,0x43,0x9a,0x2e,0xc6,0xb9,0x09,0xe9,0x7a,0x01,0x67,0x8a,
0xb6,0xf8,0xdf,0x38,0x91,0x5f,0x23,0xfa,0x4f,0x10,0xe5,0x44,0xa4,0x29,0x48,0x39,
0xa2,0x3c,0x09,0xe9,0x66,0xa4,0x0c,0xa4,0x1b,0x90,0xae,0x45,0xca,0x63,0xdf,0xfc,
0xa7,0x88,0x7c,0xaa,0xa0,0x85,0xf8,0x3f,0x11,0x29,0x0b,0xe9,0x46,0xf6,0x1f,0xff,
0xd9,0xae,0x2a,0x27,0x9b,0xe0,0x14,0xc1,0x0f,0xfa,0x4b,0x32,0xef,0x1b,0xfe,0xc6,
0x9b,0x78,0x96,0xfa,0x0d,0xe3,0xa6,0x99,0xe0,0xeb,0xc4,0xfe,0xc7,0xff,0xb2,0x45,
0x3e,0x19,0x29,0xf7,0x1b,0xfa,0xde,0x89,0x89,0x4e,0x6c,0x1b,0x1b,0xa7,0x0d,0xe5,
0xd3,0xa6,0xf2,0x71,0xa4,0x21,0x53,0xf9,0x1f,0x91,0xce,0x9b,0xca,0x77,0x03,0xff,
0x92,0xa9,0x7c,0x3b,0xd1,0xff,0xe8,0x58,0xf9,0x21,0xb4,0x67,0x98,0xca,0xcb,0xae,
0xa2,0x7b,0xfc,0x55,0xbc,0xcd,0xba,0xaa,0x7c,0x2b,0xfa,0xe7,0x9b,0xfa,0x57,0xa0,
0x5c,0x62,0x2a,0x3f,0x81,0x72,0xa5,0xa9,0xfc,0x1a,0x52,0xb5,0xa9,0xbc,0x1c,0xed,
0x2b,0x4d,0xe5,0x28,0xd2,0x5a,0x53,0xf9,0x59,0x24,0x9f,0xa9,0x9c,0x0c,0x7c,0xbf,
0xa9,0xfc,0x28,0xca,0xdb,0x4d,0xe5,0xfb,0x49,0x3f,0x4c,0xe5,0x66,0x94,0xf7,0x9b,
0xca,0xdd,0x48,0x7d,0xa6,0xf2,0x34,0xb4,0x1f,0x36,0x95,0x8b,0x50,0x3e,0x6e,0x2a,
0x9f,0x45,0x1a,0x34,0x95,0x5f,0x46,0x0a,0x9b,0xca,0x93,0x80,0xff,0x91,0xa9,0xfc,
0x3e,0xd2,0x45,0x53,0x79,0x17,0xc9,0xcd,0x63,0x63,0xe5,0x6b,0x80,0x6f,0x37,0x95,
0xbf,0x24,0x59,0x37,0x95,0x8f,0x90,0xee,0x98,0xca,0x25,0x64,0x3b,0x4c,0x65,0x12,
0x3c,0xa7,0xa9,0xfc,0x1b,0xa4,0x2a,0x53,0x79,0x0a,0xda,0x57,0x98,0xca,0xad,0x57,
0xed,0xe7,0x28,0xf1,0xc4,0xd4,0xfe,0x3f,0x90,0x3c,0xe6,0xf1,0xa1,0xef,0xeb,0x48,
0xcf,0x67,0xb3,0x86,0x86,0x35,0xeb,0xda,0xdb,0x1a,0xbc,0x3e,0x57,0x87,0xaf,0xa1,
0x81,0x35,0xdc,0xfd,0x60,0x43,0xad,0x7b,0x4d,0x8b,0xd7,0xe7,0xee,0xa8,0x68,0x75,
0x79,0xbd,0x6e,0x2f,0x21,0x77,0xf8,0x08,0xdb,0xc1,0x9a,0x5a,0xdb,0x9b,0xbe,0xd7,
0xb0,0xc6,0xed,0xf3,0xb5,0xac,0x73,0x53,0xc3,0x9a,0xa6,0xa6,0x06,0xaf,0xd1,0xd6,
0xd0,0xe0,0x72,0xbb,0x56,0xb5,0x34,0xac,0x6f,0x7b,0xa8,0xa5,0xad,0xb9,0xa1,0xc9,
0xe3,0x69,0xf0,0x74,0xa8,0xdf,0x5c,0xed,0xa0,0xbe,0x4d,0x06,0x05,0x5e,0x0c,0xe9,
0xf6,0x31,0xaf,0xaf,0xa3,0xc9,0xf3,0x30,0xf3,0x7a,0x3a,0x5a,0xda,0x7c,0xab,0xa9,
0xd8,0xd1,0xb4,0xb6,0x83,0x35,0xb5,0xb7,0xb5,0xb9,0x9b,0x7c,0x6c,0x7d,0x1b,0x8c,
0xd3,0xf7,0xd0,0x0d,0x94,0xb5,0x31,0xaf,0xbb,0x95,0x2a,0x5d,0xab,0xda,0x3b,0x7c,
0x0c,0xe4,0x78,0x5a,0x9a,0xa9,0x87,0xaf,0xbd,0x95,0xb2,0x56,0x60,0xac,0x73,0xaf,
0xf3,0x62,0xd4,0x86,0x06,0x77,0x47,0x47,0x5b,0x7b,0x03,0xe8,0x76,0xf9,0x5a,0xda,
0xdb,0xd8,0x2a,0x10,0xc1,0x7c,0x4d,0x68,0x73,0xf9,0x7c,0x1d,0xac,0xc3,0xed,0x6a,
0x26,0x5c,0x9a,0xba,0xc3,0xd5,0xe2,0x75,0xa3,0xa6,0xe9,0xc1,0xd5,0x1d,0xed,0xeb,
0x58,0x4b,0x7b,0x93,0x0f,0xc3,0x3d,0x8c,0x09,0xd7,0xb1,0x55,0x4d,0xed,0xc0,0xc0,
0xf2,0x81,0xd1,0xee,0x21,0x0a,0x7c,0x9c,0x3c,0xcc,0x4d,0xf4,0xb7,0xb9,0xc0,0x0e,
0xaf,0xbb,0xad,0xd9,0xd7,0xce,0x5c,0x4d,0x4d,0x6e,0x8f,0x0f,0x73,0xac,0x11,0x73,
0x00,0x15,0x44,0xb4,0x77,0x80,0x18,0x5a,0xb5,0xe0,0xf5,0x3a,0x57,0x4b,0x1b,0x7b,
0xa8,0xa3,0xc5,0xe7,0x46,0x7d,0xd3,0x06,0x57,0x83,0xcb,0xe7,0xde,0xd0,0xe2,0x63,
0x0b,0x2a,0x2a,0x1a,0x66,0x16,0xce,0x62,0x0b,0xaa,0x16,0xcd,0xad,0x68,0x28,0x2a,
0x2c,0xe6,0x76,0x33,0xfe,0x9f,0x05,0xc9,0x2a,0x6c,0xf1,0x7f,0xfd,0x3f,0x2b,0xff,
0x97,0xc4,0x4b,0x62,0x0b,0x84,0xed,0x24,0xfd,0x5e,0x76,0xd3,0xc3,0xe3,0xc9,0xf2,
0xed,0x15,0x06,0x8f,0xda,0x0b,0x4d,0xed,0x19,0x2d,0x2d,0x13,0xc8,0xca,0xee,0x37,
0xb5,0x07,0x44,0x3b,0xbb,0xdc,0x2e,0x5f,0x6e,0xaf,0x5c,0x2a,0xb1,0xc9,0x30,0xfc,
0xaf,0x2c,0x91,0xb8,0x2e,0x1c,0xa2,0x1c,0x13,0x1f,0xa6,0x1c,0xc6,0xba,0x9f,0x72,
0x2c,0x63,0x80,0x72,0x18,0xe4,0xe3,0x94,0xc3,0xb0,0x9e,0xa0,0x1c,0x8e,0xe1,0x24,
0xe5,0xe8,0x3f,0x48,0x39,0x28,0x3b,0x4d,0x39,0x8c,0xf3,0x59,0xca,0x31,0x53,0x98,
0x72,0x18,0xfc,0x21,0xca,0xe1,0x38,0x46,0x28,0x07,0x31,0x1f,0x51,0x0e,0xe3,0x7c,
0x9e,0x72,0x08,0xfa,0x05,0xca,0x61,0x88,0x2f,0x52,0x0e,0xc7,0x72,0x89,0x72,0x32,
0xc2,0xa0,0xef,0x1a,0x38,0x24,0x2b,0xe5,0x70,0x34,0x49,0x94,0xc3,0x71,0xa5,0x50,
0x0e,0xe3,0x6d,0xa7,0x1c,0x46,0x30,0x83,0x72,0x38,0xb6,0x4c,0xca,0xe1,0xac,0xa6,
0x50,0x0e,0xe7,0xa4,0x50,0x0e,0xe7,0x93,0x47,0x39,0x8c,0xfb,0x74,0xca,0xc1,0xa8,
0x7c,0xca,0xe1,0xd0,0x54,0xca,0x61,0xe8,0x8b,0x29,0x87,0x43,0x2a,0xa1,0x1c,0xce,
0x6c,0x0e,0xe5,0x70,0x96,0x4e,0xca,0xe1,0xec,0x92,0x9c,0x05,0x7f,0x82,0x7b,0x3f,
0x97,0xe4,0x7f,0x7d,0xc4,0x1a,0x2e,0xd0,0xad,0xe1,0x5e,0x7d,0x62,0xf8,0x89,0x70,
0xd2,0xf9,0x5f,0xe8,0xe1,0x37,0x40,0xe7,0x9b,0x4f,0x68,0x29,0x6f,0x6f,0xd7,0xc2,
0x9f,0x1c,0xd6,0xe3,0xf0,0x69,0x13,0x7c,0xd2,0x04,0x1f,0x37,0xc1,0xfd,0x26,0xf8,
0x90,0x09,0xee,0x33,0xc1,0x07,0x4c,0x70,0xc8,0x04,0xef,0x36,0xc1,0x3b,0x4c,0xf0,
0x36,0x13,0xec,0x37,0xc1,0x1b,0x4c,0xb0,0xc7,0x04,0xaf,0x35,0xc1,0x8d,0x26,0x78,
0x85,0x09,0xae,0x36,0xc1,0x0b,0x4d,0xb0,0xd3,0x04,0x97,0x98,0x60,0xd5,0x04,0x4f,
0x37,0xc1,0x8a,0x09,0xce,0x34,0xc1,0x76,0x13,0x9c,0x64,0x82,0x99,0x09,0xbe,0x78,
0x61,0x0c,0x3e,0x6f,0x82,0x47,0x4c,0x70,0xd8,0x04,0x9f,0x36,0xc1,0x27,0x4d,0xf0,
0x71,0x82,0xfb,0x42,0x51,0x16,0x0e,0x45,0xad,0xf6,0x7d,0x43,0x13,0x94,0x50,0xc4,
0xaa,0x60,0x4f,0x59,0x81,0x6e,0xef,0xef,0xd5,0xad,0xfd,0x05,0x7a,0x0a,0xeb,0xd5,
0x53,0xd4,0x5e,0x7d,0x4f,0x2c,0x76,0xae,0x1b,0x69,0x1b,0xf6,0xf8,0xd0,0x21,0xe8,
0xc1,0x00,0x64,0x0d,0xf5,0x19,0x68,0xb7,0xa8,0x4f,0x84,0x99,0xd2,0x33,0xcc,0x58,
0x6d,0x74,0x6a,0x6c,0x86,0xb4,0x33,0x16,0x1b,0x0d,0x1f,0x43,0x6c,0x48,0xfa,0x06,
0x1c,0xa6,0xbc,0xa7,0x53,0x9b,0xa4,0x84,0x2c,0x4c,0x39,0x66,0x03,0x4e,0xc4,0x03,
0x79,0x52,0xd0,0x97,0xe4,0x89,0xa9,0x3b,0xd0,0x5e,0x17,0x85,0x4c,0x25,0x71,0x7c,
0x01,0xcf,0x04,0x1e,0xc9,0xd9,0xfe,0xc5,0x86,0x92,0x4a,0xea,0xc9,0x21,0x49,0x39,
0x35,0x24,0xb3,0xba,0x88,0x85,0xbb,0xfc,0xba,0xe8,0xe7,0xb1,0x58,0x96,0xc4,0x42,
0x34,0x6f,0x84,0xc5,0x73,0x35,0x44,0xed,0xa3,0xac,0xff,0x94,0x2e,0xd9,0xfd,0x5a,
0x0a,0xab,0x8d,0x40,0x75,0xb3,0x24,0xe5,0xbd,0x21,0xe0,0x46,0x88,0x96,0xcf,0xd0,
0xef,0xea,0x3e,0x92,0x52,0xab,0x51,0x3b,0xca,0xe5,0x52,0x3f,0x70,0xfb,0x8f,0x0c,
0x21,0x0a,0x88,0x5e,0x14,0xb8,0x76,0xa2,0x95,0x75,0xea,0xac,0x1f,0xb8,0xa0,0xa5,
0x0c,0xf3,0x83,0x86,0xf4,0x38,0x2d,0xe8,0x6b,0xc9,0x30,0x42,0x81,0xd1,0x7c,0x94,
0x2f,0xa0,0x1f,0xc6,0x8d,0x4a,0xea,0x09,0xd0,0x0c,0x1e,0xf7,0x77,0xea,0x88,0xd1,
0x46,0x73,0x59,0x3d,0xea,0x6e,0x94,0x6d,0x3c,0x94,0xab,0x8b,0x52,0xff,0x7c,0x5e,
0x57,0x65,0x63,0x47,0x3a,0x13,0x25,0xe6,0x97,0x25,0xe7,0x59,0xcc,0x5d,0x1f,0x95,
0x59,0x75,0xea,0xbf,0xc7,0x62,0xaf,0x31,0x25,0x14,0x85,0xd9,0x18,0xb5,0xaa,0x4f,
0x0e,0xb1,0xfe,0xf7,0xf4,0x5c,0xd0,0x25,0xf5,0x07,0x64,0x6b,0xbf,0x64,0x4b,0x32,
0xc2,0x1f,0xb4,0x81,0x2e,0xb4,0x49,0xce,0x80,0x46,0x74,0x7f,0x41,0xf3,0x3b,0x09,
0xb7,0x3e,0xca,0xfa,0x8f,0xd9,0x24,0xa5,0x0b,0xf5,0xb5,0x91,0x3f,0x63,0x3c,0x3b,
0xf8,0x8a,0x88,0x27,0x4a,0x6b,0x02,0x7c,0x28,0x1f,0x7c,0xef,0xcf,0x0d,0x45,0xd2,
0x80,0x23,0x1f,0xe9,0x19,0x96,0x9c,0xa1,0x68,0xb6,0x9d,0x69,0x19,0xa9,0xdb,0x23,
0x72,0x6a,0x60,0xb8,0x52,0xe9,0xd1,0x41,0x0b,0xe4,0xc3,0x1f,0xaa,0x54,0x02,0x3f,
0xa5,0xfe,0x3e,0xec,0x61,0x9e,0xd2,0xab,0xef,0x2e,0xde,0xa9,0xef,0xcd,0xd8,0xa9,
0x4b,0xc6,0xbe,0x24,0x4b,0x6a,0x40,0xcb,0x26,0xde,0xa8,0xa1,0x63,0xbb,0x8b,0xbb,
0xf4,0x38,0x8f,0x09,0xff,0xe2,0xbc,0x82,0x3f,0x35,0x3b,0x7b,0xf5,0x85,0x58,0xcf,
0xde,0xfa,0x5d,0x3a,0x0b,0x85,0x22,0x3b,0x6d,0x09,0x61,0xc9,0x1f,0x8a,0xdc,0xfd,
0xdf,0xb6,0x68,0x56,0xcf,0xd6,0x30,0xb3,0x87,0xa2,0x89,0xd8,0x87,0x34,0xc8,0x5b,
0xa2,0x3d,0x14,0xc9,0x06,0x6e,0x32,0xca,0x4f,0xa1,0x9c,0x7e,0xc3,0x16,0x4d,0xaa,
0xde,0xac,0x25,0xa1,0x2c,0xd9,0x83,0xe1,0x9b,0xd1,0xf6,0x04,0xea,0xb3,0xd9,0xb2,
0xe8,0xde,0x62,0x8c,0x57,0x1d,0x3a,0x66,0x61,0xcb,0x22,0x7b,0xeb,0x83,0x93,0x2f,
0x6e,0x36,0x68,0x5c,0xeb,0xe8,0xd5,0xbd,0x58,0xa7,0x33,0x17,0x6b,0x50,0x03,0xe1,
0x27,0xef,0x0a,0x68,0x55,0x24,0x1f,0xf6,0x77,0x75,0xd9,0x19,0x8a,0x4c,0x60,0x35,
0xd8,0xc7,0x9a,0x74,0xe2,0x0f,0xc9,0x93,0x05,0x7a,0x50,0x0e,0x1a,0x24,0xfb,0xd1,
0xa1,0x74,0x7b,0xa7,0x26,0xd9,0x8f,0xe9,0x96,0xfe,0x80,0x76,0x8b,0x51,0xa7,0xa7,
0x90,0x9e,0x80,0x17,0x72,0x35,0xe5,0xec,0x16,0xc9,0x0e,0xb9,0x04,0x6e,0x19,0xc6,
0xa1,0x3a,0x92,0x2d,0x8b,0x3d,0x0c,0xdc,0xa6,0xb0,0x64,0xef,0x0a,0x63,0xec,0x68,
0x3e,0x63,0x67,0xa8,0x0f,0x6b,0x0c,0x45,0x64,0xea,0x13,0x3e,0x39,0x94,0xcf,0x1e,
0xe0,0xf2,0x9b,0x80,0xf6,0x74,0xda,0x43,0xfb,0x59,0xbd,0x02,0x30,0xdc,0x42,0x96,
0x4d,0x7d,0x4f,0x5f,0x02,0x1e,0xc2,0x75,0x64,0x1d,0xc0,0xde,0x48,0xd5,0x73,0xb5,
0x39,0xa0,0x7f,0xff,0x0d,0x3d,0x3a,0xd1,0x39,0x27,0x37,0xa0,0x33,0x7b,0xb7,0x7e,
0x00,0x65,0x2b,0x72,0x1b,0xf8,0x11,0xb4,0xf7,0xea,0xa1,0xb2,0x1e,0x3d,0x01,0xfc,
0x60,0xd5,0x9b,0xc3,0x1e,0xf4,0xa3,0x7a,0xea,0xd7,0x8a,0xb6,0x78,0xbf,0xaf,0xbe,
0x32,0xda,0x41,0xc7,0xa8,0xa4,0xfc,0x6e,0x88,0x29,0x6f,0xe8,0x16,0xd0,0x9d,0xc0,
0xea,0x21,0xd7,0x9b,0x89,0x07,0x8f,0xc1,0x16,0x44,0xa9,0x1e,0x1e,0x4d,0x27,0x39,
0xb1,0xb2,0x10,0x4e,0xa8,0xc1,0x34,0xa6,0x9c,0xe4,0xba,0x0c,0x79,0x4c,0x7d,0x01,
0xb4,0xa7,0x60,0xff,0x9f,0xcc,0xee,0xd2,0x2c,0xaa,0x2b,0xec,0x2c,0xea,0xd2,0x37,
0x0a,0xb9,0xf8,0x15,0xec,0xc4,0x9f,0x7e,0x05,0xfd,0x27,0x9d,0x71,0x56,0x6b,0x70,
0x59,0xaf,0x9d,0xc2,0xbc,0x2b,0x41,0xd3,0x40,0x5c,0xce,0x52,0x7b,0x86,0xb3,0x9d,
0x56,0xd2,0xb9,0xa8,0xbd,0xf2,0x48,0x44,0x2e,0x87,0x9c,0xa9,0x3d,0x3a,0xc9,0xb2,
0xa4,0x92,0x9e,0xd6,0x45,0xf3,0x31,0x3e,0xdc,0xeb,0x19,0xc9,0x5e,0xa1,0x1d,0x39,
0x8a,0x7e,0xfd,0xdb,0xb5,0x94,0x23,0x3b,0x87,0xb3,0x99,0xa4,0xad,0x24,0x19,0x60,
0xf6,0xe8,0xc7,0xb1,0x58,0x72,0xa5,0x4a,0x72,0x16,0x8e,0xc6,0xe5,0x12,0x27,0x18,
0xdd,0xfb,0x55,0x6c,0xf4,0x1c,0xe8,0xa8,0xc7,0x9c,0x09,0x58,0x83,0x3c,0x1d,0xfb,
0x05,0x9f,0xb5,0x10,0x3e,0xcb,0x12,0xc6,0x7a,0x4a,0xb0,0x17,0x19,0xa1,0x48,0x6e,
0x7e,0x28,0x52,0xf1,0xc7,0xc5,0x9a,0x65,0x20,0x14,0xc9,0x99,0xde,0x15,0xb9,0x71,
0x0e,0xe6,0x56,0xba,0xa1,0xab,0xdd,0x9a,0x02,0xbe,0x4d,0xc4,0x7e,0xe7,0x97,0x04,
0x22,0x7d,0xa0,0x9f,0xea,0xee,0x47,0x5e,0xf1,0xc7,0x6e,0xcd,0x7a,0x7e,0xdf,0xd0,
0xcd,0x6f,0x22,0x6e,0x7f,0x0b,0xe7,0x0d,0xe4,0xe9,0x58,0x2b,0xad,0x65,0x02,0x64,
0xf6,0x1e,0xe0,0xe4,0x91,0x2d,0x73,0xee,0xd3,0xad,0x58,0x93,0x95,0x21,0x77,0x36,
0x85,0x33,0x30,0xde,0x17,0x77,0x85,0xa2,0x3d,0x56,0x6b,0xb8,0x78,0x3c,0x3b,0xc7,
0x58,0x30,0x3c,0x45,0xd0,0xec,0x9c,0x3b,0x89,0x79,0x30,0x46,0x10,0xfa,0x71,0xe0,
0xe4,0x62,0xed,0x70,0x0d,0xe4,0x19,0xf2,0x62,0x53,0x77,0x44,0xa0,0xe0,0x77,0xff,
0x2f,0xec,0xeb,0xcf,0xcb,0x82,0x1a,0x53,0xbb,0xf5,0x66,0x8c,0xe3,0x67,0xcb,0xa3,
0x09,0x6a,0xe8,0x45,0xbf,0x1a,0x7a,0x16,0xfb,0x11,0x21,0xda,0xb6,0x12,0x8d,0xf6,
0x6e,0x8d,0xca,0xb4,0xf7,0x77,0xd3,0x5e,0x63,0xed,0xb0,0x35,0x67,0x8a,0x41,0x8f,
0x45,0xd9,0x35,0x2c,0x33,0x7f,0x58,0xb2,0x55,0xc3,0xee,0x04,0x87,0x21,0xbf,0xaf,
0x65,0x60,0xbe,0xc3,0xd2,0x2e,0xbd,0x05,0xb8,0x92,0x1a,0x8e,0x1e,0x76,0x04,0x31,
0x7f,0xb7,0xe6,0x11,0x74,0xfd,0x00,0x6b,0x3b,0x5c,0x60,0xec,0xe5,0x1c,0x27,0xf9,
0x83,0x5d,0xfa,0xd4,0xff,0x1d,0xd4,0x2e,0x02,0x6f,0x12,0xfb,0xc5,0x48,0xd7,0x6f,
0x83,0xda,0x24,0x76,0x70,0xc4,0xc2,0x7e,0x3c,0x42,0xf6,0xce,0xc2,0xb6,0x8f,0xa4,
0xe4,0xee,0xd2,0x7f,0x3e,0x21,0xa8,0xd9,0x41,0x27,0x2b,0x0a,0xea,0x2e,0x8c,0x6d,
0x77,0xbe,0x3e,0xf2,0x26,0x7c,0x03,0x8d,0xb9,0x19,0x63,0xd2,0x5a,0x59,0x2a,0xda,
0x73,0x90,0x24,0xa4,0xf2,0x5e,0xfd,0x5e,0xe0,0xbd,0x8e,0x75,0x3e,0x8e,0x74,0x9c,
0xed,0xe2,0xb2,0x87,0xdd,0x3c,0xd3,0xca,0xcb,0x41,0x3d,0x53,0x32,0xea,0x20,0xbb,
0x67,0xd6,0xa0,0xee,0x04,0xd6,0x94,0x29,0x05,0xf4,0x01,0xd0,0x95,0x2f,0x8d,0xe1,
0x37,0xa2,0x2d,0x5f,0x0a,0xea,0x56,0x13,0xfe,0x7d,0xa8,0xdb,0x0b,0x7c,0x2b,0xf0,
0x77,0x01,0xff,0xac,0x69,0xfc,0x7a,0xb4,0x9d,0xc5,0xf8,0xe7,0xd9,0x18,0xfe,0x52,
0xd4,0xb5,0x02,0xff,0x3c,0x0b,0xe8,0xcd,0xd5,0xbd,0xba,0xb3,0xfc,0x29,0x9d,0x6c,
0x32,0xc2,0xbb,0x33,0x0c,0x7c,0xaa,0xe7,0x3a,0x15,0x22,0xdd,0x88,0x38,0x1d,0x9b,
0xf5,0xbf,0xfc,0x2d,0x76,0xce,0xca,0xed,0x52,0x28,0x5a,0x33,0x63,0xb3,0x96,0xf9,
0x95,0x51,0x4e,0x17,0xb2,0x70,0x58,0xea,0xe1,0x63,0x83,0xaf,0xa7,0x99,0x02,0x3e,
0xe7,0x04,0x74,0x0f,0x78,0x32,0x1e,0x72,0xba,0x13,0xfc,0xf8,0x36,0xf8,0x52,0xfc,
0x88,0xc4,0x88,0x3f,0x7b,0x51,0x3e,0x0f,0xfe,0xd8,0xce,0x2e,0xd6,0x52,0x20,0x0b,
0xd0,0x71,0x4d,0xba,0x35,0x14,0xed,0x03,0x9f,0xea,0x68,0x4f,0x61,0xb7,0x2c,0xc8,
0xf7,0x13,0xff,0xb8,0x3d,0xc2,0xfe,0xf3,0xf9,0xba,0xb5,0x7f,0x06,0x1d,0x64,0x43,
0xa9,0x6e,0x0f,0xc1,0xd5,0x46,0xfb,0x59,0x82,0x61,0x27,0x57,0x60,0xcf,0x49,0x36,
0x68,0xcc,0xb5,0xe0,0xfd,0x2f,0xfe,0x66,0x8c,0x47,0x75,0x23,0xb4,0x06,0x15,0xb2,
0xed,0x0c,0x84,0xc9,0x26,0xdc,0x43,0x7e,0x05,0xf6,0xd4,0xe6,0x21,0x5d,0x63,0xa5,
0x89,0x2a,0xb7,0x79,0xa3,0xbc,0xac,0xbe,0x3f,0xa4,0x40,0x47,0x3f,0x8d,0xc5,0xf6,
0xc0,0x47,0x02,0x0f,0xf6,0x3f,0x6e,0xdf,0xe0,0x6b,0x15,0xd8,0x09,0xb2,0x25,0x86,
0x0f,0x7c,0x73,0x28,0x81,0xf7,0x05,0x4e,0xf5,0x37,0xe3,0xd8,0xa6,0x60,0x8d,0xea,
0x1b,0x43,0x09,0x9c,0xb6,0x4e,0x2d,0x19,0xbc,0xe5,0x6b,0x01,0xcf,0xbe,0x45,0xf6,
0x73,0xd6,0x3e,0x9d,0xa9,0xef,0xf1,0xf8,0x60,0x1a,0xec,0xe2,0x64,0xd4,0x5f,0xcb,
0xaa,0xd3,0x11,0xb6,0x26,0xef,0x07,0x7f,0x2b,0x18,0xc9,0x74,0x75,0xea,0x54,0xf2,
0xab,0xea,0xef,0xf5,0xf5,0xc0,0x83,0xed,0xc8,0xda,0x4e,0x72,0x0f,0xdb,0x9b,0x29,
0x7c,0x13,0xc1,0xc8,0xd3,0x10,0x9e,0x67,0xc1,0xee,0x8e,0xfa,0x80,0x87,0x3d,0xcd,
0x5a,0x2b,0xf0,0x10,0xa6,0x27,0xcb,0x02,0x6f,0xbc,0x09,0x86,0x9f,0x4d,0xb6,0x0a,
0x98,0x7c,0xb7,0x34,0x1e,0x7c,0x62,0x7e,0xad,0x18,0x72,0x90,0x88,0x3d,0xa0,0xf5,
0x3d,0xc7,0x65,0x60,0x59,0xe4,0xd5,0x58,0xac,0x94,0x6c,0x84,0xf4,0x87,0x6e,0xed,
0x3c,0xf4,0xe8,0xc7,0xd8,0xcf,0xaf,0x28,0xc1,0x41,0xca,0x58,0xfc,0x4b,0x88,0xe9,
0x7f,0x86,0x34,0xfe,0x2d,0x43,0x0f,0xe6,0x7e,0xb8,0x58,0x7b,0x02,0x7d,0x53,0xb0,
0x9f,0xc9,0x4e,0xb2,0xbd,0xe0,0x2f,0xc6,0x4f,0xc2,0xf8,0x3b,0x51,0x2f,0xdd,0xda,
0xad,0x5d,0xc0,0x3c,0x49,0xb0,0x9b,0xa4,0xe7,0xdd,0x7f,0x33,0x6c,0x51,0x29,0xf1,
0x07,0xbc,0xcb,0x2c,0xee,0xd6,0x4f,0x83,0xfe,0x29,0xc8,0xcb,0xef,0x84,0xfe,0xc3,
0x0e,0x25,0x81,0x56,0xb2,0x15,0x90,0x85,0x08,0x8d,0x47,0x31,0xce,0x3a,0x1a,0xcb,
0x59,0xaf,0xc1,0x66,0x66,0x55,0xa2,0x1f,0x8d,0x91,0xa6,0xfe,0x5a,0x9f,0x2e,0xe6,
0xd8,0x6d,0x9a,0xc3,0x47,0x73,0xa8,0x24,0x77,0xa0,0x03,0x75,0x7e,0xd2,0xe5,0xc6,
0x40,0x98,0xf6,0x67,0x9d,0x98,0x3f,0x8b,0xd6,0x6b,0x27,0xdf,0x11,0x8a,0xc4,0x2e,
0x19,0xb2,0x46,0x70,0xb9,0x90,0xb5,0x04,0x21,0x6b,0x64,0x93,0x2a,0x61,0xcb,0x6f,
0x34,0xc9,0xda,0x62,0x4e,0x8b,0x4f,0x43,0x79,0x26,0xe1,0x22,0x7f,0x8f,0xf4,0x0b,
0x76,0x1c,0x5c,0x0a,0xa5,0xcf,0xfd,0xd0,0xb0,0x41,0x77,0x82,0x47,0x0b,0x91,0xec,
0x38,0x7f,0x6c,0x43,0x7e,0xe0,0x2d,0x83,0x8f,0xa4,0x7b,0x5e,0x1e,0x3f,0x52,0xdc,
0xda,0xad,0xcb,0x28,0xf7,0x29,0x47,0x22,0x12,0x97,0x2f,0xd8,0x21,0x63,0xdd,0xd1,
0x34,0x3e,0x67,0xb5,0x06,0x1b,0xfa,0x1a,0xf9,0x41,0xe0,0x6a,0x76,0x21,0x57,0x88,
0xa9,0xb2,0xec,0x42,0x87,0x6d,0x76,0xc3,0xee,0xe7,0x88,0x36,0x8a,0xab,0xe2,0xf5,
0x14,0x1b,0xbf,0x77,0xc9,0xa8,0x97,0x45,0xfd,0x0b,0xc0,0xc3,0xfa,0x46,0x6f,0x26,
0xfc,0xc6,0x1d,0x7a,0x5c,0xcf,0xae,0xe5,0xe5,0xcd,0xdc,0x1f,0x91,0x3f,0xcc,0xa9,
0x37,0xf6,0x38,0x0c,0xfb,0x26,0xff,0x01,0xba,0x0c,0x9b,0x44,0x3e,0x42,0x86,0x3e,
0xff,0x91,0xf3,0xac,0x5a,0x83,0x3c,0xbd,0x4d,0xfb,0x78,0xb0,0xcc,0xb0,0x59,0x2a,
0xe9,0x32,0xec,0x57,0x0b,0xc6,0x3f,0x58,0xb6,0x0b,0xfe,0xa3,0x8e,0xe6,0x4d,0x4e,
0x40,0xde,0x8c,0xf9,0x97,0xa2,0x7e,0x97,0x0b,0x7e,0x4d,0xdd,0x35,0x6c,0x51,0x36,
0x87,0x13,0xc7,0xd7,0x52,0xbc,0xf5,0x2c,0xfa,0xff,0x34,0x41,0x0d,0x3e,0x77,0x1f,
0x63,0xcf,0x6f,0x80,0x2c,0xd9,0x40,0xb7,0xc5,0xde,0x19,0x9e,0x00,0xba,0x7e,0x87,
0xb9,0x12,0xc8,0xfe,0xdf,0xd1,0xad,0xc9,0xe8,0x63,0xab,0x0e,0x84,0xa5,0x92,0x65,
0x7a,0x82,0x12,0x1c,0x26,0x9d,0x5a,0x82,0x71,0x17,0xa6,0x92,0x4d,0x9b,0x0b,0x9f,
0x5c,0x0b,0x79,0x0e,0x6e,0x55,0x61,0x1f,0x88,0xa6,0x3c,0xc4,0x50,0x32,0xeb,0x19,
0xce,0x43,0x79,0xfe,0x04,0xbf,0x56,0x02,0xb9,0xb4,0xc0,0x8f,0xa4,0x91,0xaf,0xb6,
0xbf,0x3b,0x94,0xec,0xac,0xd1,0x10,0x33,0xa6,0x67,0x53,0x2c,0xe5,0x0c,0x05,0x68,
0x1f,0x71,0x1c,0x4e,0x1e,0x87,0xf2,0xb5,0xf6,0x4e,0x19,0x81,0x6e,0x32,0xc5,0x59,
0xe3,0x78,0x9c,0xf3,0xae,0x9e,0x0c,0x38,0xd9,0x1e,0x4a,0xb7,0x72,0x5e,0xb2,0x51,
0x0b,0x5b,0x49,0xf6,0x25,0x4b,0xe6,0x7e,0x9f,0xc6,0x3c,0x36,0x44,0xb1,0xaa,0x8c,
0x58,0x1b,0x7e,0xaf,0xf4,0x20,0xb7,0xb5,0x15,0x9c,0x2e,0xec,0xbb,0x03,0xe3,0x94,
0x4a,0xf6,0x3a,0x3e,0x0e,0xe4,0xdb,0xc2,0xec,0x47,0x6d,0x88,0xdb,0x24,0x0b,0x8f,
0xa9,0x6b,0xa2,0x80,0x53,0xc1,0x8f,0x74,0x49,0x3d,0x9a,0x41,0x71,0x10,0xf9,0x4b,
0x59,0x69,0x0a,0x37,0x72,0x1f,0xd8,0x39,0x4c,0x7a,0xdf,0x07,0xbe,0x12,0xef,0x24,
0x13,0xef,0xfa,0x90,0x60,0x17,0x9e,0xaf,0xb4,0x5f,0xc9,0xbb,0xad,0xe0,0x1d,0xc7,
0x57,0x37,0x87,0x81,0xa3,0x13,0x0f,0xe3,0xfc,0x23,0xde,0xa1,0xaf,0x4d,0xfe,0xc3,
0x98,0xcf,0x7c,0x05,0x67,0xfa,0x7c,0x97,0xc4,0xbe,0xc2,0x59,0x7c,0xfa,0xfd,0x12,
0x3b,0xbf,0x80,0xe4,0xf4,0x94,0xce,0x60,0x37,0x0b,0xe8,0xac,0x10,0x22,0x7f,0xcd,
0xb2,0x2a,0x61,0xcf,0x8f,0x0b,0xb9,0x02,0x1f,0x92,0x4b,0x50,0xa6,0x98,0xf7,0x98,
0xa8,0x3b,0xbf,0xf5,0xf5,0x4c,0x8a,0x85,0xbf,0x8b,0xb2,0xf2,0x24,0xf4,0x0f,0x71,
0x32,0xc5,0xc2,0xab,0x51,0xce,0xc0,0x9e,0x64,0x60,0x3f,0xe4,0xc6,0x9e,0xe1,0xf9,
0x8b,0xb7,0x68,0x25,0xce,0xa0,0x66,0x71,0x06,0xc3,0xcc,0xbf,0x2d,0x6c,0xf1,0x6f,
0xd3,0x6e,0xa5,0x18,0x57,0xfd,0x37,0x7d,0x1c,0xe4,0x92,0xe2,0x71,0x69,0xc7,0xa3,
0x1a,0xce,0x04,0x7b,0x6c,0x71,0x3b,0xbc,0x63,0xcc,0x0e,0x67,0x0b,0x3b,0x9c,0x28,
0xe4,0xfd,0x9f,0xc4,0xfc,0xd0,0x99,0xe4,0x24,0xff,0xe6,0xf0,0x38,0xff,0x0a,0xf0,
0x01,0xf2,0xd7,0xb8,0x3b,0x0c,0x9a,0x16,0x26,0x8e,0x5f,0x4e,0xb4,0x1d,0xb7,0x2a,
0x2d,0xe1,0x24,0xfb,0xa3,0xe1,0x71,0xe8,0x77,0x27,0xfa,0xf8,0xa1,0xe3,0x7e,0x95,
0xce,0x75,0xc1,0xb0,0xc5,0xbe,0x73,0x58,0xb2,0x83,0x16,0x7b,0xd7,0x70,0xb2,0x6a,
0xe8,0xfc,0x5a,0x61,0x2b,0xef,0x07,0x2e,0xea,0xc0,0xf7,0x37,0x86,0x0d,0xff,0x50,
0xa9,0x63,0xbc,0x11,0x2b,0xfb,0x76,0xe4,0x14,0xf6,0x3b,0x01,0x6b,0x48,0x1c,0xbf,
0x82,0xe6,0x38,0x40,0xf8,0xd4,0x5f,0x62,0x95,0x5a,0x3e,0xfa,0x2f,0x41,0xdf,0x29,
0x74,0xf6,0x54,0x28,0xae,0xf3,0xc3,0x58,0x74,0x0d,0x53,0xdf,0x57,0x60,0x17,0xfe,
0xe5,0x2d,0x83,0xef,0xf1,0x3d,0x38,0x81,0xf2,0x3b,0x48,0xe7,0xcb,0x0d,0xfe,0xcb,
0xff,0xb6,0x58,0x23,0xfe,0xfb,0xe1,0x53,0x49,0x5f,0x21,0xb3,0x91,0x87,0xb1,0xae,
0x06,0xf8,0xcb,0xcf,0xbf,0x24,0xbf,0x59,0xad,0xad,0x47,0xf9,0x2c,0xf6,0x61,0x95,
0xe0,0xc1,0xf7,0xb9,0x3f,0x79,0x5f,0x77,0xa1,0x1f,0xd9,0x7d,0x8f,0xc8,0xbd,0xc8,
0x0f,0xe5,0xf4,0xda,0x5a,0x48,0x6e,0x49,0x9e,0x28,0x8e,0x21,0x7d,0x45,0x4e,0x67,
0xb1,0x03,0xd0,0x25,0x79,0x5c,0xb7,0x96,0x8b,0x71,0x28,0x27,0x9f,0xfc,0xea,0x97,
0x86,0x2d,0x5a,0x09,0x5b,0xc4,0x6d,0xc0,0xb7,0x42,0xd1,0x0f,0xbf,0x1c,0xf3,0xd1,
0x49,0x97,0x0c,0xbb,0x59,0xcf,0x63,0x0c,0x43,0xc6,0x26,0x80,0x46,0xf9,0xd1,0x6e,
0x6d,0x31,0xf9,0x5d,0xc4,0xe8,0xd6,0x46,0x7e,0xbe,0xbd,0x85,0x72,0x49,0x1d,0xe4,
0x3e,0x18,0xfe,0x77,0x4f,0x02,0xe7,0x31,0xf6,0x55,0x11,0xfb,0x6a,0xa7,0x7d,0xad,
0xe1,0xfb,0x2a,0xd9,0x49,0xa7,0x97,0x47,0x48,0xbf,0x12,0xa8,0x8d,0xd5,0x52,0xec,
0x12,0x51,0xb0,0x3e,0x9c,0x57,0xf8,0x99,0x95,0x6c,0x25,0x74,0x4c,0xe7,0x63,0x38,
0xaf,0xf4,0xd1,0xc0,0xd9,0xc3,0xd4,0xdf,0xe9,0xf7,0x61,0x2e,0xf2,0x9b,0x64,0xe3,
0xef,0xc7,0x7a,0x0e,0x12,0xed,0x4a,0xb5,0x96,0xc8,0x7d,0xeb,0x16,0x8d,0x74,0x8c,
0xd6,0xda,0x87,0x7d,0x1a,0x42,0x9b,0x7c,0x3b,0xd6,0xed,0x0f,0x84,0xe1,0x93,0x47,
0xa9,0x4f,0x19,0xfa,0xec,0xa0,0x3e,0x9e,0x6a,0xed,0x3a,0xce,0x57,0x92,0x81,0xb7,
0xb8,0x4c,0x50,0x6c,0x21,0xf3,0xab,0x60,0xd0,0xc1,0x2a,0x74,0x3a,0x03,0x50,0xdc,
0xcf,0xe9,0x66,0xec,0x31,0x9c,0x2f,0x75,0xa2,0xf7,0x53,0xa2,0xd7,0xb3,0x15,0xbe,
0xf7,0x5e,0x83,0x46,0xf5,0xdf,0x75,0xc5,0xb8,0x0b,0x48,0x4e,0xb0,0x93,0x5e,0x85,
0x22,0xcf,0x7f,0x69,0xf0,0x9c,0x9f,0x1f,0x11,0xc7,0x11,0xdf,0x5e,0x82,0x5c,0xf9,
0x11,0xd7,0xca,0xff,0x06,0x9f,0xdc,0xf9,0xfa,0xc8,0x8b,0xc7,0x19,0x1b,0x82,0x6c,
0x0c,0x22,0xfd,0x01,0xe9,0xcf,0x48,0x93,0x51,0x47,0x67,0x84,0x7c,0x92,0x0f,0xf2,
0x99,0x76,0xe3,0x1c,0x40,0x71,0x3b,0xdd,0x77,0xfc,0xec,0x4b,0xc3,0xef,0xb5,0x60,
0x9f,0xf2,0x4f,0x1a,0x67,0x80,0xeb,0xe9,0x61,0x07,0x0b,0x39,0xcf,0xe3,0x6c,0x9b,
0x37,0xab,0x57,0x7f,0xe0,0x43,0x23,0x66,0xcb,0x47,0xbc,0x47,0x7e,0xef,0x81,0xc2,
0x50,0xd4,0x4d,0x6b,0x6e,0xac,0xd6,0xee,0x94,0xd8,0x99,0x6b,0x11,0xb7,0xcf,0x41,
0x9e,0x04,0x3f,0x94,0x50,0xdd,0x15,0x4e,0x50,0x97,0xc1,0xd6,0x2c,0x83,0xce,0xcc,
0xd3,0xe4,0xe2,0x00,0xe8,0xaf,0x8b,0x16,0x4b,0x2c,0x2b,0x91,0xea,0xd0,0x46,0x75,
0x16,0x9c,0x55,0xa4,0x24,0x6f,0x54,0x2a,0x09,0xc8,0xe8,0x27,0xe7,0xa3,0x5d,0x12,
0xb6,0x17,0xb1,0x4c,0xd8,0x0a,0xbb,0xf8,0x25,0xd6,0x67,0xb1,0x2f,0x83,0x7f,0x5b,
0xa6,0x4b,0x79,0x5d,0x11,0x19,0xb0,0x84,0xf3,0x8c,0x44,0x79,0x3e,0xca,0xd8,0xd7,
0xa9,0xe8,0x77,0xad,0xc4,0x46,0x53,0xd4,0x0f,0xf4,0x09,0x9e,0x0f,0xf4,0x44,0x5f,
0x20,0x32,0x11,0xb0,0x65,0xc3,0xd6,0xc8,0x24,0xca,0x37,0x6e,0x8d,0x24,0x7a,0xc2,
0x91,0x95,0xc1,0x5e,0x4e,0x7b,0x8a,0xba,0x5b,0x5f,0x30,0x71,0x9b,0x46,0x3e,0x32,
0x58,0xbc,0x4d,0x5f,0x82,0x75,0xf8,0x8a,0x77,0xeb,0x52,0xe8,0x31,0xcd,0xe2,0xb9,
0x19,0x67,0xdb,0x7b,0xa3,0xfe,0xfd,0xdb,0x74,0x1c,0x0f,0x92,0xc9,0x6e,0x8a,0xfb,
0x8c,0xe7,0x5b,0x81,0xc3,0x61,0x35,0x20,0xb7,0x16,0x6f,0xb3,0xf9,0xf2,0x76,0xeb,
0x29,0x19,0xbd,0xfa,0x4f,0x66,0x60,0x7f,0xac,0xbd,0xfa,0xfd,0x18,0x87,0x6c,0x9c,
0xfc,0xfd,0xb7,0xb0,0xd7,0xd7,0x92,0xaf,0x4d,0x1e,0xb1,0x20,0xd6,0x4e,0xef,0xd5,
0x7d,0x79,0x3b,0x74,0xc9,0x83,0x7a,0x45,0xd6,0xd6,0xe6,0xf9,0x71,0x8e,0xf0,0x6b,
0x35,0xc0,0xff,0x39,0xf0,0x9d,0xc0,0x25,0xbf,0x72,0x18,0xb8,0xc7,0x09,0xb7,0x78,
0x07,0x6f,0x77,0xb2,0x74,0x8a,0x99,0x2c,0x90,0xe9,0xf4,0xf9,0xc0,0x3d,0x48,0xb8,
0x18,0x83,0xe8,0x83,0xbc,0x27,0x6f,0x9f,0xd9,0xab,0xef,0x05,0xfe,0xcf,0x27,0x04,
0x34,0x92,0x35,0x5f,0x71,0x8f,0x3e,0x07,0x78,0x3f,0x01,0x5e,0xa6,0xa7,0x5b,0xab,
0xe7,0xf2,0xff,0x7b,0x5d,0xb2,0xff,0xde,0xe0,0x1d,0xce,0x8a,0x73,0xa7,0x1b,0x77,
0x45,0x68,0x7b,0x8d,0x7c,0xef,0x75,0x80,0xe7,0x43,0xf6,0x0b,0xc8,0xf7,0x62,0x6d,
0x15,0x80,0x93,0x10,0x67,0x8e,0x43,0xbf,0x7c,0xd0,0x23,0xe7,0x05,0x78,0xbf,0x6d,
0xa0,0x89,0xfa,0x12,0xbf,0xc9,0xa6,0x6f,0xc3,0x1a,0xf2,0xf8,0xdc,0x7e,0x2d,0x1b,
0x73,0x6e,0xc6,0x9c,0x93,0xd1,0x27,0x03,0x7d,0xaf,0x65,0xbf,0xe7,0xfb,0x7b,0x0d,
0xca,0x32,0xce,0x98,0x2c,0x25,0x10,0xd9,0x31,0x8e,0x9d,0xbb,0x58,0x84,0x73,0x62,
0x36,0x74,0x03,0xf2,0xfe,0xc8,0x5d,0x38,0xdf,0xb1,0x40,0xf8,0x40,0x22,0x3b,0x37,
0x80,0xfa,0xed,0x79,0x74,0x8e,0xa8,0x8d,0x6c,0xb7,0x06,0x26,0x67,0x62,0x8c,0xeb,
0xa8,0x2f,0xe6,0xce,0x02,0x6c,0xc1,0x7e,0x5f,0x4f,0x39,0xf6,0x7b,0x37,0x70,0x77,
0x64,0xd0,0xbd,0x4d,0x4d,0x64,0x47,0x5e,0x60,0x32,0xce,0xe0,0xa3,0xa4,0x27,0x93,
0x29,0x76,0x16,0xf3,0x9b,0xe7,0xbe,0x96,0xf2,0x39,0x81,0x88,0x6d,0x3c,0xbf,0xbb,
0xe9,0x01,0x9f,0xf7,0xa4,0xa2,0xce,0x2e,0xf0,0xd2,0x04,0x5e,0xfa,0x55,0x78,0xd0,
0xd3,0x40,0x7e,0x6e,0xaf,0xbe,0xab,0xb8,0x4b,0x97,0x69,0x6e,0xc5,0xc0,0xb7,0x78,
0xb6,0x86,0x6d,0xd0,0x51,0xba,0x23,0xb9,0xa2,0x1e,0x34,0x3c,0x0b,0x9b,0x74,0x91,
0xfc,0x17,0xfa,0xbd,0xa4,0xf4,0x70,0x3e,0x3f,0x44,0x31,0x82,0xfd,0x03,0x3d,0x45,
0xf9,0x40,0x2f,0x39,0xda,0xc3,0xf7,0x61,0x22,0xca,0x17,0x80,0x47,0x72,0x3c,0x09,
0x30,0x97,0x63,0x7b,0x7e,0xd8,0xa2,0x4a,0x61,0x92,0xaf,0x22,0x2e,0x77,0xb0,0x31,
0x74,0x7e,0x08,0x0f,0xea,0x56,0xfb,0xa0,0x3e,0x31,0xa3,0x33,0x92,0x00,0x78,0x62,
0x66,0x67,0x24,0x91,0xf2,0x29,0x9d,0x11,0x4b,0xf8,0xe4,0x30,0xc5,0xfe,0x92,0xbd,
0x2d,0x9c,0x33,0x44,0xe7,0x8b,0x01,0xdd,0x16,0x1e,0xe0,0x71,0x55,0xce,0x08,0xce,
0xfd,0x53,0x60,0x17,0x51,0x4e,0x44,0xfd,0x47,0x74,0xa7,0x98,0x73,0x34,0xea,0x54,
0x8e,0x46,0x53,0x94,0xae,0x48,0x6e,0x46,0x28,0x92,0xa2,0xfc,0x1a,0x31,0xdb,0xaf,
0xf5,0xdc,0x4c,0xe3,0xbe,0x60,0x22,0xe0,0x49,0xa8,0xb3,0xda,0xfd,0x1a,0xdd,0xcb,
0xd9,0xfa,0x31,0xb7,0x32,0xa8,0x4b,0xec,0xfb,0x7a,0x0a,0xe8,0x4e,0x40,0x39,0x05,
0x34,0x27,0x52,0x4e,0x34,0x2b,0xfe,0x70,0xae,0x95,0xe2,0x54,0xcc,0xcb,0x06,0xf4,
0xdc,0x24,0x63,0x9c,0x04,0xc0,0x89,0xa8,0x93,0xd4,0x3a,0xed,0xcf,0xb1,0xd8,0x2d,
0x43,0xb0,0x31,0xc5,0x45,0x3d,0x5c,0x77,0xa6,0x52,0xac,0x84,0x73,0x62,0x26,0xe6,
0xb9,0x0e,0x69,0x1c,0x62,0xf0,0x2c,0xe4,0xd7,0x23,0x5e,0x9f,0x82,0x74,0x03,0xd2,
0x54,0xa4,0x6c,0x24,0xb2,0x25,0x16,0xfb,0xbb,0xc3,0x37,0xb0,0x0f,0xf4,0x29,0xe0,
0x1f,0xad,0x95,0x81,0x8e,0xa9,0x28,0xdb,0xe9,0x2e,0x0e,0xb4,0x64,0x03,0x66,0x9c,
0x96,0xce,0x30,0xad,0x69,0x0a,0xc6,0xba,0xc1,0xb4,0xa6,0xa9,0x80,0xb3,0x51,0x77,
0x0e,0xeb,0xcf,0x6c,0x0c,0x45,0x57,0x38,0x0d,0x1b,0xf0,0xe8,0x5d,0xc6,0x9d,0x83,
0x1d,0x3c,0xc6,0xd9,0x10,0xf1,0x62,0x28,0xc2,0xcf,0xda,0x28,0xdf,0xf4,0x05,0xc5,
0xc0,0xd5,0x91,0x2a,0xb5,0x77,0x32,0xf4,0x2f,0xfd,0x65,0x25,0x98,0x0a,0xdf,0x38,
0x4a,0xfe,0xd9,0xbf,0x9f,0xd6,0xf1,0x9d,0xa8,0xcf,0xd7,0x33,0x79,0xf4,0xab,0x58,
0x56,0x04,0xe7,0xdc,0x7f,0x88,0x9f,0x89,0xc4,0xdd,0xdc,0xb7,0x60,0x3b,0xe9,0xcc,
0xeb,0x40,0x7e,0x3b,0x52,0x39,0x52,0x3d,0x52,0xca,0x57,0xb1,0xd8,0x4d,0x50,0x3a,
0x27,0xfe,0x27,0xbb,0xea,0x16,0x36,0xf5,0xa7,0xd0,0x9f,0x29,0x4b,0x21,0x0f,0xf0,
0x23,0x41,0x6b,0x50,0x4f,0xc1,0x99,0xdd,0x02,0x7f,0xf1,0x24,0xdd,0x7b,0x4c,0x42,
0x6c,0x87,0x76,0x2b,0x72,0x6b,0x76,0xaf,0x1e,0x05,0x6d,0x0c,0x30,0x03,0x1c,0x06,
0x7c,0x61,0x62,0xaf,0x7e,0x71,0x6a,0xaf,0xfe,0x01,0xe0,0x11,0xc0,0xe7,0x01,0x9f,
0x01,0x3c,0x08,0x38,0x74,0xc3,0x2e,0xfd,0xf7,0x80,0xc3,0x80,0x0f,0x00,0x1e,0x04,
0x7c,0x1a,0xf0,0x7e,0xc0,0xa7,0x00,0xd7,0xd3,0xdd,0xa2,0x71,0x4e,0x4c,0x1e,0x40,
0xfd,0x00,0xfa,0xbe,0x83,0xfa,0x7e,0xc0,0xfd,0x80,0x8f,0x03,0x3e,0x0c,0xf8,0x30,
0xe0,0x37,0x00,0x1f,0x02,0x7c,0x08,0x30,0xd9,0xe8,0xbd,0x80,0xfb,0x00,0xff,0x12,
0xf5,0x07,0x01,0x1f,0x04,0x7c,0x98,0xc6,0x5c,0x82,0xf1,0x69,0x0e,0x94,0x0f,0xa1,
0x1c,0x02,0x1c,0x04,0xfc,0xcf,0xa6,0xf9,0xc8,0xee,0x6c,0x47,0xfd,0x76,0xd4,0xff,
0x0c,0xf5,0xee,0xa9,0x38,0x8b,0xd1,0x9d,0x24,0xdf,0x8b,0x1c,0x7d,0xc3,0x9d,0x58,
0x9f,0x69,0x6f,0xac,0x74,0x6f,0x07,0x98,0xf6,0xe7,0x97,0x9f,0xf3,0xb8,0x22,0xba,
0x02,0x7d,0x9b,0xc1,0x87,0x92,0xe5,0xdd,0xfa,0xd0,0xe7,0xb4,0x5f,0xa1,0x68,0x33,
0xf8,0xd4,0x65,0x83,0x3d,0x28,0x32,0xe6,0xb1,0x93,0x1e,0x29,0xbb,0xa0,0xbf,0x4d,
0xe1,0xfc,0x42,0x8a,0xf5,0xeb,0xe8,0xec,0xbb,0x27,0x6f,0x6a,0x2f,0xbf,0xc7,0xf9,
0x9d,0xe8,0xb7,0x1c,0xfd,0x4a,0xd0,0xa7,0x78,0x55,0x50,0x97,0x1c,0x81,0x68,0x49,
0x51,0x50,0xbf,0x08,0x1a,0x14,0x94,0x5f,0x6e,0x0c,0x46,0xfc,0x8b,0xc1,0x63,0x87,
0x31,0xe6,0x3c,0xf2,0xef,0x69,0xbb,0xc0,0x83,0x9a,0x68,0x36,0x9d,0xa3,0x91,0xe7,
0x89,0xf8,0x7c,0x16,0x64,0xfb,0x52,0x6a,0x50,0xcf,0x99,0x18,0xe4,0xbe,0xe5,0x69,
0x8c,0x9f,0x82,0x71,0x1d,0x6a,0x85,0x86,0xb9,0xe9,0xbc,0xff,0x98,0x03,0xeb,0x48,
0xc1,0xf8,0x67,0xc5,0x78,0x5f,0xdc,0x15,0x7a,0x99,0xee,0xab,0x56,0x0a,0xde,0x7c,
0x31,0x23,0x74,0x6c,0xa7,0xc5,0xd2,0x1f,0x2c,0xeb,0x7d,0xdf,0x0a,0x3c,0x6b,0x19,
0xf6,0x3d,0xb7,0x47,0x4f,0xb1,0xc3,0xe6,0x41,0xc6,0xad,0xb9,0x01,0x7e,0x26,0x64,
0xc8,0x11,0x6b,0x8c,0x5e,0x12,0xe3,0x5c,0x03,0x1a,0x86,0x00,0xab,0x80,0xd3,0x45,
0xec,0x16,0x6f,0x93,0x45,0x4c,0x42,0x77,0x5b,0xf0,0x67,0xa3,0xc4,0x13,0x2b,0xe8,
0xb2,0xc0,0xde,0xc2,0x47,0xed,0x21,0x5e,0x64,0xde,0xd0,0xab,0xef,0x04,0xbd,0x88,
0x79,0xa3,0x69,0xe0,0x87,0x2a,0xe8,0xa4,0x3d,0xa1,0xbb,0xae,0x8d,0x73,0xc0,0x83,
0x1c,0x6e,0xa3,0x29,0xa6,0xcf,0x22,0x9f,0x33,0x32,0x05,0xf1,0x10,0xea,0x7a,0xd1,
0xcf,0x86,0x3e,0x2b,0x80,0x73,0x1c,0x65,0x8c,0x1b,0x95,0xff,0xda,0xfb,0x34,0xc5,
0x76,0xca,0x7e,0xc6,0x3e,0x42,0xca,0xfc,0x29,0xd2,0x7e,0x7a,0x90,0x19,0x8a,0x1e,
0xcf,0x09,0xe8,0xe4,0xab,0xa6,0x57,0x41,0x96,0xa4,0x74,0xee,0xfb,0x42,0x29,0xbd,
0xfa,0x22,0xc8,0x02,0xd1,0x46,0xb4,0xde,0x33,0xa3,0x4b,0x9b,0x83,0x79,0x4f,0x80,
0xe6,0x81,0x9c,0x20,0xd7,0x7d,0x3a,0x97,0xc5,0xf9,0x36,0x1b,0x3c,0xeb,0x17,0xf0,
0x44,0xfe,0x1c,0x24,0x14,0x6d,0x04,0x3d,0x4e,0xc8,0xc8,0x5c,0xd0,0xb3,0x62,0x8a,
0xb1,0xc7,0xf7,0x7f,0xce,0xef,0xab,0xa2,0xa4,0x1f,0x74,0xc7,0xd7,0x8c,0x71,0x06,
0x30,0x26,0x62,0xc6,0xe8,0x71,0xe4,0x79,0x82,0x1f,0x24,0x23,0x5f,0x4c,0xaa,0x8b,
0x2a,0xe0,0x07,0xdd,0x83,0x9d,0x45,0x5b,0xa6,0x18,0xa3,0x0a,0x63,0xe0,0x0c,0x11,
0x3d,0x81,0x31,0x2e,0x8e,0xf1,0x3b,0xeb,0x2f,0x28,0x67,0xd0,0x5d,0x0b,0xfc,0xd1,
0xca,0x5b,0x69,0x2d,0xa9,0x14,0x27,0x24,0xa7,0xd8,0x77,0x82,0xe6,0x9d,0xdc,0x47,
0x81,0xdf,0xa5,0xb4,0xe6,0x13,0x58,0x33,0x3d,0x27,0xe9,0x4f,0xed,0xd1,0xd5,0x5b,
0x29,0xa6,0xae,0xe1,0xcf,0x48,0xcc,0xb8,0xd0,0xab,0x3d,0x16,0xc1,0x9f,0x94,0x7f,
0xe8,0xc5,0xda,0x9f,0xd6,0x13,0x29,0xde,0x00,0x2f,0x5f,0xa2,0x79,0xc0,0xc3,0xdd,
0x48,0xce,0xe7,0x18,0x6b,0x46,0xda,0x85,0x74,0x1c,0xe9,0x24,0xd2,0x79,0x82,0x73,
0x9e,0xd6,0x07,0x4b,0x7b,0xf9,0x1e,0xfd,0x4f,0x8c,0xed,0x83,0x4f,0x75,0xb2,0x34,
0xfe,0x8c,0x0a,0xe3,0xa6,0x87,0x30,0xc6,0xee,0xe2,0xa7,0xf5,0xbd,0x79,0x4f,0xeb,
0x07,0xef,0x36,0xf4,0x81,0xe8,0xf5,0xe7,0xed,0xe2,0x7d,0xfe,0xbb,0x11,0xef,0x8c,
0x0e,0x8a,0x35,0x3e,0x25,0xe4,0x86,0xee,0x7f,0xe9,0xbe,0x65,0x10,0x3c,0x69,0xfd,
0x1b,0x62,0x10,0xb2,0x93,0xd7,0x1b,0xf7,0x84,0xc3,0x17,0x63,0xe7,0x7e,0x88,0x3e,
0x0b,0x61,0x5b,0x7b,0x12,0x12,0xc2,0xcd,0x59,0xbd,0x7a,0xfc,0x99,0x07,0x9d,0xbb,
0xe6,0x7f,0x6e,0x9c,0x37,0x8a,0xe9,0x9e,0x49,0xdc,0x5b,0x42,0x59,0xde,0xa6,0x31,
0xe7,0x66,0x07,0xb5,0xa3,0x5f,0x8a,0x73,0xa2,0x84,0x3d,0xa1,0xfb,0x5c,0xbb,0xa1,
0x3b,0xcf,0x63,0x5c,0xd2,0xfb,0x95,0xe2,0xae,0x20,0xce,0xf3,0x84,0xc6,0x60,0xb8,
0x3f,0xef,0x77,0x7a,0x31,0xe8,0xa5,0xf8,0x7c,0x36,0x72,0xd8,0x6e,0xcb,0xc1,0x82,
0xa0,0x0d,0x67,0x58,0x1b,0xc9,0x52,0x81,0xd1,0xc6,0xcf,0xe0,0x34,0x06,0xda,0xf4,
0x0b,0xb7,0x60,0xbd,0x6a,0x70,0x98,0x6c,0xd7,0xc4,0x2f,0x8c,0x7b,0x88,0x03,0x8b,
0x60,0xb7,0x0a,0x8c,0xb5,0xd3,0x39,0xdd,0x4f,0x72,0x83,0xf6,0x9a,0x89,0xdd,0x5a,
0x1e,0xd6,0x41,0xf7,0x54,0x23,0xa0,0x83,0xca,0x04,0x3f,0xf3,0xb9,0x21,0x43,0xff,
0x7a,0x67,0x40,0x4b,0x12,0xf2,0x98,0x5e,0xb6,0x45,0xa3,0xf6,0x8b,0xd7,0x19,0x67,
0x40,0x8b,0x1a,0x0c,0x13,0xee,0x19,0xea,0x77,0x67,0x37,0xc7,0x4b,0x54,0x02,0xda,
0xd9,0xeb,0x0c,0x59,0x1a,0x44,0x7d,0xe9,0x17,0x63,0x63,0x6e,0x17,0x63,0x3e,0x72,
0x97,0x90,0x4b,0xd0,0x9b,0x4d,0x7b,0x8d,0x3d,0x4a,0xba,0xbd,0x97,0xef,0x1f,0xad,
0xe9,0x60,0x81,0xa1,0x7b,0x36,0xb1,0x97,0x14,0xaf,0x1d,0x2c,0x78,0x5a,0x1f,0x2a,
0xe9,0x15,0xf5,0x5d,0xf2,0x74,0x2e,0x7b,0x3d,0x90,0x27,0x7a,0x9e,0xb2,0x2a,0xcc,
0x75,0x55,0x09,0x3d,0x9b,0x8b,0xd8,0x35,0x97,0x9f,0x9b,0xe9,0x2e,0x66,0xab,0x7e,
0x12,0x72,0x45,0xfa,0x44,0x36,0xe9,0xa4,0x63,0x2b,0xe7,0x7b,0x39,0xe8,0xd8,0x8d,
0xb1,0x4e,0x4a,0x01,0xf2,0x85,0xd1,0xed,0x25,0xf4,0x1c,0x94,0x8d,0xde,0x81,0xfa,
0x93,0xd2,0x56,0x5d,0x19,0xd7,0xab,0xbb,0x38,0xad,0x4f,0x0b,0x5a,0xb7,0xea,0x38,
0xdb,0x44,0x4f,0x20,0x1f,0x2f,0xe8,0x5d,0x51,0xd2,0x7b,0x59,0xde,0x6c,0xdf,0x40,
0x0b,0x78,0xfc,0x5a,0x82,0xd0,0x85,0x7c,0xe0,0xa6,0x28,0x3d,0xfa,0x69,0xe8,0x03,
0xdd,0x7f,0x4c,0x83,0x9e,0x9c,0x4d,0xed,0xe1,0x7a,0x01,0x5a,0xcf,0x3c,0x02,0xfd,
0x3f,0x0d,0x3c,0xf7,0x92,0x6e,0x8d,0xe4,0x78,0x1b,0xec,0x05,0xce,0xdf,0x5a,0xe5,
0xec,0x5f,0xeb,0x79,0x64,0x93,0x20,0x6f,0x4e,0x47,0xb3,0x2e,0xa1,0xce,0x79,0x53,
0xb7,0x3e,0x6f,0xf5,0xaf,0xf5,0xf9,0x48,0xd7,0x95,0xd1,0xfd,0x25,0x62,0x10,0xe5,
0xbd,0x61,0x4f,0x66,0xaf,0xbe,0x01,0xfc,0x96,0x1a,0xb7,0xe0,0x2c,0xb7,0x3c,0xca,
0x70,0x7e,0xc7,0x39,0x2b,0x0b,0x3c,0x89,0xdc,0xc2,0xcf,0xe7,0x47,0x87,0x92,0x79,
0x3e,0xa0,0xd7,0xc0,0x07,0xed,0xbe,0xcd,0x78,0x9e,0x44,0xbe,0xc8,0x29,0x91,0xbd,
0x75,0x85,0x67,0x5c,0x34,0xce,0xae,0x1b,0x13,0x7b,0xf5,0x5a,0xac,0xa9,0xb5,0xd8,
0x78,0xae,0x6b,0x3c,0x13,0x35,0x6c,0x2b,0xc5,0x5b,0xc9,0x42,0xde,0x7c,0xa2,0x1d,
0xf6,0xe5,0x65,0xc8,0xe0,0xf3,0x16,0x53,0x9d,0x85,0xee,0x0d,0x31,0x5f,0x6b,0xb1,
0x5f,0x3f,0x7d,0xb3,0x71,0xae,0x1e,0x44,0x1e,0x97,0x05,0xe8,0xc8,0xe8,0xc5,0x1a,
0xc2,0x5d,0x16,0x9d,0xfa,0x80,0x5f,0xee,0x6a,0xf0,0xa7,0x59,0x1b,0xdf,0x87,0x4d,
0x5f,0x1e,0xbd,0x05,0xb6,0x61,0x26,0x72,0xec,0xf1,0x63,0xf5,0x03,0x3b,0xf4,0xd0,
0x6d,0xd4,0x7f,0x65,0x94,0xfa,0xee,0xc6,0x18,0xbb,0xaf,0xa5,0x3b,0xa0,0x50,0x2a,
0x8d,0x73,0x07,0xc9,0x9e,0xf0,0xa9,0x0e,0xf4,0x49,0x52,0x9e,0xd2,0x99,0xb3,0x13,
0x71,0x2b,0x3d,0x53,0xad,0x35,0xec,0x8e,0xfa,0x14,0xa7,0x49,0xc5,0x59,0x46,0x52,
0x2b,0x6d,0x7b,0xaf,0xa1,0x67,0x20,0x4f,0x61,0xcf,0x9f,0xd2,0xed,0xfd,0x4f,0xe9,
0xf5,0xf5,0x4f,0xea,0x0b,0x87,0x7b,0x39,0x2d,0x25,0x18,0x7b,0xa2,0x3d,0x94,0x6a,
0x61,0xdd,0x7f,0x22,0xde,0x16,0xa3,0xcc,0xfa,0xbb,0xf5,0x1c,0xcc,0xc3,0x9f,0xa9,
0x41,0xe6,0x99,0x32,0x00,0xdd,0x0a,0x68,0x53,0x6e,0x26,0xbb,0x62,0xe8,0xd0,0x85,
0x9b,0x0c,0x1d,0x4a,0x01,0xfe,0x35,0x26,0x3d,0xfa,0x2d,0xf5,0x03,0x4e,0x50,0xf0,
0x25,0x99,0xfb,0xe9,0x1d,0x97,0x6d,0x30,0xce,0x36,0x7b,0xfc,0xf5,0x7e,0x3d,0x88,
0x34,0x78,0x8d,0x71,0xc6,0x38,0xf7,0x19,0x9d,0x51,0x43,0xd1,0xef,0x41,0x06,0xcf,
0xcf,0x83,0x9c,0xe5,0x1a,0x7a,0x0b,0x9b,0x70,0xc6,0x2f,0x7c,0x27,0xfc,0x5e,0x72,
0x86,0x7a,0x65,0x5c,0xf7,0x64,0x76,0x90,0xc7,0xd1,0xf4,0xdc,0xa5,0x0f,0x63,0x38,
0xb9,0xdf,0xab,0x8e,0xd4,0x27,0x74,0xd3,0x33,0xb8,0xe4,0x3f,0x7f,0x46,0xfb,0xbb,
0x43,0xdf,0x86,0xbc,0xf5,0x1a,0xe3,0xb9,0x03,0xe9,0xe9,0x28,0xca,0xd5,0x98,0x2b,
0x88,0xb9,0x28,0xde,0xf8,0x36,0x68,0x5f,0x08,0xdb,0xe4,0xc7,0x7a,0x9d,0xb5,0x41,
0xbe,0xae,0x7e,0xe0,0xcc,0x99,0xdd,0xab,0xcf,0x99,0xdd,0xad,0x37,0x09,0x5d,0xff,
0xf6,0xd4,0x6e,0x3e,0x3f,0xf1,0xbe,0x12,0x73,0xd2,0x7d,0x1b,0xdd,0x4d,0x0d,0x7c,
0x46,0xe7,0x75,0x63,0x5e,0x3a,0x4b,0xfe,0x96,0xe6,0x55,0x77,0xf0,0x58,0xfd,0xdb,
0x16,0x96,0x95,0x87,0xb9,0xea,0x67,0xef,0xd3,0x33,0x96,0x19,0xef,0x0a,0x50,0x0c,
0x38,0x82,0xf3,0xb4,0x53,0x7a,0x8a,0xdb,0x4c,0x28,0xc9,0x19,0x77,0xa1,0x71,0x67,
0xdd,0x9f,0x86,0x73,0x73,0x6a,0x57,0xb8,0xdf,0x9e,0x8a,0xd8,0x96,0x69,0x35,0xb9,
0x74,0x8f,0x94,0x16,0x3d,0x2b,0xd1,0x7d,0x45,0x05,0xce,0xf5,0xdd,0x9a,0x9c,0x1f,
0x8a,0xd6,0x83,0xae,0x8d,0x98,0x47,0x42,0x7f,0xba,0x9f,0x1e,0xc4,0x18,0xfd,0x0e,
0x63,0xdf,0xc9,0x3e,0x92,0x0d,0x38,0xeb,0xd8,0x0c,0xfe,0x6e,0xd6,0x36,0x4c,0x86,
0xff,0xff,0xcc,0x88,0x87,0xd2,0x40,0x8b,0xcc,0x7d,0xad,0x81,0xfb,0xa6,0xc4,0x5e,
0xdb,0x58,0x0c,0xdd,0x70,0x56,0x6a,0xa4,0xb3,0xfd,0xd0,0xcb,0x0c,0xd3,0xf3,0x94,
0xc3,0x92,0x78,0x9e,0xc2,0x8c,0x3b,0x1c,0xca,0xe3,0xcf,0x51,0x2e,0xf2,0x3b,0x96,
0xaf,0x3f,0x23,0x89,0xdf,0xcd,0xd9,0xd4,0xc6,0x30,0x9d,0x9d,0x9e,0x97,0xe8,0x6e,
0x88,0xdf,0x9d,0xc1,0xff,0x9f,0x84,0xae,0xd5,0x45,0x7f,0x8a,0x73,0x7d,0x5c,0x8e,
0x15,0xf0,0xfd,0xbd,0xf8,0x5a,0x1a,0x43,0x91,0x1f,0x03,0x3f,0x73,0xd6,0x3e,0xe8,
0xeb,0x7b,0xfa,0x0a,0x8c,0xb5,0x07,0xb8,0xb2,0x87,0x9e,0xa3,0xdc,0x1b,0x7d,0x1a,
0xf0,0x14,0xf1,0x5c,0xa5,0x02,0xe3,0x54,0xd3,0x7d,0x1f,0xf4,0x86,0x62,0xa3,0x1d,
0x12,0x2b,0x9d,0x69,0xdc,0xf7,0xec,0x29,0x47,0xfe,0x3a,0xda,0xe6,0x22,0x7f,0x0c,
0x7d,0xca,0xb0,0xe6,0x79,0x80,0xcf,0xa0,0xee,0x3d,0xd8,0xa3,0x7a,0xa2,0x01,0xf0,
0x72,0xe4,0x5d,0x92,0xa1,0xdf,0x35,0x2f,0x74,0x6b,0xab,0x1e,0xef,0xd6,0x52,0x42,
0x8f,0x69,0x56,0xff,0x36,0xad,0x02,0x6b,0x97,0x41,0xd3,0x0f,0xc0,0x7b,0x45,0xd0,
0x43,0x72,0xf9,0x20,0xf0,0x69,0x7e,0x9a,0xd3,0x8b,0x39,0x1d,0x62,0xce,0xef,0x20,
0x6f,0x47,0x5b,0x3e,0xce,0xee,0xe5,0x90,0xa9,0x46,0xd8,0x36,0x92,0x25,0xb2,0x3b,
0x16,0x45,0x46,0x39,0xa0,0x37,0x67,0xc0,0x87,0x62,0xad,0x74,0x77,0xf0,0x02,0xd9,
0xed,0x1b,0x7b,0xf5,0xfa,0x8c,0x9d,0xdc,0x36,0x36,0x62,0x1e,0x31,0x56,0x56,0x73,
0xf1,0x4e,0xbe,0x3f,0xf7,0xa1,0x6e,0x97,0x80,0x57,0x00,0x66,0xe8,0xd7,0x87,0xb3,
0xf9,0x69,0x8c,0x71,0x10,0xb0,0x15,0xf0,0xfb,0x80,0x6b,0x40,0xeb,0x90,0x8c,0x98,
0x2d,0xad,0x57,0x3f,0x85,0xf2,0x0e,0xb4,0x5d,0x02,0xfc,0x59,0x2c,0xc6,0xd7,0xb0,
0x48,0xac,0x41,0xe6,0xfe,0xfe,0x3d,0xdd,0x61,0xaf,0xc1,0xd9,0x32,0x94,0xde,0x0e,
0x1f,0x3d,0x17,0x7d,0x37,0xe0,0xec,0x3d,0xe8,0x30,0xce,0x71,0xb2,0x27,0x64,0x81,
0xaf,0x4c,0x9e,0x23,0x19,0x7e,0xa5,0x1a,0xb2,0x26,0xab,0x0b,0xb4,0x24,0x11,0xaf,
0x54,0x82,0xee,0xe9,0x20,0x5e,0x45,0x9a,0x83,0x54,0x89,0x54,0x85,0x54,0x8f,0xf4,
0x0a,0xd2,0x49,0x24,0xf6,0x33,0xc6,0xec,0x33,0x0d,0x3b,0x98,0x82,0x9c,0xc6,0x98,
0x4d,0x3e,0x1b,0xf0,0x97,0xa0,0x89,0x21,0x87,0x8c,0x8c,0x5e,0x2a,0x32,0x68,0xa4,
0xbb,0xc6,0x0b,0x45,0x3c,0xee,0x88,0x14,0xdb,0xf6,0x71,0x7c,0xed,0x53,0xe3,0xae,
0x8e,0x9e,0x35,0x9c,0xc6,0x99,0xba,0xde,0xb8,0x47,0xa0,0x38,0x3a,0x3d,0x99,0xee,
0x4e,0x30,0xde,0x17,0x93,0xb8,0xef,0x79,0x9b,0x3f,0xa3,0x96,0xe5,0x70,0xb9,0xb0,
0x43,0xb4,0xf6,0x62,0x5b,0xb7,0xfe,0x17,0x8c,0x91,0xc9,0xdf,0x9d,0x08,0x45,0x4b,
0x6c,0xfb,0xf8,0xf8,0x27,0x50,0xb7,0x0d,0xe3,0xad,0xb0,0x06,0xf4,0x54,0xb4,0x6d,
0xec,0xc4,0xd8,0xe2,0xfe,0x87,0xee,0x8c,0x09,0xb7,0x15,0xb4,0xcc,0x11,0xf8,0x44,
0xcb,0x2f,0xd1,0xa7,0xd9,0xba,0x4d,0xb7,0x89,0xb1,0x9c,0xa2,0xed,0x5f,0x50,0x3f,
0x07,0x63,0xad,0xc4,0x58,0xd5,0x09,0xfb,0x74,0xf1,0x1c,0x26,0xf9,0x72,0x7c,0x90,
0x4a,0xef,0x19,0xf1,0x78,0x30,0x99,0xdf,0xa7,0xf3,0x77,0x70,0x58,0xf2,0x5a,0x92,
0x77,0xcf,0x56,0x2d,0x81,0xdd,0x1b,0xf9,0x69,0x2c,0xf6,0xda,0x45,0xd5,0x88,0xb9,
0x06,0xa1,0x7f,0x1f,0x62,0x0e,0x5a,0xc7,0x47,0xa9,0x86,0x8d,0x7d,0xf6,0x53,0xd2,
0x0d,0x23,0x4e,0xa3,0xf3,0xe2,0x69,0xd4,0x57,0x62,0xaf,0xf7,0x7d,0x6a,0xc4,0xbf,
0x37,0xc0,0xe6,0xc6,0xd7,0xdd,0x8e,0x71,0x7f,0xc3,0x0c,0xb9,0x3d,0x41,0xb1,0x37,
0xc6,0x5d,0x21,0xf8,0x86,0x63,0x6a,0xb2,0x32,0x0d,0x34,0x2a,0xef,0xea,0x0e,0xa5,
0x56,0x1b,0x60,0xec,0x6e,0x8a,0xe7,0x8f,0x82,0x7f,0xf5,0xf0,0xc1,0xc1,0x23,0x86,
0x7d,0xb2,0x2a,0x5d,0x69,0x34,0x1e,0x7f,0xaf,0x09,0x63,0x7a,0xe8,0x5e,0x58,0x39,
0x3b,0x0c,0x1e,0x5b,0x26,0xa9,0xa1,0xf4,0x3d,0x98,0xb7,0x51,0x82,0x8c,0x0b,0xfd,
0x7d,0x00,0xfb,0x57,0xa2,0xd2,0x39,0xca,0x90,0x1f,0x6c,0x7f,0x56,0x36,0x68,0x3a,
0x48,0x67,0x04,0xd4,0xb7,0x8a,0xf9,0xa1,0x07,0x72,0x6b,0x5e,0xc0,0xd6,0x5a,0x4c,
0xe7,0x08,0x9a,0x27,0x64,0x79,0x16,0xb8,0x4f,0x93,0x1f,0xc5,0xd9,0x7a,0xf5,0x71,
0xe3,0x3e,0x9c,0xee,0xc5,0x83,0x80,0x1f,0x45,0x9a,0xf8,0x2b,0xc6,0x7e,0x88,0xbc,
0x1b,0xe9,0x59,0xa4,0x7f,0x46,0x7a,0x03,0xe9,0x38,0xd2,0x19,0xa4,0x0f,0x91,0xce,
0x23,0x7d,0x82,0x74,0x01,0xb8,0x13,0xe8,0x1d,0x0e,0xa4,0x1b,0x91,0xa6,0x21,0x35,
0xa3,0xfe,0x0e,0xe4,0xd5,0x48,0x6b,0x91,0x76,0x63,0x1e,0x2f,0xf2,0x19,0xeb,0x19,
0xfb,0xc1,0xaf,0x8c,0x67,0x74,0x9d,0x34,0x07,0xb5,0x21,0x85,0x90,0x7e,0x82,0xf4,
0x1c,0xd2,0xcf,0x90,0x5e,0x44,0x3a,0x8c,0xf4,0x1b,0xa4,0xf7,0x91,0xfe,0xf8,0x2b,
0xba,0x3b,0xad,0x4f,0x65,0x52,0x7d,0xea,0x4a,0x8c,0xdd,0x87,0xf2,0x47,0x48,0x2e,
0xc0,0x9f,0x52,0x9b,0x5c,0x9f,0x3a,0x84,0xdc,0xf6,0x36,0x68,0x47,0x0a,0x6d,0x91,
0x58,0x26,0xf2,0x6c,0xa4,0x99,0x48,0xb7,0x21,0xdd,0x83,0x74,0x1f,0xd2,0x06,0xa4,
0x1d,0x48,0xcf,0x21,0xfd,0x2b,0xd2,0x49,0xa4,0x28,0xd2,0x28,0x52,0xff,0x1b,0x58,
0x03,0xc6,0xfc,0xcb,0xdb,0x34,0xdf,0x0f,0x2a,0x2d,0xef,0x30,0x36,0x1e,0x29,0x0d,
0xe9,0xda,0x77,0x0c,0xfe,0x4c,0x45,0x1e,0x7f,0x6e,0x43,0xcf,0x6c,0x6e,0x45,0xb9,
0x08,0xa9,0x14,0xa9,0x1c,0xe9,0x9f,0x90,0xaa,0x90,0x96,0x21,0x7d,0x07,0xa9,0x09,
0xa9,0x15,0x89,0xee,0x29,0xe8,0x19,0x1f,0xf1,0xbc,0xe3,0x1d,0xe3,0x3e,0xc3,0xca,
0x5e,0xd3,0xe9,0xac,0x4e,0xcf,0xb0,0xad,0xd8,0xdf,0x6a,0xf8,0x2b,0x2b,0x3b,0x70,
0xf9,0xf9,0xf5,0xed,0xe4,0x53,0x20,0xaf,0xb2,0xba,0x55,0xb3,0xf0,0x3b,0xca,0xba,
0x53,0xf4,0x0c,0x0a,0x67,0xc8,0x97,0xff,0x02,0xf9,0xa5,0x3a,0x15,0x5b,0x32,0x05,
0xf2,0xd5,0xe8,0xcf,0xd6,0x59,0xe3,0xbb,0xba,0xc5,0x13,0x8a,0x0c,0x3d,0xb3,0x5b,
0x1f,0x72,0x6d,0xd3,0x57,0xc5,0xf5,0x81,0x91,0x3e,0x54,0x47,0x47,0xa4,0x6d,0x36,
0xd2,0x89,0xdd,0x16,0x76,0x6e,0xc4,0x9e,0xad,0xdf,0x6c,0x45,0x2e,0x6d,0xd3,0x71,
0xb6,0xd0,0xec,0x18,0x8b,0xec,0xef,0x5f,0x11,0xcf,0x1d,0x64,0xd9,0x90,0x2b,0x23,
0x96,0x48,0x51,0x77,0x4c,0xbe,0xe4,0xf0,0x4f,0xa6,0xb3,0x42,0x3c,0x56,0xa3,0xfb,
0x0d,0x8a,0xa1,0x52,0xf9,0xb9,0xb8,0x0e,0xf1,0x1e,0xdd,0xdf,0xfa,0x6d,0xd4,0x6e,
0x13,0xcf,0xc9,0xe9,0x8c,0x76,0x41,0xcd,0x86,0x1c,0x06,0x28,0x2e,0x18,0x8d,0x85,
0x92,0xb5,0x64,0xb6,0x9c,0xdf,0x75,0x36,0xa6,0x66,0xf3,0xfb,0x21,0x8a,0x43,0x86,
0x3e,0x89,0x9d,0x23,0xdb,0x4c,0xef,0x6b,0x91,0xcf,0xab,0xf8,0x2a,0x56,0x4a,0x7e,
0x9b,0xe6,0xf9,0x35,0xd6,0x56,0x52,0x93,0xad,0x1f,0x67,0x86,0xcf,0xc6,0x16,0xff,
0x5f,0x7d,0x76,0x3f,0x1b,0xf3,0xd9,0xf4,0x2e,0x04,0xf9,0xec,0x27,0x3e,0x19,0xf3,
0xd9,0x87,0x30,0x86,0x52,0x64,0xf8,0x61,0xe3,0xdc,0xbd,0x19,0x3a,0x9f,0xad,0x3f,
0xf7,0x89,0xe1,0xab,0x6f,0x26,0x1b,0xef,0xc8,0xe6,0xb1,0xb4,0x92,0x7b,0xa5,0x5f,
0x7e,0x2e,0xfe,0x9e,0x83,0x78,0xb6,0x62,0x6b,0xbc,0xd2,0x2f,0x27,0xfc,0x07,0x7e,
0x39,0xee,0x8b,0x6d,0xea,0x6a,0xee,0x9f,0x7b,0xe8,0xfd,0x13,0x19,0x7c,0x80,0x7d,
0xf9,0xc3,0x27,0xc6,0x99,0xed,0x71,0xb2,0x61,0x90,0x07,0x0b,0xdb,0xc2,0x75,0x3c,
0x09,0x3c,0x1c,0xfd,0x84,0xec,0x0d,0x3f,0xe3,0x25,0x13,0xce,0x66,0xf4,0xcb,0x84,
0x1d,0xdc,0x9d,0x96,0xad,0x1f,0x13,0xfd,0xfc,0xc4,0xd3,0xa2,0x6c,0xbd,0x24,0x17,
0xb1,0x7f,0xce,0x51,0xf2,0x65,0xa3,0x99,0xee,0x7d,0xfa,0x21,0xe0,0xd0,0xf3,0x94,
0x7f,0x11,0x78,0xd3,0xe2,0xb6,0x48,0x7d,0x57,0x9f,0x25,0xd6,0xbf,0x5b,0xf4,0xa3,
0x7b,0xcc,0x12,0xac,0x77,0x9d,0xb0,0x83,0x64,0x83,0x2e,0xa0,0xff,0x46,0xf4,0x55,
0x84,0xef,0x2f,0x16,0xf1,0xf9,0x6c,0xe4,0x4d,0x22,0x3e,0xcf,0x98,0x99,0xad,0x9f,
0xcd,0xcd,0xd6,0x33,0xd3,0xb3,0x11,0x2f,0xef,0x1c,0xa6,0x38,0xe7,0x23,0x8c,0x99,
0x87,0x72,0x1f,0xce,0x58,0x17,0x01,0x9f,0x67,0xc6,0x3b,0x2d,0xb0,0x47,0xc7,0x96,
0xd1,0x9e,0x16,0xd1,0x39,0x3a,0x3d,0x8a,0xf8,0x3f,0xeb,0x56,0x8c,0x5f,0x2d,0x9e,
0xfb,0xd4,0xa3,0xcf,0xe3,0x82,0xd6,0x7b,0x30,0x4f,0x71,0x13,0x68,0x2b,0xfa,0x11,
0xc7,0x5d,0x00,0x5c,0xa7,0x4a,0x77,0x49,0x5b,0x74,0x05,0xeb,0xcf,0x9b,0xbc,0x4f,
0x7f,0x09,0xf6,0x4e,0x59,0xbf,0x4f,0xdf,0x66,0xc9,0xe6,0xcf,0x43,0x1f,0xfd,0xe4,
0xf2,0xb3,0xf7,0x64,0x6a,0x4f,0x46,0xdc,0x05,0x1d,0x1a,0xa5,0xb6,0x03,0xc0,0xe9,
0xfc,0xc4,0x78,0x76,0x47,0xfe,0xe6,0x15,0x94,0x1f,0x11,0xf8,0xf4,0x2e,0x47,0x63,
0xde,0x8f,0x78,0xfc,0x30,0x16,0x37,0x6c,0xe1,0x7e,0xe0,0x34,0x68,0xca,0x83,0x4f,
0x2b,0x05,0xee,0x8d,0x18,0x6b,0x48,0xcc,0xd5,0x26,0xfa,0x92,0x3e,0x35,0x17,0xff,
0x88,0xcb,0xd3,0xf5,0x80,0x6f,0x20,0x19,0xb1,0x1a,0x38,0x6e,0x81,0x43,0x77,0xe9,
0x19,0xa2,0xae,0xf1,0x13,0xe3,0x19,0x0f,0xc5,0xd6,0x79,0x56,0x63,0xff,0xef,0x13,
0x78,0xf4,0x0c,0x22,0x49,0xfd,0x9d,0xde,0xcc,0x7d,0x00,0xcb,0x2a,0x2e,0xce,0xe6,
0xfe,0xa9,0x38,0xd7,0xd0,0xa1,0x6a,0x81,0xbf,0xd4,0xb4,0xce,0x38,0x2f,0x5e,0xfc,
0x64,0x4c,0x87,0x56,0xc4,0xc6,0x74,0x08,0x3a,0x7a,0x66,0x63,0x5e,0xb6,0x9e,0x5f,
0xb3,0x93,0x9f,0x3d,0x26,0x90,0x0e,0x61,0x9d,0x6f,0xe4,0xd2,0x33,0x30,0xbf,0x26,
0xe7,0xf8,0xc3,0xfd,0x4a,0x9a,0x9e,0x5d,0x6d,0xd3,0x6a,0x97,0x41,0x9e,0xab,0x27,
0x6b,0x36,0xa1,0x43,0xa4,0x3b,0x12,0x62,0xf5,0x1a,0x7e,0xe7,0x00,0x1f,0x5c,0x4d,
0xfa,0x64,0x8c,0xbb,0x11,0xe3,0x0c,0x36,0x63,0xdf,0xa5,0x1f,0xf1,0xbd,0xcd,0xf9,
0x4f,0xe8,0x66,0xa6,0x69,0x5c,0x3a,0x4f,0x54,0x21,0xa7,0xf3,0x65,0x0a,0x6c,0x94,
0x0b,0xe7,0x52,0x3a,0x5f,0xd0,0x99,0x94,0xeb,0x6e,0xbe,0x71,0x47,0xc9,0x9c,0xdd,
0xfa,0xfb,0x17,0x0c,0x1d,0x20,0x9e,0x64,0xa8,0xc6,0xfc,0x2b,0xa6,0x65,0xdb,0x5e,
0x52,0xb7,0xf0,0x67,0xf9,0x74,0x6e,0x9c,0xc4,0x76,0x25,0x3d,0xda,0xbe,0x45,0x9e,
0xc4,0xb6,0x24,0xd5,0xdf,0xb4,0x8f,0xfb,0xbe,0x49,0xa0,0x69,0xc3,0xac,0x6c,0xdd,
0x2a,0x7c,0xe4,0x78,0xb1,0xf6,0x63,0x69,0xc6,0xda,0xa5,0x54,0xbf,0x41,0xa3,0x6a,
0xd1,0x6a,0x66,0x12,0x8d,0xe9,0x9c,0xa7,0xf4,0x6e,0x43,0x3d,0xce,0xc0,0x7b,0x3e,
0x33,0xce,0x10,0xd4,0xf7,0x26,0xf4,0x1d,0x70,0x43,0xd6,0x99,0xb1,0xde,0xdc,0xff,
0xc4,0x7a,0xaf,0x13,0xeb,0x25,0x9f,0x7d,0x5d,0x41,0x37,0x5f,0x37,0xe9,0x35,0xad,
0x9d,0xfa,0x2d,0x44,0xb9,0xed,0x82,0xf1,0xac,0x17,0xba,0xf4,0xf6,0x04,0x6e,0x5f,
0x42,0x91,0x1c,0xec,0xe5,0x79,0xb6,0x45,0x1f,0x87,0x72,0x7c,0x0e,0xba,0x37,0x4c,
0x51,0x73,0xf5,0xaa,0x6b,0xb2,0xf5,0xef,0x5e,0x30,0xf6,0x9f,0xde,0x69,0x24,0xfc,
0xe0,0x85,0x31,0x3a,0xe9,0xfc,0xd6,0x3a,0x3f,0xfb,0xf2,0x3b,0x6a,0x69,0xff,0x09,
0x3a,0xc7,0x7d,0x83,0xcd,0x9c,0x7b,0xe1,0xb2,0x8c,0xbd,0x4d,0x63,0x3d,0xc5,0x69,
0x0a,0xea,0xc7,0xe7,0x93,0x9f,0xa1,0xb1,0x97,0x47,0x37,0x7c,0x11,0x4b,0x1e,0x04,
0x3d,0x83,0x09,0xd9,0xfa,0xbd,0x17,0x0c,0xfb,0xf9,0x7b,0xe0,0x3d,0x6d,0xba,0xbf,
0xa7,0x77,0x6f,0x7e,0x59,0x80,0x7d,0xa4,0xe7,0xe8,0xb0,0x97,0x14,0x3f,0x53,0x2c,
0x97,0x07,0xfc,0xfd,0x88,0x47,0xfd,0x4a,0x80,0x3f,0xf3,0xb6,0xda,0x9f,0xe5,0xf7,
0x67,0x88,0x53,0xb3,0xb6,0x21,0xbe,0xa6,0x67,0x71,0xa1,0xb2,0x4e,0x7d,0x1b,0xf2,
0xfd,0xc8,0x83,0xc8,0x0f,0x20,0xa7,0x98,0x8c,0xde,0xfb,0xba,0xf4,0xb1,0xc1,0x37,
0x7a,0x8f,0xeb,0x14,0xbf,0x97,0x7a,0x99,0xde,0xd9,0xe1,0x71,0x16,0xdd,0x57,0x81,
0xf7,0x59,0x14,0x67,0xb6,0x8a,0xe7,0xf0,0x0f,0xd1,0xd9,0x7c,0x66,0xaf,0xcd,0xae,
0xf4,0xd0,0x3b,0xce,0x16,0xbb,0x12,0xa0,0xbb,0xad,0x51,0xba,0xef,0xa0,0xe7,0xbe,
0x09,0xf4,0x5c,0x92,0xde,0xdd,0xa5,0xf7,0xe4,0xa4,0x1f,0x0d,0x2b,0xa0,0x2f,0x03,
0x73,0x5e,0xca,0xa5,0xf7,0xbd,0xba,0x86,0xad,0x2a,0xc5,0x9e,0x01,0x8d,0xe6,0x90,
0x84,0x7f,0x1e,0xa6,0xbb,0x0f,0xc7,0x96,0x70,0x7c,0x8c,0x0f,0xe0,0x93,0xe9,0x2c,
0xb0,0x6e,0x46,0x28,0x1a,0x46,0xac,0x38,0x00,0x1a,0x4f,0x1e,0xed,0xd5,0x0f,0x51,
0x9c,0x8f,0xfa,0xc1,0x5c,0x7a,0xbf,0x2f,0xc0,0x9f,0x2f,0xa6,0xa8,0x3d,0xc3,0xd3,
0x30,0xc7,0x0f,0xc1,0xaf,0x7e,0xd9,0xe0,0xc9,0x21,0xb1,0xa6,0x42,0xec,0x59,0x1f,
0xf0,0x27,0x41,0xf7,0xc3,0x1f,0x1b,0xef,0x07,0x8e,0x07,0xee,0xde,0x22,0x7a,0x67,
0xc0,0xd0,0x1d,0x7a,0xa7,0x68,0x02,0xd6,0x99,0xcc,0x6a,0xd3,0x19,0x7f,0x67,0xfe,
0x88,0xcd,0xaa,0xec,0xe3,0xf7,0x2d,0x06,0x8d,0x75,0xf0,0x23,0xac,0xd4,0x6a,0xa7,
0xd8,0xf3,0x14,0xd7,0x87,0x7f,0x07,0xbd,0x2b,0x31,0x6e,0x3d,0xe8,0x58,0x81,0x39,
0x6d,0x18,0xf3,0x7b,0x98,0x9f,0xe2,0x5a,0x7a,0xcf,0x8f,0xe2,0x10,0xed,0x63,0xc3,
0x57,0x5a,0x8b,0x7a,0xdf,0x00,0x2f,0x8e,0xd5,0xe7,0x05,0xde,0xa0,0xfb,0xc5,0x7f,
0xe0,0xf6,0x7e,0x1f,0x3f,0x4b,0x16,0x62,0xed,0x0f,0x51,0x6c,0x02,0x1d,0x22,0xba,
0xa9,0xdf,0xe0,0xc7,0xfc,0x19,0x0f,0xbd,0x07,0x71,0xe6,0x78,0x39,0xf8,0x86,0xf8,
0x3c,0x53,0x0d,0xea,0x32,0x6c,0x06,0xdd,0x21,0xbc,0x52,0x33,0x10,0x99,0xc4,0x7a,
0x46,0x8a,0xfb,0x83,0x5a,0x5e,0x98,0xde,0x05,0xdd,0x3e,0x32,0x89,0x3d,0x3e,0x42,
0x67,0x8c,0x57,0x1d,0x03,0x11,0x79,0x4e,0x85,0xf6,0x6a,0xd1,0x40,0xc4,0x36,0x27,
0xa0,0xbd,0x3a,0x73,0x20,0x32,0x80,0x58,0x97,0xde,0x31,0xf1,0x7e,0x6c,0xc8,0xa1,
0x53,0x0a,0xea,0xf7,0x32,0xf6,0x5a,0x4d,0x76,0x50,0xdb,0xff,0xb1,0x61,0x43,0xeb,
0x40,0x43,0x0d,0x7f,0xaf,0xf4,0xf0,0x48,0xc2,0x9f,0x29,0x7f,0x61,0x84,0x60,0x73,
0x9e,0xc8,0xf6,0x8e,0x4c,0x53,0xe9,0x5d,0xf1,0xc7,0x47,0xfc,0x8e,0xa0,0xbe,0xbd,
0x26,0xc8,0xef,0xb4,0xc9,0x8e,0xa6,0x28,0xdb,0xb5,0x43,0xf1,0xf1,0xc9,0xbf,0xd0,
0x5d,0x37,0x78,0x52,0x85,0xb9,0x37,0xcb,0xec,0x5c,0xce,0xa7,0x46,0xdb,0x1c,0xb4,
0x7d,0x8c,0xfa,0x67,0x3f,0xa1,0x3b,0x87,0x50,0x24,0x7d,0x6a,0x50,0x5b,0x2b,0xda,
0xe8,0xfd,0x51,0x87,0x78,0x7f,0xed,0x84,0x3d,0xa8,0xad,0x12,0xf5,0xf4,0x1e,0xea,
0xad,0xa2,0x7e,0x01,0x68,0x5e,0x29,0xea,0x33,0x81,0x0f,0x3f,0xfc,0x1a,0xc9,0x71,
0x18,0xf8,0xcb,0x45,0x3d,0xbd,0x57,0x9a,0x4d,0xf5,0xe0,0xe7,0xbd,0xa0,0xc9,0xae,
0xd2,0x33,0x91,0x74,0x2e,0xbb,0xf1,0xe7,0x3c,0x87,0x58,0xef,0x64,0x24,0xdb,0x7c,
0xb4,0xd3,0xbb,0x49,0xa9,0x18,0xe3,0xd5,0xd4,0xc1,0xc8,0x2f,0xf2,0x07,0x23,0xbf,
0xb9,0x70,0xd9,0x97,0x65,0x2d,0x74,0xf6,0xea,0xbb,0x70,0x06,0xe0,0xed,0x69,0x83,
0x91,0x97,0x95,0x5d,0x91,0x37,0x2f,0x5c,0xf6,0x31,0xf4,0x5e,0x46,0xf4,0xd5,0xf4,
0xc1,0xc8,0x4b,0x85,0x83,0x91,0x7e,0x51,0x4f,0x3f,0x8f,0x2c,0x80,0x9d,0x7f,0xe4,
0x63,0xe3,0xfe,0xc6,0xf8,0xb9,0x9d,0xf1,0x6e,0x1a,0xc5,0xac,0x87,0x90,0x1e,0x46,
0xdc,0xda,0x85,0xf4,0x43,0xa4,0x43,0x05,0x88,0x77,0x61,0x1c,0x76,0x01,0x7e,0xf6,
0x1d,0xe3,0xbd,0xd4,0x3e,0xaa,0xaf,0x93,0xd8,0x80,0x88,0x6f,0x37,0x31,0x26,0x4d,
0x7e,0x25,0x16,0x3b,0x81,0xf2,0xc5,0x1d,0x88,0xe5,0x29,0x0e,0xc6,0x01,0x69,0x2a,
0xff,0xa9,0x46,0x4d,0xb4,0x93,0xec,0x4e,0xbf,0x12,0x66,0x76,0xd7,0x5c,0x49,0xa9,
0xd1,0x3c,0xfc,0xbc,0xd6,0x17,0x61,0x6a,0xe3,0x5c,0xfa,0x9d,0x40,0x3b,0xce,0xf7,
0x32,0x4b,0x8d,0xd0,0xbb,0x35,0xe9,0x33,0xda,0x23,0xa9,0x93,0xda,0x23,0xb2,0xe2,
0x0c,0x67,0x2b,0x1d,0x5a,0x97,0xd2,0x65,0xa7,0x77,0x40,0xe4,0xbf,0x3e,0x41,0x79,
0xa4,0x73,0x52,0x1d,0xfd,0x4e,0x23,0xdc,0x79,0x57,0x85,0x22,0x09,0x58,0x02,0xdc,
0x39,0x51,0xd4,0xdf,0x89,0x7a,0x01,0x4b,0x80,0x3b,0x27,0x88,0xfa,0x32,0xd4,0x0b,
0x58,0x02,0xdc,0x99,0x22,0xea,0xe7,0xa0,0x5e,0xc0,0x12,0xe0,0xce,0xf1,0xa2,0xfe,
0x0e,0xd4,0x0b,0x58,0x02,0xdc,0x99,0x2c,0xea,0x4b,0x51,0x2f,0x60,0x09,0x70,0xe7,
0x38,0x51,0x7f,0x3b,0xea,0x05,0x2c,0x01,0xee,0x4c,0x12,0xf5,0x25,0xa8,0x17,0xb0,
0x04,0xb8,0x33,0x51,0xd4,0xdf,0x86,0x7a,0x01,0x4b,0x80,0x3b,0x13,0x44,0xfd,0x6c,
0xd4,0x0b,0x58,0x02,0xdc,0x69,0x13,0xf5,0xb3,0x50,0x2f,0x60,0x09,0x70,0xa7,0x55,
0xd4,0x17,0xa3,0x5e,0xc0,0x12,0xe0,0x4e,0x8b,0xa8,0x9f,0x89,0x7a,0x01,0x4b,0x80,
0x3b,0x65,0x51,0x5f,0x84,0x7a,0x01,0x4b,0x80,0x3b,0x25,0x51,0xef,0x40,0xbd,0x80,
0x25,0xc0,0x9d,0x4c,0xd4,0xab,0xa8,0x17,0x30,0x7c,0x87,0x42,0x77,0xa7,0x8c,0x35,
0xce,0x35,0x7e,0x2f,0x33,0x27,0x32,0x06,0x87,0x66,0x9e,0x98,0x44,0xbf,0x0b,0xf0,
0x5b,0xa8,0x9c,0x8a,0x7d,0xcc,0x56,0x56,0xf1,0xdf,0x9e,0xcc,0x94,0x43,0x26,0x3c,
0xf8,0x1a,0x29,0x7c,0x4c,0x96,0x42,0x2f,0x7b,0xe8,0x0e,0xc4,0x78,0x27,0x29,0xd9,
0x02,0xff,0xb1,0x3e,0x06,0xdb,0xe2,0x7c,0x7d,0x64,0x27,0xb3,0x84,0x2d,0xf6,0xf2,
0x30,0xe1,0xcb,0x92,0xa2,0x91,0x8c,0xca,0xa9,0x39,0x9a,0x5f,0xe9,0x8b,0x74,0xaa,
0x7d,0xa9,0x16,0x56,0x94,0x3a,0xf7,0xc4,0xf9,0xd4,0x0a,0x24,0xe8,0x6c,0x32,0x3d,
0xaf,0xbe,0x71,0x4e,0x47,0xd8,0xa2,0x74,0xf5,0x4b,0x76,0x05,0x47,0x83,0x1c,0x23,
0x57,0x9b,0x5e,0xba,0x8e,0x9e,0x9d,0xc7,0x66,0x74,0xca,0x92,0x3d,0x2a,0xdb,0xfc,
0xd1,0x98,0xb5,0x9f,0xe8,0x4f,0x93,0xa5,0xd4,0xa8,0x3c,0xb9,0x33,0x1a,0xcb,0x38,
0x82,0xb3,0xbf,0x2b,0x0d,0x63,0x46,0x6e,0x14,0x31,0x41,0x8d,0x65,0x47,0x58,0x51,
0x9b,0xb4,0xd4,0x74,0xc4,0xf7,0x0e,0xa6,0x41,0x8c,0xbf,0xc3,0xec,0xdf,0x07,0x1d,
0x61,0x4d,0xb6,0x55,0x53,0x7c,0x51,0x2a,0x59,0xf9,0x3b,0x7a,0xa5,0x21,0xd6,0x17,
0x71,0xd9,0xe9,0xf7,0x42,0x5d,0xda,0x57,0xb0,0xbd,0x05,0xf4,0x7e,0x83,0x54,0x13,
0xed,0x1a,0x0f,0x7e,0xb1,0x7e,0x8b,0x85,0xf9,0xe9,0x37,0x44,0x91,0x4e,0x7b,0x1f,
0xe7,0xa1,0x6c,0xb3,0x47,0x69,0x8e,0x4f,0x60,0xa3,0xed,0xbf,0x6d,0x8f,0x24,0xf5,
0x57,0x69,0x29,0x4a,0x6d,0xd8,0x9e,0x12,0x8a,0x74,0x8d,0xf7,0x87,0x98,0xb2,0xea,
0x25,0xf4,0x79,0x46,0x95,0x03,0x2f,0x1a,0xfc,0x2a,0x02,0x9d,0x39,0x98,0x57,0x91,
0xe9,0x8c,0x8f,0x3d,0x48,0x7b,0x3f,0x16,0x1b,0xed,0xc4,0x19,0x04,0x3c,0x88,0x10,
0x0f,0x28,0xc6,0x24,0xfa,0xf9,0xf3,0x4a,0xe0,0xc3,0xe6,0x48,0xd4,0x57,0x62,0x2a,
0xcd,0x99,0x0e,0x38,0x35,0x66,0x4d,0xe3,0xef,0xaa,0xfa,0x41,0xaf,0x2c,0xf9,0x6f,
0xe4,0xbc,0xcd,0xdb,0x89,0x71,0xfd,0x45,0x80,0x1d,0xb4,0xce,0x4d,0xd6,0x00,0xe7,
0x11,0xb5,0xcd,0xcd,0x3f,0x8f,0xfe,0xa1,0xd4,0x8a,0x39,0xe7,0x25,0xd8,0xfe,0x54,
0x7f,0x1e,0x78,0x5f,0xdc,0x87,0xfd,0x55,0x25,0xc9,0xe6,0x4f,0x17,0xbf,0x93,0xa2,
0xfb,0xa1,0x51,0xd9,0x61,0xd7,0x68,0x7f,0x59,0x7f,0x1f,0xad,0x55,0xba,0xa7,0x38,
0xc0,0xef,0x53,0x48,0x6f,0x27,0xf1,0xdf,0x95,0xec,0xe0,0xf5,0xfc,0xbd,0x0c,0x53,
0x59,0x76,0xa4,0x1a,0xbc,0x65,0x1e,0xf8,0x97,0x88,0x26,0xa1,0x3f,0xeb,0x0f,0xd1,
0x7c,0xa8,0x0e,0x59,0xee,0xc3,0x38,0x90,0x51,0x59,0x9e,0x55,0xa1,0x4d,0x81,0x3c,
0x25,0x29,0xb5,0x5a,0xd7,0x1d,0x15,0x61,0x7a,0x8f,0x38,0xb5,0x28,0x10,0xb6,0x1f,
0x0d,0x45,0x14,0xc8,0x98,0x2c,0xad,0x8c,0xaa,0xf2,0xb3,0x9c,0xdf,0x44,0x97,0x82,
0xbd,0x48,0x15,0x6d,0xdb,0xd9,0x8e,0x88,0x03,0x6d,0x07,0x27,0xf5,0x73,0x9e,0xc4,
0xfa,0x43,0xd1,0xd0,0xad,0x53,0xc2,0xcf,0xdc,0x31,0xc5,0x9e,0x02,0x39,0x4a,0x61,
0x33,0x53,0xef,0x24,0xfe,0x29,0x5d,0x61,0xb2,0x51,0x7e,0x2b,0xd6,0x99,0xd1,0x97,
0x4a,0xcf,0xc0,0xe5,0x99,0xc0,0x95,0x03,0x91,0x67,0xd2,0x02,0x91,0x1d,0x8e,0xce,
0xb0,0x2c,0xa5,0x80,0x5f,0xb0,0x67,0xf6,0x90,0xe3,0xd9,0xec,0x4e,0x47,0x40,0x0d,
0x39,0x20,0xef,0x91,0x4d,0xca,0x51,0xed,0x6f,0x46,0x1c,0xfa,0x98,0x2c,0xd5,0x5d,
0xde,0x7b,0x63,0xff,0xd4,0xa8,0x7c,0x24,0x45,0xeb,0xcc,0x08,0x49,0x21,0xeb,0xf6,
0xc8,0x33,0x56,0xc2,0xaf,0xd5,0x62,0x6a,0xc7,0x51,0xec,0xf7,0x11,0xe0,0x1c,0x21,
0x9e,0x73,0x5e,0xa2,0x7e,0x16,0x7c,0xf0,0x75,0xac,0x03,0x3a,0xc2,0xde,0x45,0xdb,
0x29,0xc8,0x83,0xe6,0x87,0xec,0x38,0xd2,0x8c,0xf5,0xd0,0x9a,0x5d,0x8c,0xcb,0x92,
0xb6,0x5d,0xed,0x89,0xc4,0xd7,0xc5,0xe5,0xe4,0x08,0xd3,0xfc,0xd8,0x7b,0xc8,0x98,
0x05,0x32,0x26,0x23,0xc6,0x4a,0x4e,0x01,0x7d,0x8c,0xcd,0x44,0x9b,0xa4,0x81,0x6e,
0xb4,0xa5,0x5a,0x20,0x43,0x46,0x9b,0xbd,0x33,0xd2,0x0f,0x59,0x7a,0xe6,0x8e,0x94,
0x30,0x78,0x11,0x21,0x5e,0x90,0x1f,0x92,0x8f,0x9c,0x04,0xfe,0xa9,0xf4,0x3f,0xf1,
0xdf,0xd3,0x29,0x58,0x37,0xd3,0x2e,0xaf,0x45,0x52,0xd3,0x49,0xbe,0x18,0x73,0xa4,
0xcb,0x92,0x23,0x7d,0x02,0x7f,0xf6,0x59,0xc4,0xdf,0xd7,0x25,0x19,0xa1,0x77,0x7a,
0x31,0x0e,0xc9,0x62,0x16,0xe4,0x85,0xcb,0x10,0xff,0xbd,0x9d,0x18,0x67,0x93,0xd5,
0x7f,0x59,0xc6,0x08,0xb6,0x08,0xf8,0x9b,0xf6,0xa5,0x94,0xef,0xcb,0x5c,0xbe,0x2f,
0xd8,0x93,0x88,0xdf,0x1a,0x8a,0x4c,0x21,0x1d,0x2d,0x0a,0x45,0x73,0xb0,0x27,0x4a,
0x51,0x20,0x42,0x7b,0x42,0xf6,0x89,0xf6,0xe2,0x11,0xe5,0x27,0x9a,0xfc,0x06,0xc9,
0x64,0x5d,0x84,0x6c,0x15,0xd6,0x9e,0xf3,0x0c,0xe0,0x67,0x00,0x1f,0x04,0x9c,0x03,
0xfb,0x96,0x03,0xdb,0x96,0x2f,0xa1,0x1e,0xf0,0x33,0x80,0x0f,0x02,0xb6,0x14,0xf5,
0x45,0xf2,0x8f,0xf6,0xa5,0x9e,0xc7,0x7a,0x69,0x1f,0xf7,0xd1,0x3b,0x92,0xe8,0x67,
0xde,0x47,0xda,0x43,0xda,0xbf,0x4d,0xca,0xce,0xbf,0xbb,0x77,0x4f,0xd0,0x5d,0xeb,
0xff,0xe3,0x3e,0x0c,0x98,0xf6,0xc1,0x26,0x78,0xf9,0x2a,0xfd,0xa6,0x0a,0xbc,0xfc,
0x99,0xf1,0xbb,0x46,0x7a,0x67,0x71,0x94,0xca,0x16,0xc1,0xdb,0xa7,0xf9,0xbb,0x9a,
0x88,0xb5,0xe9,0x1e,0x5a,0xec,0xd9,0x87,0xc0,0x95,0x73,0x4e,0x46,0x7f,0x42,0xb9,
0xe3,0x54,0xf4,0x71,0xe4,0xfb,0xd1,0xee,0x47,0xbc,0xbb,0xc9,0x5a,0x4b,0x67,0xab,
0xd2,0x1f,0x83,0xde,0xdc,0xfc,0xba,0x70,0x22,0x3d,0xb3,0x2f,0x26,0x1b,0x07,0xbd,
0x87,0x7d,0x14,0x76,0x3a,0xcd,0xfc,0x5b,0x48,0x17,0x64,0x31,0xbe,0xb7,0xb4,0xa7,
0xc0,0x83,0xbe,0x85,0x2d,0x66,0x1c,0x19,0xb6,0x9b,0x9e,0x31,0xd5,0xfd,0x35,0x76,
0x4e,0x46,0x1c,0xc1,0xdf,0x6f,0xf6,0xc3,0x26,0x7a,0x30,0x36,0xce,0x02,0xfb,0x43,
0xbd,0xfa,0xc7,0xe7,0x63,0xe7,0x42,0xf6,0x5e,0x3d,0x39,0xf4,0x04,0x78,0xfa,0x44,
0x98,0xed,0xf8,0x6e,0x78,0xd1,0x93,0x7d,0x91,0xf3,0x5b,0x5f,0x4f,0xa2,0xdf,0x17,
0x32,0x75,0x8f,0x4e,0xef,0x6a,0xd2,0xd9,0x99,0xee,0x8c,0xa4,0xea,0x45,0x1a,0xfd,
0xe6,0x73,0x1c,0xbd,0xe3,0x5a,0x6d,0xa3,0xf7,0x8c,0xa7,0xd3,0xb9,0x96,0x9e,0x3d,
0x59,0xfb,0xaf,0xc4,0x95,0xd1,0x7f,0x8e,0xc0,0x25,0x3c,0xab,0x63,0xcf,0xf0,0x95,
0x63,0x05,0xf9,0x58,0x32,0xc5,0xef,0x47,0xae,0x6c,0x8b,0xf7,0xfb,0x2b,0xce,0xd2,
0xfc,0xbd,0xe1,0x6d,0x8c,0x51,0xa2,0x75,0x65,0xd2,0xef,0x89,0x14,0xe3,0x37,0xad,
0x32,0xfd,0xa6,0xd5,0x4e,0xef,0xe0,0xd1,0xef,0xdd,0x76,0x4e,0xd6,0xcf,0x63,0x2f,
0x1e,0x05,0x07,0x98,0xf1,0x3b,0x68,0xfa,0x6d,0xaa,0x64,0xfc,0xc2,0x5d,0x4a,0x4d,
0xb3,0xa7,0xb3,0x86,0x45,0x95,0x75,0x65,0xd3,0xd6,0xe7,0xe7,0x4e,0xf3,0xe6,0x8e,
0xfd,0x33,0xa1,0xbc,0xfe,0x96,0x8a,0xa5,0x4b,0xe6,0x2f,0x5a,0x50,0xc6,0x5a,0x3c,
0x3e,0xd7,0xaa,0x56,0xb7,0x57,0x29,0xa8,0x56,0x16,0x2d,0xa9,0x5e,0x56,0xaf,0x94,
0x57,0x54,0xcc,0xab,0xae,0x57,0xee,0x50,0xc6,0x9a,0xe6,0x5f,0x51,0xf2,0x29,0x6d,
0x2e,0x1f,0x2a,0x99,0xaf,0xc9,0xc3,0xbe,0x56,0x5d,0xae,0x54,0xd7,0xce,0xab,0x5d,
0xba,0xac,0x7e,0xd1,0x92,0x05,0x4a,0x81,0x47,0x99,0xe6,0x55,0x72,0x94,0x02,0xaf,
0xe2,0x28,0xba,0xad,0x50,0xc5,0x7f,0x0e,0xa5,0xa0,0xa0,0xd9,0xd3,0xde,0xe1,0x53,
0xa6,0x35,0x2b,0x05,0xdf,0x55,0x2a,0x97,0x94,0xd7,0xa3,0xca,0xd7,0xae,0x94,0x4e,
0x6b,0x66,0xd3,0x6e,0x5b,0x5f,0xaa,0x4c,0x2b,0xbc,0xc5,0x9b,0xcc,0x2a,0x17,0xd5,
0x55,0xe4,0x97,0x57,0xd5,0x2e,0xce,0x9f,0xd6,0xc4,0xe6,0xad,0x58,0x54,0xcf,0x69,
0x67,0x56,0xd6,0xe6,0xf6,0x79,0x7d,0x34,0x55,0x6b,0x9b,0xb2,0x51,0x71,0xaf,0xe9,
0x70,0x7b,0x94,0xdc,0x07,0xd6,0x37,0x7b,0x36,0x3e,0x00,0x8a,0x72,0x51,0xe7,0x75,
0x37,0x2b,0xb9,0xde,0x32,0xe5,0x3e,0xe5,0xfe,0x5b,0xca,0x94,0xb2,0x35,0x54,0xd7,
0xb4,0x1e,0x3d,0x9a,0x95,0x9b,0xf1,0x5f,0xc1,0x6a,0xc5,0x91,0x5f,0x3c,0x86,0xa7,
0x72,0xc2,0xd4,0xd2,0xb2,0xb2,0x5c,0xe5,0x4e,0x85,0xcd,0xf0,0xad,0xf3,0x50,0x9a,
0xa6,0xce,0x6e,0x36,0xad,0xaf,0x5c,0xf0,0xa7,0xa0,0x45,0x71,0xf9,0xd6,0xaa,0x62,
0x6d,0x97,0x17,0xe3,0xe5,0x8b,0xa9,0x5d,0x5a,0xcd,0x2a,0xee,0x99,0x35,0x6b,0xd6,
0xec,0x86,0x69,0xdf,0xd8,0xd9,0xa3,0x80,0xd0,0xcb,0xbd,0x08,0x91,0xfa,0x55,0x2d,
0x05,0xaf,0x0a,0x5a,0xdb,0xd7,0x14,0x78,0x3a,0xdc,0xab,0x5b,0x36,0x28,0x58,0xaa,
0x92,0xcb,0x9a,0xd7,0xb9,0xbd,0x6b,0x40,0xa7,0xb1,0x44,0xaa,0x42,0xc1,0xe7,0x6a,
0x69,0x55,0x0a,0x1c,0x97,0x29,0x9d,0xe6,0x2d,0xc4,0x90,0xac,0xc0,0xd5,0xda,0xca,
0x9a,0xd6,0x7b,0x7d,0xed,0xeb,0x4a,0xbd,0x6e,0xaf,0xb7,0xa5,0xbd,0xad,0xa1,0xa5,
0x99,0x25,0xa3,0x57,0x19,0xa8,0x63,0x2e,0x8f,0xa7,0xb5,0xc5,0xcb,0x3c,0x1d,0xed,
0xab,0x5b,0x40,0x12,0x13,0x38,0x5e,0x36,0xa3,0xd9,0xe5,0x73,0xcd,0x30,0x7a,0x16,
0x36,0xb5,0xb7,0xad,0x6e,0x59,0xe3,0xc5,0xa0,0x33,0x0c,0xb0,0x70,0x5a,0x61,0x89,
0xb7,0xb0,0xa5,0xad,0x85,0xd1,0xae,0x94,0xb2,0xaa,0x79,0x95,0x65,0xf9,0xd3,0x9a,
0x8d,0xff,0xd9,0xbc,0xba,0xfa,0x6a,0xca,0xcb,0x17,0xd5,0xce,0xa5,0xbc,0x62,0x71,
0xf9,0x3d,0x94,0x57,0x56,0xd4,0xd5,0xe7,0xab,0x1b,0xa6,0xa9,0x25,0x1b,0x44,0xc6,
0x96,0xcf,0x2d,0xaf,0xa7,0xa6,0x86,0xc5,0xe5,0x0b,0x58,0xbe,0x9a,0xaf,0xb2,0xea,
0xc5,0x4b,0x2b,0xe7,0x95,0xe5,0x17,0x4d,0x58,0x8c,0x9d,0x46,0x9e,0x5f,0xa4,0xe2,
0x7f,0x55,0xcd,0x9f,0x89,0x7f,0x58,0x45,0x7d,0x6d,0x15,0x9b,0xcd,0x0a,0xe2,0x6b,
0xe2,0xf4,0x1b,0x1f,0xa0,0xa0,0x75,0x89,0x5a,0xb1,0x1c,0xaa,0x79,0xb0,0xa5,0xd9,
0xdd,0x5e,0xda,0xd4,0xde,0xec,0x6e,0x6a,0x58,0xed,0xf1,0xb2,0xa2,0x59,0xa2,0x8a,
0xff,0xdb,0xc0,0x1b,0x98,0xa3,0xe8,0x76,0x51,0xbb,0xce,0xb5,0xa1,0x61,0x55,0x8b,
0xaf,0xc3,0xe5,0x73,0x33,0xc7,0x2c,0x4c,0x68,0x54,0x8b,0xaa,0x86,0x26,0x5f,0x47,
0x6b,0xc3,0x3a,0xf4,0x61,0xb3,0x8b,0x59,0xb3,0xdb,0xe7,0x6e,0xf2,0x95,0x1a,0x59,
0x83,0xef,0x61,0x8f,0x9b,0xcd,0xa4,0xaf,0x6a,0xf8,0x3a,0xda,0x5b,0x4b,0x45,0xde,
0xd0,0xea,0x7e,0xd0,0xdd,0xca,0xd6,0xb8,0xdb,0xdc,0x1d,0xae,0xd6,0xd2,0x36,0xd7,
0x83,0xc4,0xd7,0x86,0x66,0xf7,0xba,0xf6,0xaf,0x55,0xb6,0x7b,0x7c,0x9c,0xf5,0xea,
0x06,0x95,0x16,0xac,0xaa,0x0e,0x56,0xb5,0x74,0x69,0x75,0xbe,0x83,0x2d,0xaa,0x9c,
0xb7,0x1c,0xac,0xe1,0xb2,0x5f,0x55,0xbe,0xa4,0xd2,0x80,0x6a,0xe7,0x55,0x2c,0x25,
0x2d,0xa8,0x58,0xba,0xf8,0xde,0x4a,0x28,0xad,0xcc,0x2a,0x1a,0xea,0x2a,0x58,0xd5,
0xa2,0x25,0xf7,0xe4,0x17,0x38,0x98,0xc4,0x99,0xc5,0xb7,0x05,0x7c,0x33,0x14,0x7b,
0x4c,0xdb,0xb1,0x19,0xf3,0x17,0x40,0x00,0x0c,0x9c,0x59,0x40,0x99,0xa6,0x16,0xad,
0x60,0xb5,0xf3,0xe6,0xa3,0xc7,0x7a,0x56,0x5d,0xb1,0xb8,0x72,0x9a,0xb7,0x0c,0x73,
0x5f,0xde,0x56,0xfc,0x0f,0x7c,0x4e,0x51,0x81,0x23,0xc7,0x00,0xf8,0x48,0x7c,0x42,
0xc7,0x95,0x6c,0x5d,0xeb,0x6a,0x6b,0xc3,0xba,0x1d,0x33,0x55,0xb6,0xde,0xeb,0xee,
0x58,0xd5,0xbe,0xa1,0x54,0xe4,0x0d,0x4d,0xeb,0x9a,0x2f,0x73,0xa9,0x7d,0xbd,0xaf,
0xb9,0xbd,0xbd,0xe3,0x72,0x79,0x75,0x6b,0xcb,0x9a,0xb5,0xbe,0x86,0x87,0x5a,0x7c,
0x6b,0xd1,0xd4,0xe0,0x5d,0xeb,0x26,0xf1,0x15,0x8d,0xee,0xf5,0xad,0xee,0x8e,0x06,
0x57,0xdb,0x1a,0xec,0x2c,0xf6,0xe9,0x6b,0xac,0x7e,0xf0,0x07,0xdf,0x58,0xfd,0xb0,
0xeb,0xa1,0xcb,0x75,0xae,0x56,0x5f,0x8b,0x6f,0x7d,0xb3,0xd1,0xdf,0x4c,0x30,0xc4,
0x67,0xbd,0x77,0x15,0x9b,0x5f,0x5f,0xbb,0x68,0x71,0x19,0xa3,0x7f,0xaf,0xa6,0xc9,
0xd5,0xd6,0xb2,0x8e,0xcd,0x87,0x70,0x12,0xcb,0xf9,0x86,0x38,0x18,0x59,0x4c,0xc1,
0x7e,0xa3,0x8a,0xb8,0x99,0x4f,0x5c,0xe5,0xec,0x8e,0x8b,0xa3,0x98,0x89,0x8d,0xf1,
0xe6,0x32,0x53,0xd8,0x1a,0x0f,0xd4,0x27,0x2e,0x09,0x2c,0x2e,0x0a,0x8c,0xbe,0xaa,
0xd2,0x6a,0xf0,0x58,0x65,0xaa,0x2a,0xc4,0x61,0xf6,0xea,0x55,0x6a,0xd3,0xac,0xdb,
0x8b,0x98,0x7a,0x5b,0x49,0x51,0x51,0xd1,0xaa,0x26,0x43,0xd7,0x5d,0xbe,0x22,0x6f,
0x7b,0x21,0xec,0x04,0x9b,0xbb,0x74,0xa9,0x61,0x10,0x49,0xa7,0x66,0xac,0xf7,0x60,
0x30,0xf7,0x8c,0x07,0xdd,0x1d,0xa4,0xd3,0x85,0xbe,0x0d,0x3e,0x56,0x39,0x7f,0xf1,
0xbd,0x44,0xe0,0x8c,0x66,0xf7,0x83,0x33,0x7c,0xbe,0x87,0x99,0xbb,0xed,0x41,0xe5,
0xde,0xa5,0xb5,0xf7,0x94,0xd7,0xce,0x2b,0x2f,0xe3,0x5f,0xab,0x5a,0xdd,0xd2,0xb1,
0xee,0x21,0x57,0x87,0x5b,0x29,0xaf,0x5f,0xd8,0x50,0x5d,0x55,0x5e,0x3f,0x7f,0x69,
0xed,0xe2,0x32,0x8f,0xab,0xa3,0xa3,0xdd,0x57,0xd0,0xbe,0xce,0xe5,0x29,0xf0,0x36,
0xb7,0xb4,0x2b,0xad,0xed,0xae,0xe6,0xf2,0xda,0xd9,0xa0,0xab,0xd0,0xbb,0x56,0x59,
0xdf,0x46,0x65,0x32,0x36,0xff,0x81,0x69,0x14,0x96,0x30,0xe9,0x45,0xa9,0xb3,0xaf,
0x8f,0x05,0xf9,0xb7,0xa0,0x38,0xdc,0xc0,0xe1,0xbb,0xe4,0xb1,0xfa,0xa3,0x2f,0x11,
0xfc,0x8f,0xfc,0x94,0xbe,0x95,0xc3,0xcf,0x73,0x38,0x66,0xc0,0xf4,0xa9,0x15,0xd6,
0xcb,0xe1,0x83,0x77,0x11,0xfc,0x05,0xc1,0x0d,0x41,0x8e,0xf3,0x23,0x03,0xe6,0x38,
0xc7,0x5f,0x8f,0x6d,0xa2,0x4a,0xe5,0x17,0xb1,0x4d,0x7d,0x7d,0x7d,0xfe,0x62,0xe4,
0xfe,0x58,0x6c,0xd3,0x4a,0x51,0x1e,0xe4,0xf9,0x01,0x7f,0xf8,0x97,0x46,0x39,0xa9,
0x3f,0xb6,0xa9,0x15,0xed,0x3e,0xe4,0xcf,0x5b,0x5e,0xf4,0x8f,0x1c,0x31,0xda,0x57,
0x1c,0x35,0xda,0x57,0x22,0x5f,0x81,0xf6,0xc3,0xc8,0x0f,0xa0,0xfd,0x22,0xd5,0x3f,
0xff,0x2d,0xff,0xf6,0x63,0x06,0xde,0x20,0xcf,0x9f,0xf7,0x7f,0x34,0x10,0xdb,0x34,
0x07,0x78,0x27,0xde,0x8c,0x6d,0x72,0x22,0xbf,0xf4,0x96,0x31,0x5e,0xe8,0xb8,0x51,
0xbf,0xfb,0x6d,0xc2,0x7b,0xc1,0x6f,0x3f,0x11,0xdb,0x54,0x82,0x72,0xf1,0x6f,0x62,
0x9b,0x58,0x30,0xd9,0xdf,0x8c,0xbc,0x18,0xe5,0x57,0xde,0x33,0xea,0x2b,0xcf,0x19,
0xfd,0xea,0xff,0x62,0xac,0xc3,0xf9,0x99,0xd1,0xef,0xd2,0x67,0x06,0x3d,0xca,0x45,
0xa3,0xfe,0xe2,0x63,0x8c,0x9d,0x7d,0x2c,0xfe,0x0d,0x99,0xb1,0x54,0x18,0xff,0xce,
0x98,0xc8,0x03,0xe2,0x5b,0x5c,0x07,0xb7,0x19,0xdf,0x0b,0x7b,0xe5,0x0d,0xe3,0x9b,
0x5a,0xf4,0x6d,0xb4,0xeb,0xc5,0x37,0xba,0xe8,0x23,0x0d,0x21,0x94,0xa7,0x98,0xbe,
0x73,0xb6,0xb6,0xd3,0xf8,0xbe,0x57,0xde,0x66,0xe3,0x3b,0x5d,0xfb,0xbb,0x8c,0xef,
0x7b,0xbd,0x20,0x19,0xdf,0xb8,0xb2,0x8b,0x6f,0x70,0x31,0xf1,0xcd,0xb0,0x03,0x4b,
0x24,0xfe,0x3d,0x1c,0x45,0x32,0xbe,0x3b,0x96,0x2a,0xbe,0x3b,0xb6,0x7d,0xab,0x01,
0x07,0xb7,0x1a,0xdf,0x4b,0x4a,0x12,0xdf,0xf3,0xa2,0xfc,0xab,0x58,0xac,0x3d,0x0f,
0xf5,0x31,0xe4,0x34,0x06,0x62,0xde,0xf6,0x77,0xb7,0xb0,0xff,0xf2,0xdf,0x81,0xc5,
0x63,0x5f,0x17,0x3b,0xb4,0xed,0xff,0xaf,0x44,0x7f,0xd5,0x4b,0xc7,0xe8,0x73,0x4e,
0xbf,0xf1,0x5b,0x0a,0xd7,0x5f,0x45,0x2d,0x2c,0x9a,0xa9,0x14,0xa9,0x8e,0x62,0x87,
0xc3,0xa1,0xb2,0xf2,0x5b,0xd0,0xca,0xbf,0xef,0xc4,0x24,0xfa,0x50,0x90,0x6d,0x56,
0xfd,0x3c,0x96,0x60,0x4d,0x92,0xc6,0x49,0x69,0xd6,0x0c,0x69,0xb2,0x74,0xad,0x25,
0x53,0xba,0x4e,0xca,0x92,0xf3,0xa5,0x05,0x15,0x15,0xa5,0xca,0xf4,0xba,0xf6,0xf5,
0x1d,0x4d,0xee,0x8e,0x87,0x95,0x05,0xb7,0xde,0xaa,0x54,0xb5,0xf8,0xdc,0x34,0x16,
0xe2,0x97,0xdb,0x0b,0x66,0xa9,0xdf,0x52,0x8a,0x0b,0x67,0x15,0x3a,0x20,0x0e,0xde,
0xb5,0xf4,0x31,0x27,0xd7,0x2a,0x06,0xe7,0xed,0x73,0x77,0x78,0x58,0x61,0x5b,0xbb,
0xcf,0x5d,0x58,0x3e,0x77,0x51,0x81,0xcf,0xb5,0x86,0x15,0xae,0x75,0x79,0xd7,0xb2,
0xc2,0xe6,0x87,0xdb,0xbc,0x0f,0xaf,0x33,0x72,0x5f,0x07,0x2b,0x5c,0xd3,0xb6,0xbe,
0x50,0x58,0x91,0x2b,0x0a,0x0d,0x68,0xeb,0x70,0xb7,0x12,0x9e,0x01,0x78,0x5a,0x7d,
0x34,0x72,0x0b,0xfe,0xf5,0xb9,0x61,0x6e,0x0a,0x57,0x53,0x8c,0x50,0xd8,0xd1,0x4e,
0x56,0x8d,0x15,0x96,0xd7,0x2e,0x2e,0x44,0x35,0x4d,0x6f,0x80,0x2d,0xcd,0x1b,0x0c,
0xfc,0x06,0x98,0x17,0xd7,0xc3,0x06,0x7e,0x1c,0xfe,0x6e,0x53,0x07,0x27,0xc1,0xb5,
0xae,0xa5,0x09,0xd3,0xb6,0x63,0x38,0x63,0x98,0x55,0x5e,0xaf,0x31,0x00,0x7d,0x04,
0xaa,0x65,0xd5,0x7a,0x1f,0x02,0x17,0xc4,0x28,0xeb,0xd6,0xb9,0xdb,0x7c,0xff,0x05,
0x39,0x19,0x2f,0x74,0x82,0xe4,0x94,0x7f,0x5f,0x50,0xba,0xf2,0xdb,0x72,0xf1,0x5d,
0x4a,0x17,0xdf,0xd4,0x23,0x3c,0xfe,0x1d,0x40,0x69,0xec,0x3b,0x79,0xcc,0xf4,0x5d,
0xbb,0x1c,0xf1,0x0d,0x3c,0x59,0xe8,0xcb,0x5a,0xe0,0xcd,0x91,0xc6,0xda,0xe3,0xba,
0x74,0xb3,0x98,0x5b,0x16,0x7a,0xb4,0x1f,0x80,0x5f,0x36,0xfa,0x4a,0x6c,0xec,0xfb,
0x80,0x33,0x84,0x2e,0xc9,0x42,0xef,0xf2,0x6c,0x86,0xbe,0x5d,0x4d,0xdf,0x6d,0xcc,
0xd0,0x19,0xc2,0x23,0x7d,0x79,0x17,0x0a,0x5a,0x6d,0xa2,0x4b,0x16,0xa9,0x52,0xe8,
0x18,0x1f,0x0f,0x7a,0x96,0x87,0x45,0x35,0x0a,0x9a,0x2d,0x26,0xfc,0x3a,0xf1,0x6d,
0x41,0x59,0xe8,0x69,0x30,0xd1,0xd0,0x4f,0xf3,0x3a,0xa8,0xbc,0xd2,0x84,0x47,0x7a,
0xbd,0x3d,0xd1,0xd0,0x77,0xab,0x58,0x5f,0x1c,0xcf,0x2d,0x68,0x4d,0x10,0x76,0xe7,
0x60,0x92,0x61,0x83,0xae,0xe6,0x5f,0xa3,0x09,0x8f,0xeb,0x0b,0xf0,0x06,0xa4,0x2b,
0xf1,0x28,0x7d,0xcf,0x84,0x47,0xdf,0x9e,0xdc,0x08,0x43,0x54,0x72,0xc7,0xd7,0xc7,
0xfb,0xbe,0x09,0x8f,0xec,0xdc,0x2b,0xf3,0x0c,0x7a,0xae,0xc6,0x7b,0xc8,0x24,0x07,
0x87,0x81,0x77,0x18,0x78,0xdb,0x13,0xbe,0x8e,0xb7,0xc9,0x84,0xb7,0xf0,0x04,0x52,
0xd5,0x95,0xdf,0x87,0x8b,0xe3,0x3d,0x66,0xe0,0x79,0xba,0x98,0xf8,0xee,0x65,0x95,
0xf1,0xcd,0xcb,0x94,0xab,0xf0,0x9e,0x12,0xdf,0x56,0xb4,0xb0,0xf8,0xf7,0x29,0xc7,
0xda,0xcc,0x78,0xcf,0x88,0x6f,0x38,0x5a,0x84,0x5d,0x0e,0xfd,0x1d,0xbc,0x7f,0x12,
0xf4,0x11,0x1e,0x7d,0x8b,0x68,0xff,0xdf,0xc1,0x7b,0x49,0xf0,0xc4,0xc2,0xe2,0xdf,
0xbd,0x1c,0xfb,0xe6,0xa6,0x79,0x7f,0xff,0xd5,0x34,0x1e,0xd9,0xf3,0x03,0x4b,0x30,
0x2e,0xfb,0xfa,0x7e,0xf4,0x9b,0xf0,0xaa,0x60,0xdb,0xaa,0x96,0x8e,0x7d,0x7b,0xd2,
0x3c,0xef,0x9b,0x62,0x5c,0xc2,0xa3,0xef,0x2a,0xad,0x03,0xde,0xc0,0x8c,0xaf,0xe3,
0xbd,0x63,0xe0,0x78,0xe2,0xf5,0x84,0x77,0xeb,0x37,0xe8,0xe5,0x1f,0x04,0xac,0x8a,
0xf2,0x6e,0xe0,0xdd,0x72,0x15,0x9e,0x64,0xa2,0x2d,0xfe,0x77,0x14,0x78,0x43,0xdf,
0x30,0xde,0xff,0x01,0xe6,0x1c,0x9d,0x8d,0xe0,0x54,0x00,0x00,
};
#endif

